@@ -60,12 +60,18 @@
 namespace BeagleWksSSParserInternal
 {
 //! Internal: the cell of a BeagleWksSSParser
-struct Cell : public MWAWCell {
+struct Cell final : public MWAWCell {
   //! constructor
-  Cell(MWAWVec2i pos=MWAWVec2i(0,0)) : MWAWCell(), m_content(), m_formula(-1), m_isEmpty(false)
+  explicit Cell(MWAWVec2i pos=MWAWVec2i(0,0))
+    : MWAWCell()
+    , m_content()
+    , m_formula(-1)
+    , m_isEmpty(false)
   {
     setPosition(pos);
   }
+  //! destructor
+  ~Cell() final;
   //! the cell content
   MWAWCellContent m_content;
   //! the formula id
@@ -74,14 +80,47 @@ struct Cell : public MWAWCell {
   bool m_isEmpty;
 };
 
+Cell::~Cell()
+{
+}
+
 //! Internal: the spreadsheet of a BeagleWksSSParser
 struct Spreadsheet {
   //! constructor
-  Spreadsheet() : m_numRows(0), m_widthCols(), m_heightRows(), m_cells(), m_lastReadRow(-1)
+  Spreadsheet()
+    : m_numRows(0)
+    , m_widthCols()
+    , m_heightRows()
+    , m_cells()
+    , m_lastReadRow(-1)
   {
   }
   //! try to associate a formula to a cell
   bool addFormula(MWAWVec2i const &cellPos, std::vector<MWAWCellContent::FormulaInstruction> const &formula);
+  //! returns the height of a row in point
+  double getRowHeight(int row) const
+  {
+    if (row<0 || row>=static_cast<int>(m_heightRows.size()) || m_heightRows[size_t(row)]<0)
+      return 16.;
+    return m_heightRows[size_t(row)];
+  }
+  //! returns the height of a row in point and updated repeated row
+  double getRowHeight(int row, int &numRepeated) const
+  {
+    double res=getRowHeight(row);
+    numRepeated=1;
+    if (row<0 || row>=static_cast<int>(m_heightRows.size()))
+      numRepeated=1000;
+    else {
+      for (auto r=size_t(row+1); r<m_heightRows.size(); ++r) {
+        double nextH=getRowHeight(row+1);
+        if (nextH<res || nextH>res)
+          break;
+        ++numRepeated;
+      }
+    }
+    return res;
+  }
   //! convert the m_widthCols, m_heightRows in a vector of of point size
   static std::vector<float> convertInPoint(std::vector<int> const &list,
       float defSize)
@@ -99,9 +138,9 @@ struct Spreadsheet {
   void updateWidthCols()
   {
     int maxCol=-1;
-    for (size_t i = 0; i < m_cells.size(); ++i) {
-      if (m_cells[i].position()[0]>maxCol)
-        maxCol = m_cells[i].position()[0];
+    for (auto const &cell : m_cells) {
+      if (cell.position()[0]>maxCol)
+        maxCol = cell.position()[0];
     }
     m_widthCols.resize(size_t(maxCol+1),-1);
   }
@@ -119,10 +158,10 @@ struct Spreadsheet {
 
 bool Spreadsheet::addFormula(MWAWVec2i const &cellPos, std::vector<MWAWCellContent::FormulaInstruction> const &formula)
 {
-  for (size_t c=0; c < m_cells.size(); ++c) {
-    if (m_cells[c].position()!=cellPos)
+  for (auto &cell : m_cells) {
+    if (cell.position()!=cellPos)
       continue;
-    m_cells[c].m_content.m_formula=formula;
+    cell.m_content.m_formula=formula;
     return true;
   }
   MWAW_DEBUG_MSG(("Spreadsheet::addFormula: can not find cell with position %dx%d\n", cellPos[0], cellPos[1]));
@@ -130,21 +169,23 @@ bool Spreadsheet::addFormula(MWAWVec2i const &cellPos, std::vector<MWAWCellConte
 }
 
 //! Internal: the chart of a BeagleWksSSParser
-struct Chart : public MWAWChart {
+struct Chart final : public MWAWChart {
   //! constructor
-  Chart(std::string const &name, BeagleWksSSParser &parser) : MWAWChart(name, parser.getParserState()->m_fontConverter),
-    m_parser(&parser), m_input(parser.getInput())
+  Chart(std::string const &name, BeagleWksSSParser &parser)
+    : MWAWChart(name, parser.getParserState()->m_fontConverter)
+    , m_parser(&parser)
+    , m_input(parser.getInput())
   {
   }
   //! send a zone content
-  void sendContent(TextZone const &zone, MWAWListenerPtr &listener);
+  void sendContent(TextZone const &zone, MWAWListenerPtr &listener) final;
   //! the main parser
   BeagleWksSSParser *m_parser;
   //! the input
   MWAWInputStreamPtr m_input;
 private:
-  Chart(Chart const &orig);
-  Chart operator=(Chart const &orig);
+  Chart(Chart const &orig) = delete;
+  Chart operator=(Chart const &orig) = delete;
 };
 
 void Chart::sendContent(Chart::TextZone const &zone, MWAWListenerPtr &listener)
@@ -163,8 +204,16 @@ void Chart::sendContent(Chart::TextZone const &zone, MWAWListenerPtr &listener)
 //! Internal: the state of a BeagleWksSSParser
 struct State {
   //! constructor
-  State() :  m_spreadsheetBegin(-1), m_spreadsheet(), m_spreadsheetName("Sheet0"), m_chartList(), m_typeEntryMap(),
-    m_actPage(0), m_numPages(0), m_headerHeight(0), m_footerHeight(0)
+  State()
+    : m_spreadsheetBegin(-1)
+    , m_spreadsheet()
+    , m_spreadsheetName("Sheet0")
+    , m_chartList()
+    , m_typeEntryMap()
+    , m_actPage(0)
+    , m_numPages(0)
+    , m_headerHeight(0)
+    , m_footerHeight(0)
   {
   }
   //! returns a color corresponding to an id
@@ -207,7 +256,7 @@ struct State {
   /** the spreadsheet name */
   std::string m_spreadsheetName;
   /** the list of chart */
-  std::vector<shared_ptr<Chart> > m_chartList;
+  std::vector<std::shared_ptr<Chart> > m_chartList;
   /** the type entry map */
   std::multimap<std::string, MWAWEntry> m_typeEntryMap;
   int m_actPage /** the actual page */, m_numPages /** the number of page of the final document */;
@@ -218,35 +267,29 @@ struct State {
 
 ////////////////////////////////////////
 //! Internal: the subdocument of a BeagleWksSSParser
-class SubDocument : public MWAWSubDocument
+class SubDocument final : public MWAWSubDocument
 {
 public:
-  SubDocument(BeagleWksSSParser &pars, MWAWInputStreamPtr input, MWAWEntry const &entry) :
-    MWAWSubDocument(&pars, input, entry)
+  SubDocument(BeagleWksSSParser &pars, MWAWInputStreamPtr &input, MWAWEntry const &entry)
+    : MWAWSubDocument(&pars, input, entry)
   {
   }
 
   //! destructor
-  virtual ~SubDocument() {}
+  ~SubDocument() final {}
 
   //! operator!=
-  virtual bool operator!=(MWAWSubDocument const &doc) const
+  bool operator!=(MWAWSubDocument const &doc) const final
   {
     return MWAWSubDocument::operator!=(doc);
   }
-  //! operator!==
-  virtual bool operator==(MWAWSubDocument const &doc) const
-  {
-    return !operator!=(doc);
-  }
 
   //! the parser function
-  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type);
+  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type) final;
 
-protected:
 private:
-  SubDocument(SubDocument const &orig);
-  SubDocument &operator=(SubDocument const &orig);
+  SubDocument(SubDocument const &orig) = delete;
+  SubDocument &operator=(SubDocument const &orig) = delete;
 };
 
 void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType /*type*/)
@@ -255,7 +298,7 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType /*ty
     MWAW_DEBUG_MSG(("BeagleWksSSParserInternal::SubDocument::parse: no listener\n"));
     return;
   }
-  BeagleWksSSParser *parser=dynamic_cast<BeagleWksSSParser *>(m_parser);
+  auto *parser=dynamic_cast<BeagleWksSSParser *>(m_parser);
   if (!parser) {
     MWAW_DEBUG_MSG(("BeagleWksSSParserInternal::SubDocument::parse: can not find the parser\n"));
     return;
@@ -272,8 +315,10 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType /*ty
 ////////////////////////////////////////////////////////////
 // constructor/destructor, ...
 ////////////////////////////////////////////////////////////
-BeagleWksSSParser::BeagleWksSSParser(MWAWInputStreamPtr input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header) :
-  MWAWSpreadsheetParser(input, rsrcParser, header), m_state(), m_structureManager()
+BeagleWksSSParser::BeagleWksSSParser(MWAWInputStreamPtr const &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header)
+  : MWAWSpreadsheetParser(input, rsrcParser, header)
+  , m_state()
+  , m_structureManager()
 {
   init();
 }
@@ -334,14 +379,14 @@ void BeagleWksSSParser::newPage(int number)
 ////////////////////////////////////////////////////////////
 void BeagleWksSSParser::parse(librevenge::RVNGSpreadsheetInterface *docInterface)
 {
-  if (!getInput().get() || !checkHeader(0L))  throw(libmwaw::ParseException());
+  if (!getInput().get() || !checkHeader(nullptr))  throw(libmwaw::ParseException());
   bool ok = false;
   try {
     // create the asciiFile
     ascii().setStream(getInput());
     ascii().open(asciiName());
 
-    checkHeader(0L);
+    checkHeader(nullptr);
     ok = createZones();
     if (ok) {
       createDocument(docInterface);
@@ -381,14 +426,14 @@ void BeagleWksSSParser::createDocument(librevenge::RVNGSpreadsheetInterface *doc
   std::vector<MWAWPageSpan> pageList;
   MWAWPageSpan ps(getPageSpan());
   if (header.valid()) {
-    shared_ptr<BeagleWksSSParserInternal::SubDocument> subDoc
+    std::shared_ptr<BeagleWksSSParserInternal::SubDocument> subDoc
     (new BeagleWksSSParserInternal::SubDocument(*this, getInput(), header));
     MWAWHeaderFooter hf(MWAWHeaderFooter::HEADER, MWAWHeaderFooter::ALL);
     hf.m_subDocument=subDoc;
     ps.setHeaderFooter(hf);
   }
   if (footer.valid()) {
-    shared_ptr<BeagleWksSSParserInternal::SubDocument> subDoc
+    std::shared_ptr<BeagleWksSSParserInternal::SubDocument> subDoc
     (new BeagleWksSSParserInternal::SubDocument(*this, getInput(), footer));
     MWAWHeaderFooter hf(MWAWHeaderFooter::FOOTER, MWAWHeaderFooter::ALL);
     hf.m_subDocument=subDoc;
@@ -428,7 +473,7 @@ bool BeagleWksSSParser::createZones()
     MWAWEntry entry;
     entry.setBegin(input->readLong(4));
     entry.setLength(input->readLong(4));
-    entry.setId((int) input->readLong(2));
+    entry.setId(static_cast<int>(input->readLong(2)));
     if (entry.length()==0) continue;
     entry.setType(i==1?"Frame":"Unknown");
     f << entry.type() << "[" << entry.id() << "]="
@@ -451,8 +496,7 @@ bool BeagleWksSSParser::createZones()
   ascii().addNote(f.str().c_str());
 
   // now parse the different zones
-  std::multimap<std::string, MWAWEntry>::iterator it;
-  it=m_state->m_typeEntryMap.find("FontNames");
+  auto it=m_state->m_typeEntryMap.find("FontNames");
   if (it!=m_state->m_typeEntryMap.end())
     m_structureManager->readFontNames(it->second);
   it=m_state->m_typeEntryMap.find("Frame");
@@ -460,8 +504,8 @@ bool BeagleWksSSParser::createZones()
     m_structureManager->readFrame(it->second);
 
   // now parse the different zones
-  for (it=m_state->m_typeEntryMap.begin(); it!=m_state->m_typeEntryMap.end(); ++it) {
-    MWAWEntry const &entry=it->second;
+  for (auto eIt : m_state->m_typeEntryMap) {
+    MWAWEntry const &entry=eIt.second;
     if (entry.isParsed())
       continue;
     f.str("");
@@ -483,7 +527,7 @@ bool BeagleWksSSParser::createZones()
   if (!readChartZone())
     input->seek(pos, librevenge::RVNG_SEEK_SET);
   if (!readSpreadsheet())
-    return m_state->m_spreadsheet.m_cells.size()!=0;
+    return !m_state->m_spreadsheet.m_cells.empty();
   /* normally ends with a zone of size 25
      with looks like 01010000010000000000000000007cffff007d0100007c0000
                 or   01010001010000000000000000000000000001000100000000
@@ -496,16 +540,15 @@ bool BeagleWksSSParser::createZones()
 
 bool BeagleWksSSParser::readRSRCZones()
 {
-  MWAWRSRCParserPtr rsrcParser = getRSRCParser();
+  auto rsrcParser = getRSRCParser();
   if (!rsrcParser)
     return true;
 
-  std::multimap<std::string, MWAWEntry> &entryMap = rsrcParser->getEntriesMap();
-  std::multimap<std::string, MWAWEntry>::iterator it;
+  auto &entryMap = rsrcParser->getEntriesMap();
   // the 1 zone
-  char const *(zNames[]) = {"wPos", "DMPF" };
+  char const *zNames[] = {"wPos", "DMPF" };
   for (int z = 0; z < 2; ++z) {
-    it = entryMap.lower_bound(zNames[z]);
+    auto it = entryMap.lower_bound(zNames[z]);
     while (it != entryMap.end()) {
       if (it->first != zNames[z])
         break;
@@ -602,7 +645,7 @@ bool BeagleWksSSParser::readChartZone()
   pos = input->tell();
   for (int i=0; i < 4; ++i) {
     static int const expectedValues[5]= {1, 0xF, 0x4000, 0x100 };
-    int val= (int) input->readULong(2);
+    auto val= static_cast<int>(input->readULong(2));
     if (val != expectedValues[i])
       f << "f" << i+1 << "=" << std::hex << val << std::dec << ",";
   }
@@ -610,7 +653,7 @@ bool BeagleWksSSParser::readChartZone()
   ascii().addNote(f.str().c_str());
   while (!input->isEnd()) {
     pos=input->tell();
-    long sz=(long) input->readULong(2);
+    auto sz=long(input->readULong(2));
     if (sz==0) {
       ascii().addPos(pos);
       ascii().addNote("Chart:_");
@@ -634,17 +677,17 @@ bool BeagleWksSSParser::readChart()
   }
   libmwaw::DebugStream f;
   f << "Chart-header:";
-  int val=(int) input->readULong(2);
+  auto val=static_cast<int>(input->readULong(2));
   f << "f0=" << std::hex << val << std::dec << ",";
-  val=(int) input->readLong(2);
+  val=static_cast<int>(input->readLong(2));
   if (val!=0x12) f << "f1=" << val << ",";
   bool findRange=false;
-  shared_ptr<BeagleWksSSParserInternal::Chart> chart(new BeagleWksSSParserInternal::Chart(m_state->m_spreadsheetName, *this));
+  std::shared_ptr<BeagleWksSSParserInternal::Chart> chart(new BeagleWksSSParserInternal::Chart(m_state->m_spreadsheetName, *this));
   MWAWBox2i serieRange;
   for (int i=0; i<2; ++i) {
     long actPos=input->tell();
-    int dSz=(int) input->readULong(2);
-    int sSz=(int) input->readULong(1);
+    auto dSz=static_cast<int>(input->readULong(2));
+    auto sSz=static_cast<int>(input->readULong(1));
     if (sSz+1!=dSz && sSz+2!=dSz) {
       input->seek(pos, librevenge::RVNG_SEEK_SET);
       MWAW_DEBUG_MSG(("BeagleWksSSParser::readChart: can not read the chart\n"));
@@ -655,23 +698,23 @@ bool BeagleWksSSParser::readChart()
     }
     std::string name("");
     for (int c=0; c<sSz; ++c)
-      name += (char) input->readULong(1);
-    if (i==1 && sSz>=5 && (int) name.length()==sSz) {
+      name += char(input->readULong(1));
+    if (i==1 && sSz>=5 && static_cast<int>(name.length())==sSz) {
       size_t cPos=0;
       for (int c=0; c<2; c++) {
-        if (cPos+1>=(size_t) sSz) break;
+        if (cPos+1>=size_t(sSz)) break;
         char ch=name[cPos++];
         if (ch<'A' || ch>'Z') break;
         int col=int(ch-'A')+1;
         ch=name[cPos++];
         if (ch>='A' && ch<='Z') {
           col=26*col+int(ch-'A')+1;
-          if (cPos+1>=(size_t) sSz) break;
+          if (cPos+1>=size_t(sSz)) break;
           ch=name[cPos++];
         }
         if (ch<'1' || ch>'9') break;
         int row=ch-'0';
-        while (cPos<(size_t)sSz && name[cPos]>='0' && name[cPos]<='9') {
+        while (cPos<size_t(sSz) && name[cPos]>='0' && name[cPos]<='9') {
           row=row*10+int(name[cPos++]-'0');
         }
         if (c==0)
@@ -681,7 +724,7 @@ bool BeagleWksSSParser::readChart()
           findRange=true;
           break;
         }
-        if (cPos>=(size_t)sSz || name[cPos++]!=':')
+        if (cPos>=size_t(sSz) || name[cPos++]!=':')
           break;
       }
     }
@@ -698,7 +741,7 @@ bool BeagleWksSSParser::readChart()
   pos=input->tell();
   f.str("");
   f << "Chart-B:";
-  val=(int) input->readLong(1);
+  val=static_cast<int>(input->readLong(1));
   MWAWChart::Axis axis[2];
   switch (val) {
   case 1: // show
@@ -712,13 +755,13 @@ bool BeagleWksSSParser::readChart()
     f << "#show[label]=" << val << ",";
     break;
   }
-  val=(int) input->readLong(1);
+  val=static_cast<int>(input->readLong(1));
   if (val) f << "f0=" << val << ",";
-  val=(int) input->readLong(1);
+  val=static_cast<int>(input->readLong(1));
   f << "f1=" << val << ",";
   for (int i=0; i<7; ++i) {
     int dim[2];
-    for (int j=0; j<2; ++j) dim[j]=(int) input->readLong(2);
+    for (int &j : dim) j=static_cast<int>(input->readLong(2));
     if (dim[0]||dim[1])
       f << "dim" << i << "?=" << dim[0] << "x" << dim[1] << ",";
   }
@@ -730,12 +773,12 @@ bool BeagleWksSSParser::readChart()
   f << "Chart-C:";
   for (int i=0; i<3; ++i) {
     int const expectedVal[3]= {0xe, 0, 0x21};
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     if (val!=expectedVal[i]) f << "f" << i << "=" << val << ",";
   }
-  val=(int) input->readLong(2);
+  val=static_cast<int>(input->readLong(2));
   f << "f3=" << val << ",";
-  val=(int) input->readLong(1);
+  val=static_cast<int>(input->readLong(1));
 
   axis[1].m_type=MWAWChart::Axis::A_Numeric;
   switch (val) {
@@ -749,7 +792,7 @@ bool BeagleWksSSParser::readChart()
     f << "#yScale="<<val << ",";
     break;
   }
-  val=(int) input->readLong(1);
+  val=static_cast<int>(input->readLong(1));
 
   axis[0].m_type=MWAWChart::Axis::A_Sequence;
   switch (val) {
@@ -768,9 +811,9 @@ bool BeagleWksSSParser::readChart()
   }
   axis[0].m_showGrid=axis[1].m_showGrid=false;
   for (int i=0; i<4; ++i) {
-    val=(int) input->readLong(1);
+    val=static_cast<int>(input->readLong(1));
     if (!val) continue;
-    char const *(wh[4])= {"draw[grid]", "draw[value]", "auto[scale]", "flip[RowCol]"};
+    char const *wh[4] = {"draw[grid]", "draw[value]", "auto[scale]", "flip[RowCol]"};
     f << wh[i];
     if (val!=1) {
       if (i==0)
@@ -780,17 +823,17 @@ bool BeagleWksSSParser::readChart()
     else f << ",";
   }
   for (int i=0; i<3; ++i) {
-    char const *(wh[3])= {"minScale", "maxScale", "step[value]"};
+    char const *wh[3] = {"minScale", "maxScale", "step[value]"};
     double value=0;
     bool isNAN=false;
     if (!input->readDouble8(value, isNAN))
       f << "###";
     f << wh[i] << "=" << value << ",";
   }
-  val=(int) input->readULong(1); // always 0?
+  val=static_cast<int>(input->readULong(1)); // always 0?
   if (val) f << "g0=" << val << ",";
-  val=(int) input->readULong(1);
-  MWAWChart::Series::Type serieType=MWAWChart::Series::S_Bar;
+  val=static_cast<int>(input->readULong(1));
+  auto serieType=MWAWChart::Series::S_Bar;
   switch (val) {
   case 0x19:
     serieType=MWAWChart::Series::S_Line;
@@ -836,7 +879,7 @@ bool BeagleWksSSParser::readChart()
   long endPos = pos+67;
   f.str("");
   f << "Chart-D:";
-  int sSz=(int) input->readULong(1);
+  auto sSz=static_cast<int>(input->readULong(1));
   if (pos+1+sSz <= endPos) {
     MWAWChart::TextZone title;
     title.m_type=MWAWChart::TextZone::T_Title;
@@ -846,7 +889,7 @@ bool BeagleWksSSParser::readChart()
     chart->add(title);
     std::string name("");
     for (int c=0; c<sSz; ++c)
-      name += (char) input->readULong(1);
+      name += char(input->readULong(1));
     f << "\"" << name << "\",";
   }
   else
@@ -860,7 +903,7 @@ bool BeagleWksSSParser::readChart()
       series.m_range=MWAWBox2i(MWAWVec2i(serieRange[0][0], r),
                                MWAWVec2i(serieRange[1][0], r));
       series.m_type=serieType;
-      unsigned char gray=(unsigned char)((r%4)*30);
+      auto gray=static_cast<unsigned char>((r%4)*30);
       series.m_style.m_lineWidth=1;
       series.m_style.m_lineColor=MWAWColor(gray,gray,gray);
       series.m_style.setSurfaceColor(MWAWColor(gray,gray,gray));
@@ -892,17 +935,17 @@ bool BeagleWksSSParser::readSpreadsheet()
   }
   libmwaw::DebugStream f;
   f << "Entries(Spreadsheet):";
-  int val= (int) input->readLong(2);
+  auto val= static_cast<int>(input->readLong(2));
   if (val!=7)
     f << "f1=" << val << ",";
-  BeagleWksSSParserInternal::Spreadsheet &sheet=m_state->m_spreadsheet;
-  sheet.m_numRows=(int) input->readLong(2)+1;
+  auto &sheet=m_state->m_spreadsheet;
+  sheet.m_numRows=static_cast<int>(input->readLong(2))+1;
   f << "num[row]=" << sheet.m_numRows << ",";
-  val= (int) input->readLong(2);
+  val= static_cast<int>(input->readLong(2));
   if (val!=-1)
     f << "f2=" << val << ",";
   for (int i=0; i < 3; ++i) { // g0=0|73|89, other 0
-    val=(int) input->readULong(1);
+    val=static_cast<int>(input->readULong(1));
     if (val)
       f << "g" << i << "=" << std::hex << val << std::dec << ",";
   }
@@ -920,8 +963,8 @@ bool BeagleWksSSParser::readRowSheet(BeagleWksSSParserInternal::Spreadsheet &she
   long pos=input->tell();
   libmwaw::DebugStream f;
   f << "Entries(Row):";
-  int row=(int)input->readLong(2);
-  long fSz=(long) input->readULong(4);
+  auto row=static_cast<int>(input->readLong(2));
+  auto fSz=long(input->readULong(4));
   long endPos=pos+6+fSz;
   if (fSz<18 || row <= sheet.m_lastReadRow || row >= sheet.m_numRows || !input->checkPosition(endPos)) {
     input->seek(pos, librevenge::RVNG_SEEK_SET);
@@ -929,18 +972,18 @@ bool BeagleWksSSParser::readRowSheet(BeagleWksSSParserInternal::Spreadsheet &she
   }
   sheet.m_lastReadRow=row;
   f << "row=" << row << ",";
-  int val=(int) input->readLong(2);
+  auto val=static_cast<int>(input->readLong(2));
   if (val && val!=int(fSz))
     f << "#sz=" << val << ",";
-  int h=(int) input->readLong(2);
+  auto h=static_cast<int>(input->readLong(2));
   if (h!=-1)
     f << "height=" << h << ",";
   sheet.m_heightRows.resize(size_t(row)+1, -1);
   sheet.m_heightRows[size_t(row)]=h;
   input->seek(10, librevenge::RVNG_SEEK_CUR); // junk
-  int N=(int) input->readLong(2)+1;
+  int N=static_cast<int>(input->readLong(2))+1;
   f << "N=" << N << ",";
-  val=(int) input->readLong(2);
+  val=static_cast<int>(input->readLong(2));
   if (val!=fSz && val) {
     if (val+1 > N) N=val+1;
     f << "unkn=" << val << ",";
@@ -967,7 +1010,7 @@ bool BeagleWksSSParser::readCellSheet(BeagleWksSSParserInternal::Cell &cell)
 {
   MWAWInputStreamPtr &input= getInput();
   long pos=input->tell();
-  int cSize=(int) input->readULong(1);
+  auto cSize=static_cast<int>(input->readULong(1));
   long endPos=pos+2+cSize+((cSize%2)?1:0);
   libmwaw::DebugStream f;
   f << "Entries(Cell)[" << cell.position() << "]:";
@@ -980,7 +1023,7 @@ bool BeagleWksSSParser::readCellSheet(BeagleWksSSParserInternal::Cell &cell)
   }
   MWAWCell::Format format;
 
-  int val=(int) input->readULong(1);
+  auto val=static_cast<int>(input->readULong(1));
   bool isFormula=val&0x80;
   if (isFormula) f << "formula,";
   int type=(val>>4)&7;
@@ -992,18 +1035,18 @@ bool BeagleWksSSParser::readCellSheet(BeagleWksSSParserInternal::Cell &cell)
       ascii().addDelimiter(pos+10,'|');
     // first read the flags which indicated what is filled
     input->seek(pos+9, librevenge::RVNG_SEEK_SET);
-    int wh=(int) input->readULong(1);
+    auto wh=static_cast<int>(input->readULong(1));
     if (wh) {
       f << "style=[";
       input->seek(pos+2, librevenge::RVNG_SEEK_SET);
       MWAWFont font(3);
-      val=(int) input->readLong(2);
+      val=static_cast<int>(input->readLong(2));
       if (val>0)
-        font.setSize((float) val);
-      val=(int) input->readLong(2);
+        font.setSize(float(val));
+      val=static_cast<int>(input->readLong(2));
       if (val>=0)
         font.setId(val);
-      int flag = (int) input->readULong(1);
+      auto flag = static_cast<int>(input->readULong(1));
       uint32_t flags=0;
       MWAWColor col;
       if (flag&7 && m_state->getColor(flag&7, col))
@@ -1016,7 +1059,7 @@ bool BeagleWksSSParser::readCellSheet(BeagleWksSSParserInternal::Cell &cell)
       font.setFlags(flags);
       cell.setFont(font);
       f << font.getDebugString(getParserState()->m_fontConverter);
-      int form=(int) input->readULong(1);
+      auto form=static_cast<int>(input->readULong(1));
       if (form) {
         if (form & 0x10)
           format.m_thousandHasSeparator=true;
@@ -1090,11 +1133,11 @@ bool BeagleWksSSParser::readCellSheet(BeagleWksSSParserInternal::Cell &cell)
           format.m_digits=(form & 0xf);
         f << format;
       }
-      val=(int) input->readULong(1);
+      val=static_cast<int>(input->readULong(1));
       if (val>>4) {
         int cId=(val>>4);
         if (cId<5) { // first five gray colors, white, lightgray, ... black
-          unsigned char gray=(unsigned char)((4-cId)*0x40);
+          auto gray=static_cast<unsigned char>((4-cId)*0x40);
           cell.setBackgroundColor(MWAWColor(gray,gray,gray));
         }
         else if (m_state->getColor(cId-3,col))
@@ -1146,7 +1189,7 @@ bool BeagleWksSSParser::readCellSheet(BeagleWksSSParserInternal::Cell &cell)
     }
     input->seek(pos+10, librevenge::RVNG_SEEK_SET);
   }
-  MWAWCellContent &content=cell.m_content;
+  auto &content=cell.m_content;
   switch (type) {
   case 0:
     f << "_";
@@ -1179,7 +1222,7 @@ bool BeagleWksSSParser::readCellSheet(BeagleWksSSParserInternal::Cell &cell)
       content.m_contentType=MWAWCellContent::C_FORMULA;
       if (format.m_format==MWAWCell::F_UNKNOWN)
         format.m_format=MWAWCell::F_NUMBER;
-      cell.m_formula=(int) input->readULong(2);
+      cell.m_formula=static_cast<int>(input->readULong(2));
       f << "id[formula]=" << cell.m_formula << ",";
     }
     else
@@ -1214,7 +1257,7 @@ bool BeagleWksSSParser::readCellSheet(BeagleWksSSParserInternal::Cell &cell)
       content.m_contentType=MWAWCellContent::C_FORMULA;
       if (format.m_format==MWAWCell::F_UNKNOWN)
         format.m_format=MWAWCell::F_TEXT;
-      cell.m_formula=(int) input->readULong(2);
+      cell.m_formula=static_cast<int>(input->readULong(2));
       f << "id[formula]=" << cell.m_formula << ",";
     }
     else
@@ -1223,7 +1266,7 @@ bool BeagleWksSSParser::readCellSheet(BeagleWksSSParserInternal::Cell &cell)
     content.m_textEntry.setLength(cSize-8-(isFormula?2:0));
     std::string text("");
     for (long i=0; i < content.m_textEntry.length(); ++i)
-      text+=(char) input->readULong(1);
+      text+=char(input->readULong(1));
     f << "\"" << text << "\",";
     break;
   }
@@ -1250,7 +1293,7 @@ bool BeagleWksSSParser::readZone0()
   long pos=input->tell();
   libmwaw::DebugStream f;
   f << "Entries(Zone0):";
-  int N=(int) input->readULong(2);
+  auto N=static_cast<int>(input->readULong(2));
   if (!input->checkPosition(pos+8+3*N)) {
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     return false;
@@ -1271,11 +1314,11 @@ bool BeagleWksSSParser::readColumnWidths(BeagleWksSSParserInternal::Spreadsheet
   long pos=input->tell();
   libmwaw::DebugStream f;
   f << "Entries(Columns):";
-  int N=(int) input->readLong(2);
+  auto N=static_cast<int>(input->readLong(2));
   f << "N=" << N << ",";
-  int val=(int) input->readLong(2);
+  auto val=static_cast<int>(input->readLong(2));
   if (val) f << "f0=" << val << ",";
-  int dSz=(int) input->readULong(2);
+  auto dSz=static_cast<int>(input->readULong(2));
   if (N<-1 || (N>=0 && dSz<=0) || !input->checkPosition(pos+6+(N+1)*dSz)) {
     MWAW_DEBUG_MSG(("BeagleWksSSParser::Zone&: header seems odd\n"));
     f << "###";
@@ -1291,15 +1334,15 @@ bool BeagleWksSSParser::readColumnWidths(BeagleWksSSParserInternal::Spreadsheet
     f.str("");
     f << "Columns-" << i << ":";
     if (dSz >= 8) {
-      val=(int) input->readLong(2);
+      val=static_cast<int>(input->readLong(2));
       if (val==1) f << "set,";
       else if (val) f << "#set=" << val << ",";
-      int w=(int) input->readLong(2);
+      auto w=static_cast<int>(input->readLong(2));
       sheet.m_widthCols.push_back(w);
       if (w>0)
         f << "w=" << w << ",";
       for (int j=0; j<2; ++j) {
-        val=(int) input->readULong(2);
+        val=static_cast<int>(input->readULong(2));
         if (val!=0xFFFF)
           f << "f" << j << "=" << std::hex << val << std::dec << ",";
       }
@@ -1328,8 +1371,8 @@ bool BeagleWksSSParser::readFormula(BeagleWksSSParserInternal::Spreadsheet &shee
     else
       f << "Formula-" << id << ":";
     ++id;
-    int row=(int) input->readULong(2);
-    int col=(int) input->readULong(2);
+    auto row=static_cast<int>(input->readULong(2));
+    auto col=static_cast<int>(input->readULong(2));
     if (row==0x4000 && col==0x4000) {
       f << "last,";
       ascii().addPos(pos);
@@ -1337,7 +1380,7 @@ bool BeagleWksSSParser::readFormula(BeagleWksSSParserInternal::Spreadsheet &shee
       return true;
     }
     f << "pos=" << col << "x" << row << ",";
-    int dataSz=(int) input->readULong(2);
+    auto dataSz=static_cast<int>(input->readULong(2));
     if (!dataSz || !input->checkPosition(pos+6+dataSz)) {
       input->seek(pos, librevenge::RVNG_SEEK_SET);
       break;
@@ -1348,8 +1391,8 @@ bool BeagleWksSSParser::readFormula(BeagleWksSSParserInternal::Spreadsheet &shee
       sheet.addFormula(MWAWVec2i(col,row), formula);
     else
       f << "###";
-    for (size_t l=0; l < formula.size(); ++l)
-      f << formula[l];
+    for (auto const &fo : formula)
+      f << fo;
     if (input->tell()!=pos+6+dataSz)
       ascii().addDelimiter(input->tell(),'|');
     input->seek(pos+6+dataSz, librevenge::RVNG_SEEK_SET);
@@ -1364,10 +1407,9 @@ bool BeagleWksSSParser::readFormula(BeagleWksSSParserInternal::Spreadsheet &shee
 ////////////////////////////////////////////////////////////
 bool BeagleWksSSParser::sendPageFrames()
 {
-  std::map<int, BeagleWksStructManager::Frame> const &frameMap = m_structureManager->getIdFrameMap();
-  std::map<int, BeagleWksStructManager::Frame>::const_iterator it;
-  for (it=frameMap.begin(); it!=frameMap.end(); ++it)
-    sendFrame(it->second);
+  auto const &frameMap = m_structureManager->getIdFrameMap();
+  for (auto it : frameMap)
+    sendFrame(it.second);
   return true;
 }
 
@@ -1393,7 +1435,7 @@ bool BeagleWksSSParser::sendPicture
     MWAW_DEBUG_MSG(("BeagleWksSSParser::sendPicture: can not find the listener\n"));
     return false;
   }
-  MWAWRSRCParserPtr rsrcParser = getRSRCParser();
+  auto rsrcParser = getRSRCParser();
   if (!rsrcParser) {
     static bool first=true;
     if (first) {
@@ -1411,7 +1453,7 @@ bool BeagleWksSSParser::sendPicture
   return true;
 }
 
-bool BeagleWksSSParser::sendText(MWAWEntry entry, bool /*headerFooter*/)
+bool BeagleWksSSParser::sendText(MWAWEntry const &entry, bool /*headerFooter*/)
 {
   MWAWSpreadsheetListenerPtr listener=getSpreadsheetListener();
   if (!listener) {
@@ -1429,7 +1471,7 @@ bool BeagleWksSSParser::sendText(MWAWEntry entry, bool /*headerFooter*/)
   while (!input->isEnd()) {
     long pos=input->tell();
     if (pos>=endPos) break;
-    unsigned char c = (unsigned char) input->readULong(1);
+    auto c = static_cast<unsigned char>(input->readULong(1));
     switch (c) {
     case 0x9:
       listener->insertTab();
@@ -1438,7 +1480,7 @@ bool BeagleWksSSParser::sendText(MWAWEntry entry, bool /*headerFooter*/)
       listener->insertEOL();
       break;
     default:
-      listener->insertCharacter((unsigned char) c);
+      listener->insertCharacter(static_cast<unsigned char>(c));
       break;
     }
   }
@@ -1455,45 +1497,45 @@ bool BeagleWksSSParser::sendSpreadsheet()
     MWAW_DEBUG_MSG(("BeagleWksSSParser::sendSpreadsheet: I can not find the listener\n"));
     return false;
   }
-  BeagleWksSSParserInternal::Spreadsheet &sheet = m_state->m_spreadsheet;
+  auto &sheet = m_state->m_spreadsheet;
   sheet.updateWidthCols();
-  size_t numCell = sheet.m_cells.size();
 
   int prevRow = -1;
-  listener->openSheet(sheet.convertInPoint(sheet.m_widthCols,76), librevenge::RVNG_POINT, m_state->m_spreadsheetName);
+  listener->openSheet(sheet.convertInPoint(sheet.m_widthCols,76), librevenge::RVNG_POINT, std::vector<int>(), m_state->m_spreadsheetName);
   sendPageFrames();
   // send the chart
-  for (size_t i = 0; i < m_state->m_chartList.size(); ++i) {
-    if (!m_state->m_chartList[i]) continue;
-    BeagleWksSSParserInternal::Chart &chart=*(m_state->m_chartList[i]);
+  int n=0;
+  for (auto &chart : m_state->m_chartList) {
+    if (!chart) continue;
     // chart have no position, so we create one
-    chart.setDimension(MWAWVec2i(200,200));
+    chart->setDimension(MWAWVec2f(200,200));
     MWAWPosition fPos(MWAWVec2f(0,0), MWAWVec2f(200,200), librevenge::RVNG_POINT);
-    fPos.setPagePos(1, MWAWVec2f(float(i)*200,200));
+    fPos.setPagePos(1, MWAWVec2f(float(n++)*200,200));
     fPos.setRelativePosition(MWAWPosition::Page);
-    listener->insertChart(fPos, chart);
+    listener->insertChart(fPos, *chart);
   }
-  std::vector<float> rowHeight = sheet.convertInPoint(sheet.m_heightRows,16);
-  for (size_t i = 0; i < numCell; i++) {
-    BeagleWksSSParserInternal::Cell const &cell= sheet.m_cells[i];
-    // FIXME: openSheetRow/openSheetCell must do that
-    if (cell.position()[1] != prevRow) {
-      while (cell.position()[1] > prevRow) {
-        if (prevRow != -1)
-          listener->closeSheetRow();
-        prevRow++;
-        if (prevRow < int(rowHeight.size()))
-          listener->openSheetRow(rowHeight[size_t(prevRow)], librevenge::RVNG_POINT);
-        else
-          listener->openSheetRow(16, librevenge::RVNG_POINT);
+  for (auto const &cell : sheet.m_cells) {
+    if (cell.position()[1]>prevRow+1) {
+      while (cell.position()[1] > prevRow+1) {
+        if (prevRow != -1) listener->closeSheetRow();
+        int numRepeat;
+        double h=sheet.getRowHeight(prevRow+1, numRepeat);
+        if (cell.position()[1]<prevRow+1+numRepeat)
+          numRepeat=cell.position()[1]-1-prevRow;
+        listener->openSheetRow(float(h), librevenge::RVNG_POINT, numRepeat);
+        prevRow+=numRepeat;
       }
     }
+    if (cell.position()[1] > prevRow) {
+      if (prevRow != -1) listener->closeSheetRow();
+      listener->openSheetRow(float(sheet.getRowHeight(++prevRow)), librevenge::RVNG_POINT);
+    }
     listener->openSheetCell(cell, cell.m_content);
     if (cell.m_content.m_textEntry.valid()) {
       listener->setFont(cell.isFontSet() ? cell.getFont() : MWAWFont());
       input->seek(cell.m_content.m_textEntry.begin(), librevenge::RVNG_SEEK_SET);
       while (!input->isEnd() && input->tell()<cell.m_content.m_textEntry.end()) {
-        unsigned char c=(unsigned char) input->readULong(1);
+        auto c=static_cast<unsigned char>(input->readULong(1));
         if (c==0xd)
           listener->insertEOL();
         else
@@ -1533,7 +1575,7 @@ bool BeagleWksSSParser::checkHeader(MWAWHeader *header, bool strict)
     return false;
   }
   for (int i=0; i < 9; ++i) { // f2=f6=1 other 0
-    int val=(int) input->readLong(2);
+    auto val=static_cast<int>(input->readLong(2));
     if (val) f << "f" << i << "=" << val << ",";
   }
   setVersion(1);
@@ -1560,7 +1602,7 @@ bool BeagleWksSSParser::checkHeader(MWAWHeader *header, bool strict)
   MWAWEntry entry;
   entry.setBegin(input->readLong(4));
   entry.setLength(input->readLong(4));
-  entry.setId((int) input->readLong(2)); // in fact nFonts
+  entry.setId(static_cast<int>(input->readLong(2))); // in fact nFonts
   entry.setType("FontNames");
   f << "fontNames[ptr]=" << std::hex << entry.begin() << "<->" << entry.end()
     << std::dec << ",nFonts=" << entry.id() << ",";
