@@ -54,6 +54,7 @@
 #include "ClarisDrawStyleManager.hxx"
 #include "ClarisDrawGraph.hxx"
 #include "ClarisDrawText.hxx"
+#include "ClarisWksStruct.hxx"
 
 #include "ClarisDrawParser.hxx"
 
@@ -63,7 +64,10 @@ namespace ClarisDrawParserInternal
 // generic class used to defined a layer
 struct Layer {
   //! constructor
-  Layer() : m_groupId(0), m_isHidden(false), m_name("")
+  Layer()
+    : m_groupId(0)
+    , m_isHidden(false)
+    , m_name("")
   {
   }
   //! the first group id
@@ -78,9 +82,22 @@ struct Layer {
 //! Internal: the state of a ClarisDrawParser
 struct State {
   //! constructor
-  State() : m_version(0), m_isLibrary(false), m_numDSET(0), m_EOF(-1),
-    m_actualLayer(1), m_numLayers(1),  m_createMasterPage(false), m_displayAsSlide(false), m_layerList(),
-    m_pageSpanSet(false), m_headerId(0), m_footerId(0), m_pages(1,1), m_zonesMap(), m_zoneIdToFileTypeMap()
+  State()
+    : m_version(0)
+    , m_isLibrary(false)
+    , m_numDSET(0)
+    , m_EOF(-1)
+    , m_actualLayer(1)
+    , m_numLayers(1)
+    , m_createMasterPage(false)
+    , m_displayAsSlide(false)
+    , m_layerList()
+    , m_pageSpanSet(false)
+    , m_headerId(0)
+    , m_footerId(0)
+    , m_pages(1,1)
+    , m_zonesMap()
+    , m_zoneIdToFileTypeMap()
   {
   }
   //! the file version
@@ -110,7 +127,7 @@ struct State {
   //! the number of pages
   MWAWVec2i m_pages;
   /** the map of zone*/
-  std::map<int, shared_ptr<ClarisWksStruct::DSET> > m_zonesMap;
+  std::map<int, std::shared_ptr<ClarisWksStruct::DSET> > m_zonesMap;
   /** map zone id to file type */
   std::map<int, int> m_zoneIdToFileTypeMap;
 };
@@ -119,8 +136,12 @@ struct State {
 ////////////////////////////////////////////////////////////
 // constructor/destructor, ...
 ////////////////////////////////////////////////////////////
-ClarisDrawParser::ClarisDrawParser(MWAWInputStreamPtr input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header) :
-  MWAWGraphicParser(input, rsrcParser, header), m_state(), m_styleManager(), m_graphParser(), m_textParser()
+ClarisDrawParser::ClarisDrawParser(MWAWInputStreamPtr const &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header)
+  : MWAWGraphicParser(input, rsrcParser, header)
+  , m_state()
+  , m_styleManager()
+  , m_graphParser()
+  , m_textParser()
 {
   init();
 }
@@ -167,13 +188,13 @@ MWAWVec2f ClarisDrawParser::getPageLeftTop()
 ////////////////////////////////////////////////////////////
 void ClarisDrawParser::parse(librevenge::RVNGDrawingInterface *docInterface)
 {
-  if (!getInput().get() || !checkHeader(0L))  throw(libmwaw::ParseException());
+  if (!getInput().get() || !checkHeader(nullptr))  throw(libmwaw::ParseException());
   bool ok = false;
   try {
     // create the asciiFile
     ascii().setStream(getInput());
     ascii().open(asciiName());
-    checkHeader(0L);
+    checkHeader(nullptr);
     ok = createZones();
     if (ok) {
       createDocument(docInterface);
@@ -183,10 +204,10 @@ void ClarisDrawParser::parse(librevenge::RVNGDrawingInterface *docInterface)
       MWAWGraphicListenerPtr listener=getGraphicListener();
 
       if (m_state->m_isLibrary) {
-        for (int i=0; i<(int) m_state->m_layerList.size(); ++i) {
+        for (size_t i=0; i<m_state->m_layerList.size(); ++i) {
           if (i>0)
             listener->insertBreak(MWAWListener::PageBreak);
-          m_graphParser->sendMainGroupChild(i, pos);
+          m_graphParser->sendMainGroupChild(int(i), pos);
         }
       }
       else if (m_state->m_displayAsSlide) {
@@ -247,27 +268,27 @@ void ClarisDrawParser::createDocument(librevenge::RVNGDrawingInterface *document
   ps.setPageSpan(1);
   std::vector<librevenge::RVNGString> listNames;
   if (m_state->m_isLibrary) {
-    numPages=(int) m_state->m_layerList.size();
+    numPages=static_cast<int>(m_state->m_layerList.size());
     if (numPages<1) numPages=1;
   }
   else {
     m_state->m_createMasterPage=!m_state->m_layerList.empty() &&
                                 !m_graphParser->isEmptyGroup(m_state->m_layerList[0].m_groupId);
     if (m_state->m_createMasterPage)
-      ps.setMasterPageName("Master");
+      ps.setMasterPageName(librevenge::RVNGString("Master"));
     for (size_t i=1; i<m_state->m_layerList.size(); ++i) {
       if (!m_graphParser->isEmptyGroup(m_state->m_layerList[i].m_groupId))
         listNames.push_back(m_state->m_layerList[i].m_name);
     }
     if (m_state->m_displayAsSlide && !listNames.empty())
-      numPages=(int) listNames.size();
+      numPages=static_cast<int>(listNames.size());
   }
   std::vector<MWAWPageSpan> pageList;
   for (int i=0; i<numPages; ++i) {
     MWAWPageSpan page(ps);
-    if (m_state->m_isLibrary && i<(int) m_state->m_layerList.size())
+    if (m_state->m_isLibrary && i<static_cast<int>(m_state->m_layerList.size()))
       page.setPageName(m_state->m_layerList[size_t(i)].m_name);
-    else if (m_state->m_displayAsSlide && i<(int) listNames.size())
+    else if (m_state->m_displayAsSlide && i<static_cast<int>(listNames.size()))
       page.setPageName(listNames[size_t(i)]);
     pageList.push_back(page);
   }
@@ -342,33 +363,33 @@ bool ClarisDrawParser::readZone()
   long pos=input->tell();
   if (!input->checkPosition(pos+4))
     return false;
-  long fSz=(long) input->readULong(4);
+  auto zoneSz=long(input->readULong(4));
   std::string what("Unknown");
-  if (fSz==0x44534554) {
+  if (zoneSz==0x44534554) {
     input->seek(pos, librevenge::RVNG_SEEK_SET);
-    return readDSET().get()!=0;
+    return readDSET().get()!=nullptr;
   }
-  else if (fSz==0x464e544d) {
+  else if (zoneSz==0x464e544d) {
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     return m_styleManager->readFontNames();
   }
-  else if ((fSz>>16)>16) {
+  else if ((zoneSz>>16)>16) {
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     return false;
   }
-  else if ((fSz>>16)!=0) {
+  else if ((zoneSz>>16)!=0) {
     ascii().addPos(pos);
     ascii().addNote("Entries(Short)");
     input->seek(pos+2, librevenge::RVNG_SEEK_SET);
     return true;
   }
-  long endPos=input->tell()+fSz;
-  if (fSz<0 || ((fSz&1) && (fSz==0x4453 || fSz==0x464e)) || !input->checkPosition(endPos)) {
+  long endPos=input->tell()+zoneSz;
+  if (zoneSz<0 || ((zoneSz&1) && (zoneSz==0x4453 || zoneSz==0x464e)) || !input->checkPosition(endPos)) {
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     return false;
   }
   libmwaw::DebugStream f;
-  if (fSz==0)
+  if (zoneSz==0)
     f << "_";
   else
     f << "Entries(" << what << ")";
@@ -386,24 +407,23 @@ bool ClarisDrawParser::readDocHeader()
   input->seek(8, librevenge::RVNG_SEEK_SET);
   libmwaw::DebugStream f;
   f << "Entries(DocHeader):";
-  int val = (int) input->readLong(2); // always find 1
+  auto val = static_cast<int>(input->readLong(2)); // always find 1
   if (val != 1)
     f << "#unkn=" << std::hex << val << std::dec << ",";
   for (int i = 0; i < 4; i++) {
-    val = (int) input->readULong(2);
+    val = static_cast<int>(input->readULong(2));
     if (val)
       f << std::hex << "f" << i << "="  << std::hex << val << std::dec << ",";
   }
   int dim[2];
-  for (int i = 0; i < 2; i++)
-    dim[i] = (int) input->readLong(2);
+  for (int &i : dim) i= static_cast<int>(input->readLong(2));
   f << "dim?=" << dim[1] << "x" << dim[0] << ",";
   int margin[6];
   f << "margin?=[";
-  for (int i = 0; i < 6; i++) {
-    margin[i] = (int) input->readLong(2);
-    if (margin[i])
-      f << margin[i] << ",";
+  for (int &i : margin) {
+    i = static_cast<int>(input->readLong(2));
+    if (i)
+      f << i << ",";
     else
       f << "_,";
   }
@@ -426,21 +446,20 @@ bool ClarisDrawParser::readDocHeader()
     m_state->m_pageSpanSet = true;
   }
   int dim2[2];
-  for (int i = 0; i < 2; i++)
-    dim2[i] = (int) input->readLong(2);
+  for (int &i : dim2) i = static_cast<int>(input->readLong(2));
   f << "dim2?=" << dim2[1] << "x" << dim2[0] << ",";
   int fl[4];
   f << "fl?=[";
-  for (int i = 0; i < 4; i++) {
-    fl[i] = (int) input->readULong(1);
-    if (fl[i])
-      f << fl[i] << ",";
+  for (int &i : fl) {
+    i = static_cast<int>(input->readULong(1));
+    if (i)
+      f << i << ",";
     else
       f << "_,";
   }
   f << "],";
   for (int i = 0; i < 9; i++) {
-    val = (int) input->readLong(2);
+    val = static_cast<int>(input->readLong(2));
     if (val)
       f << "g" << i << "="  << val << ",";
   }
@@ -469,7 +488,7 @@ bool ClarisDrawParser::readDocHeader()
   f.str("");
   f << "DocHeader-1:";
   for (int i = 0; i < 6; i++) {
-    val = (int) input->readULong(2);
+    val = static_cast<int>(input->readULong(2));
     if (val) f << "f" << i << "=" << val << ",";
   }
   ascii().addDelimiter(input->tell(), '|');
@@ -485,50 +504,50 @@ bool ClarisDrawParser::readDocHeader()
   f.str("");
   f << "DocHeader-2:";
   for (int i=0; i<5; ++i) {
-    val=(int) input->readULong(2);
-    static int const(expected[])= {0,1,2,2,0};
+    val=static_cast<int>(input->readULong(2));
+    static int const expected[] = {0,1,2,2,0};
     if (val!=expected[i])
       f << "f" << i << "=" << val << ",";
   }
   for (int i=0; i<8; ++i) {
-    val=(int) input->readULong(1);
-    static int const(expected[])= {1/*or 16*/,0,0,0,0,1,1, 0};
+    val=static_cast<int>(input->readULong(1));
+    static int const expected[] = {1/*or 16*/,0,0,0,0,1,1, 0};
     if (val!=expected[i])
       f << "f" << i+5 << "=" << val << ",";
   }
   for (int i=0; i<4; ++i) {
-    val=(int) input->readULong(2);
-    static int const(expected[])= {1,1,0x2d,0};
+    val=static_cast<int>(input->readULong(2));
+    static int const expected[] = {1,1,0x2d,0};
     if (val!=expected[i])
       f << "f" << i+13 << "=" << val << ",";
   }
   f << "fl=[";
   for (int i=0; i<13; ++i) {
-    val=(int) input->readULong(1);
+    val=static_cast<int>(input->readULong(1));
     if (val==1) f << "*,";
     else if (val) f << val << ",";
     else f << "_,";
   }
   f << "],";
   for (int i=0; i<16; ++i) { // always 0
-    val=(int) input->readULong(2);
+    val=static_cast<int>(input->readULong(2));
     if (val)
       f << "g" << i << "=" << val << ",";
   }
   for (int i=0; i<5; ++i) {
-    val=(int) input->readULong(2);
-    static int const(expected[])= {0,1,0,0x600,0x504};
+    val=static_cast<int>(input->readULong(2));
+    static int const expected[] = {0,1,0,0x600,0x504};
     if (val!=expected[i])
       f << "h" << i << "=" << std::hex << val << std::dec << ",";
   }
-  val=(int) input->readULong(1); // always 0
+  val=static_cast<int>(input->readULong(1)); // always 0
   if (val) f << "h5=" << val << ",";
   int num[3];
   for (int i=0; i<3; ++i) {
-    num[i]=(int) input->readULong(2);
+    num[i]=static_cast<int>(input->readULong(2));
     if (!num[i])
       continue;
-    static char const *(wh[])= {"color", "unkn1", "gradient"};
+    static char const *wh[]= {"color", "unkn1", "gradient"};
     f << "num[" << wh[i] << "]=" << num[i] << ",";
   }
   m_styleManager->setDefaultNumbers(num[0], num[2]);
@@ -541,7 +560,7 @@ bool ClarisDrawParser::readDocHeader()
   pos=input->tell();
   f.str("");
   f << "DocHeader(Col):";
-  int numCols = (int) input->readLong(2);
+  auto numCols = static_cast<int>(input->readLong(2));
   if (numCols < 1 || numCols > 9) {
     MWAW_DEBUG_MSG(("ClarisDrawParser::readDocHeader: pb reading number of columns\n"));
     f << "###numCols=" << numCols;
@@ -551,7 +570,7 @@ bool ClarisDrawParser::readDocHeader()
     f << "numCols=" << numCols << ",";
   f << "colsW=[";
   for (int i = 0; i < numCols; i++) {
-    val = (int) input->readULong(2);
+    val = static_cast<int>(input->readULong(2));
     f << val << ",";
   }
   f << "],";
@@ -559,14 +578,14 @@ bool ClarisDrawParser::readDocHeader()
   if (numCols > 1) {
     f << "colsS=[";
     for (int i = 0; i < numCols-1; i++) {
-      val = (int) input->readULong(2);
+      val = static_cast<int>(input->readULong(2));
       f << input->readULong(2);
       if (val) f << ":" << val << ",";
     }
     f << "],";
   }
   input->seek(pos+36, librevenge::RVNG_SEEK_SET);
-  val = (int) input->readLong(2);
+  val = static_cast<int>(input->readLong(2));
   if (val) f << "unkn=" << val << ",";
   ascii().addPos(pos);
   ascii().addNote(f.str().c_str());
@@ -600,7 +619,7 @@ bool ClarisDrawParser::readDocHeader()
   f.str("");
   f << "DocHeader-8:";
   input->seek(pos+111, librevenge::RVNG_SEEK_SET);
-  val=(int) input->readLong(1);
+  val=static_cast<int>(input->readLong(1));
   if (val==1) {
     f << "slide,";
     m_state->m_displayAsSlide=true;
@@ -628,13 +647,13 @@ bool ClarisDrawParser::readDocHeader()
     if (input->isEnd())
       return false;
     pos=input->tell();
-    long fSz=(long) input->readULong(4);
-    if (!fSz) {
+    auto zoneSz=long(input->readULong(4));
+    if (!zoneSz) {
       ascii().addPos(pos);
       ascii().addNote("_");
       continue;
     }
-    if (!input->checkPosition(pos+4+fSz)) {
+    if (!input->checkPosition(pos+4+zoneSz)) {
       MWAW_DEBUG_MSG(("ClarisDrawParser::readDocHeader: can not find zone %d\n", i+1));
       ascii().addPos(pos);
       ascii().addNote("###");
@@ -695,7 +714,7 @@ bool ClarisDrawParser::readDocHeader()
     f << "Entries(Zone" << i+1 << "A):";
     ascii().addPos(pos);
     ascii().addNote(f.str().c_str());
-    input->seek(pos+4+fSz, librevenge::RVNG_SEEK_SET);
+    input->seek(pos+4+zoneSz, librevenge::RVNG_SEEK_SET);
   }
 
   pos=input->tell();
@@ -725,13 +744,13 @@ bool ClarisDrawParser::readDocHeader()
     if (input->isEnd())
       return false;
     pos=input->tell();
-    long fSz=(long) input->readULong(4);
-    if (!fSz) {
+    auto zoneSz=long(input->readULong(4));
+    if (!zoneSz) {
       ascii().addPos(pos);
       ascii().addNote("_");
       continue;
     }
-    if (!input->checkPosition(pos+4+fSz)) {
+    if (!input->checkPosition(pos+4+zoneSz)) {
       MWAW_DEBUG_MSG(("ClarisDrawParser::readDocHeader: can not find zone %d\n", i+1));
       ascii().addPos(pos);
       ascii().addNote("###");
@@ -782,12 +801,12 @@ bool ClarisDrawParser::readDocHeader()
     f << "Entries(ZoneB" << i+1 << "A):";
     ascii().addPos(pos);
     ascii().addNote(f.str().c_str());
-    input->seek(pos+4+fSz, librevenge::RVNG_SEEK_SET);
+    input->seek(pos+4+zoneSz, librevenge::RVNG_SEEK_SET);
   }
   pos=input->tell();
   f.str("");
   f << "Entries(NDSET):";
-  m_state->m_numDSET=(int) input->readLong(2);
+  m_state->m_numDSET=static_cast<int>(input->readLong(2));
   if (m_state->m_numDSET) f << "num=" << m_state->m_numDSET << ",";
   ascii().addPos(pos);
   ascii().addNote(f.str().c_str());
@@ -811,7 +830,7 @@ bool ClarisDrawParser::readLibraryHeader()
     val=input->readLong(2);
     if (val) f << "f" << i+2 << "=" << val << ",";
   }
-  int N=(int) input->readLong(2); // checkme: the number of graphics ?
+  auto N=static_cast<int>(input->readLong(2)); // checkme: the number of graphics ?
   if (N) f << "N=" << N << ",";
   for (long i=0; i<2; ++i) { // always 0,1
     val=input->readLong(2);
@@ -843,7 +862,7 @@ bool ClarisDrawParser::readLibraryHeader()
   }
   f << "IDs=[";
   for (int i=0; i<9; ++i) { // 7 or 9 big number
-    val=(long) input->readULong(4);
+    val=long(input->readULong(4));
     if (val)
       f << std::hex << val << std::dec << ",";
     else
@@ -876,34 +895,34 @@ bool ClarisDrawParser::readLibraryHeader()
   pos=input->tell();
   f.str("");
   f << "LibHeader-B:";
-  int fSz=(int) input->readULong(1);
+  auto fSz=static_cast<int>(input->readULong(1));
   if (fSz>63) {
     MWAW_DEBUG_MSG(("ClarisDrawParser::readLibraryHeader: string size seems bad\n"));
     f << "##fSz=" << fSz << ",";
     fSz=0;
   }
   std::string text("");
-  for (int i=0; i<fSz; ++i) text+=(char) input->readULong(1);
+  for (int i=0; i<fSz; ++i) text+=char(input->readULong(1));
   f << "filename=" << text << ",";
   input->seek(pos+64, librevenge::RVNG_SEEK_SET);
   for (int i=0; i<96; ++i) { // always 0
     val=input->readLong(2);
     if (val) f << "f" << i << "=" << val << ",";
   }
-  val=(int) input->readULong(1); // always filename size ?
+  val=static_cast<int>(input->readULong(1)); // always filename size ?
   if (val!=fSz) f << "#fSz1=" << fSz << ",";
-  val=(int) input->readULong(1); // always 0?
+  val=static_cast<int>(input->readULong(1)); // always 0?
   if (val) f << "f96=" << val << ",";
   f << "ID=" << std::hex << input->readULong(4) << std::dec << ","; // big number
-  val=(int) input->readLong(2); // 0 | 0fcc
+  val=static_cast<int>(input->readLong(2)); // 0 | 0fcc
   if (val) f << "g0=" << val << ",";
-  val=(int) input->readULong(2); //  80[89]3
+  val=static_cast<int>(input->readULong(2)); //  80[89]3
   if (val) f << "fl=" << std::hex << val << std::dec << ",";
-  val=(int) input->readLong(2); // 0
+  val=static_cast<int>(input->readLong(2)); // 0
   if (val) f << "g1=" << val << ",";
-  val=(int) input->readULong(1); // always filename size ?
+  val=static_cast<int>(input->readULong(1)); // always filename size ?
   if (val!=fSz) f << "#fSz2=" << fSz << ",";
-  val=(int) input->readULong(1); // always 0?
+  val=static_cast<int>(input->readULong(1)); // always 0?
   if (val) f << "g2=" << val << ",";
   ascii().addPos(pos);
   ascii().addNote(f.str().c_str());
@@ -911,14 +930,14 @@ bool ClarisDrawParser::readLibraryHeader()
   pos=input->tell();
   f.str("");
   f << "LibHeader-C:";
-  fSz=(int) input->readULong(1);
+  fSz=static_cast<int>(input->readULong(1));
   if (fSz>63) {
     MWAW_DEBUG_MSG(("ClarisDrawParser::readLibraryHeader: string size seems bad\n"));
     f << "##fSz=" << fSz << ",";
     fSz=0;
   }
   text="";
-  for (int i=0; i<fSz; ++i) text+=(char) input->readULong(1);
+  for (int i=0; i<fSz; ++i) text+=char(input->readULong(1));
   f << "author?=" << text << ",";
   input->seek(pos+64, librevenge::RVNG_SEEK_SET);
   for (int i=0; i<96; ++i) { // always 0
@@ -932,7 +951,7 @@ bool ClarisDrawParser::readLibraryHeader()
   f.str("");
   f << "LibHeader-D:";
   for (int i=0; i<16; ++i) {
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     static int const expected[]= {4,2,0/*35 or 3f*/,48, 9, 0/*78 or 8x*/, 0x42, 18,
                                   3, 0xd4, 0/*7b or 8e*/, 0x57, 3, 0xc4, 0/*7b or 8f*/, 0
                                  };
@@ -940,9 +959,9 @@ bool ClarisDrawParser::readLibraryHeader()
       f << "f" << i << "=" << val << ",";
   }
   int dim[2];
-  for (int i=0; i<2; ++i) dim[i]=(int) input->readLong(2);
+  for (auto &i : dim) i=static_cast<int>(input->readLong(2));
   f << "dim=" << MWAWVec2i(dim[0],dim[1]) << ","; // 64x64 or 72x72
-  m_state->m_numDSET=(int) input->readLong(2);
+  m_state->m_numDSET=static_cast<int>(input->readLong(2));
   if (m_state->m_numDSET) f << "num[DSET]=" << m_state->m_numDSET << ",";
   ascii().addPos(pos);
   ascii().addNote(f.str().c_str());
@@ -952,7 +971,7 @@ bool ClarisDrawParser::readLibraryHeader()
   input->seek(-44, librevenge::RVNG_SEEK_END);
   while (input->tell()>=846) {
     pos=input->tell();
-    int c=(int) input->readULong(1);
+    auto c=static_cast<int>(input->readULong(1));
     bool find=false;
     switch (c) {
     case 0x44:
@@ -1002,7 +1021,7 @@ bool ClarisDrawParser::readLibraryHeader()
     }
     for (int i=0; ok && i<20; ++i) {
       pos=input->tell();
-      long dSz=(long) input->readULong(4);
+      auto dSz=long(input->readULong(4));
       if (!dSz) {
         ascii().addPos(pos);
         ascii().addNote("_");
@@ -1083,7 +1102,7 @@ bool ClarisDrawParser::checkHeader(MWAWHeader *header, bool /*strict*/)
   libmwaw::DebugStream f;
   f << "FileHeader:";
   input->seek(0, librevenge::RVNG_SEEK_SET);
-  int val=(int) input->readULong(1);
+  auto val=static_cast<int>(input->readULong(1));
   if (val==0x2) {
     m_state->m_isLibrary=true;
     f << "lib,";
@@ -1094,7 +1113,7 @@ bool ClarisDrawParser::checkHeader(MWAWHeader *header, bool /*strict*/)
   }
   else
     return false;
-  val=(int) input->readULong(2); // a3-b1
+  val=static_cast<int>(input->readULong(2)); // a3-b1
   if (val) f << "f0=" << std::hex << val << std::dec << ",";
   if (input->readULong(1) || input->readULong(4) != 0x45585057) return false;
   int vers=1;
@@ -1116,74 +1135,55 @@ bool ClarisDrawParser::readLayouts()
 {
   MWAWInputStreamPtr input = getInput();
   long pos=input->tell();
-  if (!input->checkPosition(pos+8)) return false;
   libmwaw::DebugFile &ascFile = ascii();
   libmwaw::DebugStream f;
   f << "Entries(Layout):";
-  long sz = (long) input->readULong(4);
-  if (sz==0) {
-    ascFile.addPos(pos);
-    ascFile.addNote("_");
-    return true;
-  }
-  long endPos=pos+4+sz;
-  if (!input->checkPosition(endPos)) {
+  ClarisWksStruct::Struct header;
+  if (!header.readHeader(input,true)) {
     MWAW_DEBUG_MSG(("ClarisDrawParser::readLayouts: the data size seems bad\n"));
     f << "###";
     ascFile.addPos(pos);
     ascFile.addNote(f.str().c_str());
     return false;
   }
-
-  int N = (int) input->readLong(2);
-  f << "N=" << N << ",";
-  int type = (int) input->readLong(2);
-  if (type != -1)
-    f << "#type=" << type << ",";
-  int val = (int) input->readLong(2);
-  if (val) f << "#unkn=" << val << ",";
-  int fSz = (int) input->readULong(2);
-  int hSz = (int) input->readULong(2);
-  if (!fSz || N*fSz+hSz+12 != sz) {
-    input->seek(pos, librevenge::RVNG_SEEK_SET);
-    MWAW_DEBUG_MSG(("ClarisDrawParser::readLayouts: unexpected field/header size\n"));
-    f << "###";
+  if (header.m_size==0) {
     ascFile.addPos(pos);
-    ascFile.addNote(f.str().c_str());
-    return false;
+    ascFile.addNote("_");
+    return true;
   }
-
-  if (long(input->tell()) != pos+4+12+hSz) {
-    ascFile.addDelimiter(input->tell(), '|');
-    input->seek(pos+4+12+hSz, librevenge::RVNG_SEEK_SET);
+  long endPos = pos+4+header.m_size;
+  f << header;
+  if (header.m_headerSize) {
+    ascFile.addDelimiter(input->tell(),'|');
+    input->seek(header.m_headerSize, librevenge::RVNG_SEEK_CUR);
   }
   ascFile.addPos(pos);
   ascFile.addNote(f.str().c_str());
 
   pos=input->tell();
-  if (fSz!=336) {
+  if (header.m_dataSize!=336) {
     input->seek(endPos, librevenge::RVNG_SEEK_SET);
     MWAW_DEBUG_MSG(("ClarisDrawParser::readLayouts: no sure how to read the data\n"));
     ascFile.addPos(pos);
     ascFile.addNote("Layout:###");
     return true;
   }
-  for (int i=0; i<N; ++i) {
+  for (long i=0; i<header.m_numData; ++i) {
     pos=input->tell();
     ClarisDrawParserInternal::Layer layer;
     f.str("");
     f << "Layout-A" << i << ":";
-    int cSz=(int) input->readULong(1);
+    auto cSz=static_cast<int>(input->readULong(1));
     librevenge::RVNGString name("");
     for (int c=0; c<cSz; ++c) {
-      char ch=(char) input->readULong(1);
+      auto ch=char(input->readULong(1));
       if (!ch) continue;
       f << ch;
-      int unicode= getParserState()->m_fontConverter->unicode(3, (unsigned char) ch);
+      int unicode= getParserState()->m_fontConverter->unicode(3, static_cast<unsigned char>(ch));
       if (unicode==-1)
         name.append(ch);
       else
-        libmwaw::appendUnicode((uint32_t) unicode, name);
+        libmwaw::appendUnicode(static_cast<uint32_t>(unicode), name);
     }
     f << ",";
     layer.m_name=name;
@@ -1194,31 +1194,31 @@ bool ClarisDrawParser::readLayouts()
     pos=input->tell();
     f.str("");
     f << "Layout-B" << i << ":";
-    val=(int) input->readULong(1); // always 40|80
+    auto val=static_cast<int>(input->readULong(1)); // always 40|80
     if (val&0x80) {
       f << "hidden,";
       layer.m_isHidden=true;
     }
     val &=0x7F;
     if (val!=0x40) f << "fl0=" << std::hex << val << std::dec << ",";
-    val=(int) input->readULong(1); // 0|1|2|6c|d8|fc|ff
+    val=static_cast<int>(input->readULong(1)); // 0|1|2|6c|d8|fc|ff
     if (val) f << "fl1=" << std::hex << val << std::dec << ",";
     for (int j=0; j<2; ++j) { // always 0
-      val=(int) input->readULong(2);
+      val=static_cast<int>(input->readULong(2));
       if (val) f << "f" << j << "=" << val << ",";
     }
-    layer.m_groupId=(int) input->readULong(2);
+    layer.m_groupId=static_cast<int>(input->readULong(2));
     f << "id[group]=" << layer.m_groupId << ",";
-    val=(int) input->readLong(4);
+    val=static_cast<int>(input->readLong(4));
     if (val==-1)
       f << "locked,";
     else if (val)
       f << "#lock=" << val << ",";
     for (int j=0; j<16; ++j) { // always 0
-      val=(int) input->readULong(4);
+      val=static_cast<int>(input->readULong(4));
       if (val) f << "g" << j << "=" << val << ",";
     }
-    val=(int) input->readULong(4);
+    val=static_cast<int>(input->readULong(4));
     if (val) f << "ID=" << std::hex << val << std::dec << ",";
     ascFile.addPos(pos);
     ascFile.addNote(f.str().c_str());
@@ -1236,12 +1236,19 @@ bool ClarisDrawParser::readLibraryNames()
   libmwaw::DebugFile &ascFile = ascii();
   libmwaw::DebugStream f;
   f << "Entries(LibraryName):";
-  long sz = (long) input->readULong(4);
-  if (sz==0) {
+  ClarisWksStruct::Struct header;
+  if (!header.readHeader(input,true)) {
+    MWAW_DEBUG_MSG(("ClarisDrawParser::readLibraryNames: the data size seems bad\n"));
+    f << "###";
+    ascFile.addPos(pos);
+    ascFile.addNote(f.str().c_str());
+    return false;
+  }
+  if (header.m_size==0) {
     ascFile.addPos(pos);
     ascFile.addNote("_");
     pos=input->tell();
-    sz = (long) input->readULong(4);
+    auto sz = long(input->readULong(4));
     if (!input->checkPosition(pos+4+sz)) {
       MWAW_DEBUG_MSG(("ClarisDrawParser::readLibraryNames: the name size seems bad\n"));
       f << "###";
@@ -1262,42 +1269,17 @@ bool ClarisDrawParser::readLibraryNames()
     return true;
   }
 
-  long endPos=pos+4+sz;
-  if (!input->checkPosition(endPos)) {
-    MWAW_DEBUG_MSG(("ClarisDrawParser::readLibraryNames: the data size seems bad\n"));
-    f << "###";
-    ascFile.addPos(pos);
-    ascFile.addNote(f.str().c_str());
-    return false;
-  }
-
-  int N = (int) input->readLong(2);
-  f << "N=" << N << ",";
-  int type = (int) input->readLong(2);
-  if (type != -1)
-    f << "#type=" << type << ",";
-  int val = (int) input->readLong(2);
-  if (val) f << "#unkn=" << val << ",";
-  int fSz = (int) input->readULong(2);
-  int hSz = (int) input->readULong(2);
-  if (!fSz || N*fSz+hSz+12 != sz) {
-    input->seek(pos, librevenge::RVNG_SEEK_SET);
-    MWAW_DEBUG_MSG(("ClarisDrawParser::readLibraryNames: unexpected field/header size\n"));
-    f << "###";
-    ascFile.addPos(pos);
-    ascFile.addNote(f.str().c_str());
-    return false;
-  }
-
-  if (long(input->tell()) != pos+4+12+hSz) {
-    ascFile.addDelimiter(input->tell(), '|');
-    input->seek(pos+4+12+hSz, librevenge::RVNG_SEEK_SET);
+  long endPos=pos+4+header.m_size;
+  f << header;
+  if (header.m_headerSize) {
+    ascFile.addDelimiter(input->tell(),'|');
+    input->seek(header.m_headerSize, librevenge::RVNG_SEEK_CUR);
   }
   ascFile.addPos(pos);
   ascFile.addNote(f.str().c_str());
 
   pos=input->tell();
-  if (fSz!=4) {
+  if (header.m_dataSize!=4) {
     input->seek(endPos, librevenge::RVNG_SEEK_SET);
     MWAW_DEBUG_MSG(("ClarisDrawParser::readLibraryNames: no sure how to read the position\n"));
     ascFile.addPos(pos);
@@ -1309,9 +1291,9 @@ bool ClarisDrawParser::readLibraryNames()
   f.str("");
   f << "LibraryName-pos:";
   std::vector<int> positions, lengths;
-  for (int i=0; i<N; ++i) {
-    int sSz=(int) input->readULong(2);
-    int position=(int) input->readULong(2);
+  for (long i=0; i<header.m_numData; ++i) {
+    auto sSz=static_cast<int>(input->readULong(2));
+    auto position=static_cast<int>(input->readULong(2));
     f << position << ":" << sSz << ",";
     positions.push_back(position);
     lengths.push_back(sSz);
@@ -1322,7 +1304,7 @@ bool ClarisDrawParser::readLibraryNames()
   pos=input->tell();
   f.str("");
   f << "LibraryName-name:";
-  sz = (long) input->readULong(4);
+  auto sz = long(input->readULong(4));
   if (sz==0 || !input->checkPosition(pos+4+sz)) {
     MWAW_DEBUG_MSG(("ClarisDrawParser::readLibraryNames: can not find the name\n"));
     f << "###";
@@ -1342,14 +1324,14 @@ bool ClarisDrawParser::readLibraryNames()
     input->seek(pos+4+positions[i], librevenge::RVNG_SEEK_SET);
     librevenge::RVNGString name("");
     for (int c=0; c<lengths[i]; ++c) {
-      char ch=(char) input->readULong(1);
+      auto ch=char(input->readULong(1));
       if (!ch) continue;
       f << ch;
-      int unicode= getParserState()->m_fontConverter->unicode(3, (unsigned char) ch);
+      int unicode= getParserState()->m_fontConverter->unicode(3, static_cast<unsigned char>(ch));
       if (unicode==-1)
         name.append(ch);
       else
-        libmwaw::appendUnicode((uint32_t) unicode, name);
+        libmwaw::appendUnicode(static_cast<uint32_t>(unicode), name);
     }
     f << ",";
     layer.m_name = name;
@@ -1374,22 +1356,21 @@ bool ClarisDrawParser::readDocInfo()
   f << "ptr=" << std::hex << input->readULong(4) << std::dec << ",";
   int val;
   for (int i = 0; i < 6; i++) {
-    val = (int) input->readULong(2);
+    val = static_cast<int>(input->readULong(2));
     if (val) f << "f" << i << "=" << std::hex << val << std::dec << ",";
   }
-  m_state->m_headerId = (int) input->readLong(2);
+  m_state->m_headerId = static_cast<int>(input->readLong(2));
   if (m_state->m_headerId) f << "headerId=" << m_state->m_headerId << ",";
-  val = (int) input->readLong(2);
+  val = static_cast<int>(input->readLong(2));
   if (val) f << "unkn=" << val << ",";
-  m_state->m_footerId = (int) input->readLong(2);
+  m_state->m_footerId = static_cast<int>(input->readLong(2));
   if (m_state->m_footerId) f << "footerId=" << m_state->m_footerId << ",";
   for (int i=0; i < 4; ++i) {
-    val = (int) input->readLong(2);
+    val = static_cast<int>(input->readLong(2));
     if (val) f << "g" << i << "=" << val << ",";
   }
   int pages[2];
-  for (int i=0; i < 2; ++i)
-    pages[i]=(int) input->readLong(2);
+  for (auto &page : pages) page=static_cast<int>(input->readLong(2));
   if (pages[1]>=1 && pages[1] < 1000 && pages[0]>=1 && pages[0]<100)
     m_state->m_pages=MWAWVec2i(pages[0],pages[1]);
   if (pages[0]!=1 || pages[1]!=1)
@@ -1469,15 +1450,15 @@ bool ClarisDrawParser::readPrintInfo()
 ////////////////////////////////////////////////////////////
 // read the document main part
 ////////////////////////////////////////////////////////////
-shared_ptr<ClarisWksStruct::DSET> ClarisDrawParser::readDSET(bool isLibHeader)
+std::shared_ptr<ClarisWksStruct::DSET> ClarisDrawParser::readDSET(bool isLibHeader)
 {
   MWAWInputStreamPtr input = getInput();
   long pos = input->tell();
   libmwaw::DebugStream f;
   libmwaw::DebugFile &ascFile=ascii();
   if (input->readULong(4) != 0x44534554L)
-    return shared_ptr<ClarisWksStruct::DSET>();
-  long sz = (long) input->readULong(4);
+    return std::shared_ptr<ClarisWksStruct::DSET>();
+  auto sz = long(input->readULong(4));
   MWAWEntry entry;
   entry.setBegin(pos);
   entry.setLength(sz+8);
@@ -1485,37 +1466,37 @@ shared_ptr<ClarisWksStruct::DSET> ClarisDrawParser::readDSET(bool isLibHeader)
   long endPos = entry.end();
   if (sz<16 || !input->checkPosition(entry.end())) {
     MWAW_DEBUG_MSG(("ClarisDrawParser::readDSET: file is too short\n"));
-    return shared_ptr<ClarisWksStruct::DSET>();
+    return std::shared_ptr<ClarisWksStruct::DSET>();
   }
 
   ClarisWksStruct::DSET dset;
   dset.m_size = sz;
-  dset.m_numData = (int) input->readULong(2);
+  dset.m_numData = static_cast<int>(input->readULong(2));
 
   input->seek(10, librevenge::RVNG_SEEK_CUR);
-  dset.m_fileType = (int) input->readULong(1);
+  dset.m_fileType = static_cast<int>(input->readULong(1));
   input->seek(-11, librevenge::RVNG_SEEK_CUR);
   int nFlags = 0;
   switch (dset.m_fileType) {
   case 1: // text
-    dset.m_beginSelection = (int) input->readLong(4);
-    dset.m_endSelection = (int) input->readLong(4);
-    dset.m_textType = (int) input->readULong(1);
-    dset.m_flags[nFlags++] = (int) input->readLong(1);
+    dset.m_beginSelection = static_cast<int>(input->readLong(4));
+    dset.m_endSelection = static_cast<int>(input->readLong(4));
+    dset.m_textType = static_cast<int>(input->readULong(1));
+    dset.m_flags[nFlags++] = static_cast<int>(input->readLong(1));
     dset.m_headerSz = 44;
     dset.m_dataSz = 28;
     break;
   default:
-    dset.m_flags[nFlags++] = (int) input->readLong(2); // normally -1
-    dset.m_flags[nFlags++] = (int) input->readLong(2); // the 0
-    dset.m_dataSz = (int) input->readULong(2);
-    dset.m_headerSz = (int) input->readULong(2);
-    dset.m_flags[nFlags++] = (int) input->readLong(2);
+    dset.m_flags[nFlags++] = static_cast<int>(input->readLong(2)); // normally -1
+    dset.m_flags[nFlags++] = static_cast<int>(input->readLong(2)); // the 0
+    dset.m_dataSz = static_cast<int>(input->readULong(2));
+    dset.m_headerSz = static_cast<int>(input->readULong(2));
+    dset.m_flags[nFlags++] = static_cast<int>(input->readLong(2));
     break;
   }
-  dset.m_flags[nFlags++] = (int) input->readLong(2);
-  dset.m_id = (int) input->readULong(2) ;
-  shared_ptr<ClarisWksStruct::DSET> zone;
+  dset.m_flags[nFlags++] = static_cast<int>(input->readLong(2));
+  dset.m_id = static_cast<int>(input->readULong(2));
+  std::shared_ptr<ClarisWksStruct::DSET> zone;
   switch (dset.m_fileType)  {
   case 0:
     zone=m_graphParser->readGroupZone(dset, entry, isLibHeader);
@@ -1534,14 +1515,15 @@ shared_ptr<ClarisWksStruct::DSET> ClarisDrawParser::readDSET(bool isLibHeader)
     zone.reset(new ClarisWksStruct::DSET(dset));
     f << "Entries(DSETU): " << *zone;
 
-    int data0Length = (int) zone->m_dataSz;
-    int N = (int) zone->m_numData;
+    auto data0Length = static_cast<int>(zone->m_dataSz);
+    auto N = static_cast<int>(zone->m_numData);
 
     ascFile.addDelimiter(input->tell(), '|');
     ascFile.addPos(pos);
     ascFile.addNote(f.str().c_str());
 
-    if (sz-12 != data0Length*N + zone->m_headerSz) {
+    const long dataSz = sz-12-zone->m_headerSz;
+    if ((dataSz && (data0Length<=0 || (dataSz/data0Length)!=N || (dataSz%data0Length)!=0)) || (!dataSz && N)) {
       MWAW_DEBUG_MSG(("ClarisDrawParser::readDSET: unexpected size for zone definition, try to continue\n"));
       ascFile.addPos(pos);
       ascFile.addNote("###");
