@@ -62,7 +62,10 @@ enum PLCType { P_Font,  P_Ruler, P_Child, P_TextZone, P_Token, P_Unknown};
 /** Internal : the different plc types: mainly for debugging */
 struct PLC {
   /// the constructor
-  PLC() : m_type(P_Unknown), m_id(-1), m_extra("")
+  PLC()
+    : m_type(P_Unknown)
+    , m_id(-1)
+    , m_extra("")
   {
   }
   //! operator<<
@@ -107,18 +110,20 @@ std::ostream &operator<<(std::ostream &o, PLC const &plc)
 }
 
 /** Internal: class to store the paragraph properties */
-struct Paragraph : public MWAWParagraph {
+struct Paragraph final : public MWAWParagraph {
   //! Constructor
-  Paragraph() : MWAWParagraph(), m_labelType(0)
+  Paragraph()
+    : MWAWParagraph()
+    , m_labelType(0)
   {
   }
   //! destructor
-  virtual ~Paragraph();
+  ~Paragraph() final;
   //! operator<<
   friend std::ostream &operator<<(std::ostream &o, Paragraph const &ind)
   {
     o << static_cast<MWAWParagraph const &>(ind) << ",";
-    static char const *(labelNames[]) = {
+    static char const *labelNames[] = {
       "none", "diamond", "bullet", "checkbox", "hardvard", "leader", "legal",
       "upperalpha", "alpha", "numeric", "upperroman", "roman"
     };
@@ -220,7 +225,10 @@ void Paragraph::updateListLevel()
 //! paragraph plc
 struct ParagraphPLC {
   //! constructor
-  ParagraphPLC() : m_rulerId(-1), m_flags(0), m_extra("")
+  ParagraphPLC()
+    : m_rulerId(-1)
+    , m_flags(0)
+    , m_extra("")
   {
   }
   //! return the label type
@@ -247,18 +255,18 @@ struct ParagraphPLC {
     }
     if (info.m_flags&4)
       o << "flags4,";
-    static char const *(labelNames[]) = {
+    static char const *labelNames[] = {
       "none", "diamond", "bullet", "checkbox", "hardvard", "leader", "legal",
       "upperalpha", "alpha", "numeric", "upperroman", "roman"
     };
 
-    int listType=int((info.m_flags>>3)&0xF);
+    auto listType=int((info.m_flags>>3)&0xF);
     if (listType>0 && listType < 12)
       o << labelNames[listType] << ",";
     else if (listType)
       o << "#listType=" << listType << ",";
     if (info.m_flags&0x80) o << "flags80,";
-    int listLevel=int((info.m_flags>>8)&0xF);
+    auto listLevel=int((info.m_flags>>8)&0xF);
     if (listLevel) o << "level=" << listLevel+1;
     if (info.m_flags>>12) o << "flags=" << std::hex << (info.m_flags>>12) << std::dec << ",";
     if (info.m_extra.length()) o << info.m_extra;
@@ -276,7 +284,10 @@ struct ParagraphPLC {
 /** internal class used to store a text zone */
 struct TextZoneInfo {
   //! constructor
-  TextZoneInfo() : m_pos(0), m_N(0), m_extra("")
+  TextZoneInfo()
+    : m_pos(0)
+    , m_N(0)
+    , m_extra("")
   {
   }
   //! operator<<
@@ -301,10 +312,15 @@ enum TokenType { TKN_UNKNOWN, TKN_FOOTNOTE, TKN_PAGENUMBER, TKN_GRAPHIC, TKN_FIE
 /** Internal: class to store field definition: TOKN entry*/
 struct Token {
   //! constructor
-  Token() : m_type(TKN_UNKNOWN), m_zoneId(-1), m_page(-1), m_descent(0), m_fieldEntry(), m_extra("")
+  Token()
+    : m_type(TKN_UNKNOWN)
+    , m_zoneId(-1), m_page(-1)
+    , m_descent(0)
+    , m_fieldEntry()
+    , m_extra("")
   {
-    for (int i = 0; i < 3; i++) m_unknown[i] = 0;
-    for (int i = 0; i < 2; i++) m_size[i] = 0;
+    for (auto &i : m_unknown) i = 0;
+    for (auto &i : m_size) i = 0;
   }
   //! operator <<
   friend std::ostream &operator<<(std::ostream &o, Token const &tok);
@@ -377,17 +393,27 @@ std::ostream &operator<<(std::ostream &o, Token const &tok)
 }
 
 //! low level internal: main text zone
-struct DSET : public ClarisWksStruct::DSET {
+struct DSET final : public ClarisWksStruct::DSET {
   //! constructor
-  explicit DSET(ClarisWksStruct::DSET const &dset = ClarisWksStruct::DSET()) :
-    ClarisWksStruct::DSET(dset), m_zones(), m_numChar(0), m_numTextZone(0), m_numParagInfo(0),
-    m_numFont(0), m_fatherId(0), m_unknown(0),
-    m_subSectionPosList(), m_fontList(), m_paragraphList(), m_tokenList(),
-    m_textZoneList(), m_plcMap()
+  explicit DSET(ClarisWksStruct::DSET const &dset = ClarisWksStruct::DSET())
+    : ClarisWksStruct::DSET(dset)
+    , m_zones()
+    , m_numChar(0)
+    , m_numTextZone(0)
+    , m_numParagInfo(0)
+    , m_numFont(0)
+    , m_fatherId(0)
+    , m_unknown(0)
+    , m_subSectionPosList()
+    , m_fontList()
+    , m_paragraphList()
+    , m_tokenList()
+    , m_textZoneList()
+    , m_plcMap()
   {
   }
   //! destructor
-  virtual ~DSET();
+  ~DSET() final;
   //! true if the zone is outlined
   bool isOutlined() const
   {
@@ -430,7 +456,10 @@ DSET::~DSET()
 //! Internal: the state of a ClarisDrawText
 struct State {
   //! constructor
-  State() : m_version(-1), m_paragraphsList(), m_zoneMap()
+  State()
+    : m_version(-1)
+    , m_paragraphsList()
+    , m_zoneMap()
   {
   }
 
@@ -439,7 +468,7 @@ struct State {
   //! the list of paragraph
   std::vector<Paragraph> m_paragraphsList;
   //! the list of text zone
-  std::map<int, shared_ptr<DSET> > m_zoneMap;
+  std::map<int, std::shared_ptr<DSET> > m_zoneMap;
 };
 
 }
@@ -447,9 +476,11 @@ struct State {
 ////////////////////////////////////////////////////////////
 // constructor/destructor, ...
 ////////////////////////////////////////////////////////////
-ClarisDrawText::ClarisDrawText(ClarisDrawParser &parser) :
-  m_parserState(parser.getParserState()), m_state(new ClarisDrawTextInternal::State), m_mainParser(&parser),
-  m_styleManager(parser.m_styleManager)
+ClarisDrawText::ClarisDrawText(ClarisDrawParser &parser)
+  : m_parserState(parser.getParserState())
+  , m_state(new ClarisDrawTextInternal::State)
+  , m_mainParser(&parser)
+  , m_styleManager(parser.m_styleManager)
 {
 }
 
@@ -481,10 +512,10 @@ int ClarisDrawText::numPages() const
 ////////////////////////////////////////////////////////////
 // a document part
 ////////////////////////////////////////////////////////////
-shared_ptr<ClarisWksStruct::DSET> ClarisDrawText::readDSETZone(ClarisWksStruct::DSET const &zone, MWAWEntry const &entry)
+std::shared_ptr<ClarisWksStruct::DSET> ClarisDrawText::readDSETZone(ClarisWksStruct::DSET const &zone, MWAWEntry const &entry)
 {
   if (!entry.valid() || zone.m_fileType != 1)
-    return shared_ptr<ClarisWksStruct::DSET>();
+    return std::shared_ptr<ClarisWksStruct::DSET>();
   long pos = entry.begin();
   MWAWInputStreamPtr &input= m_parserState->m_input;
   input->seek(pos+8+16, librevenge::RVNG_SEEK_SET); // avoid header+8 generic number
@@ -492,7 +523,7 @@ shared_ptr<ClarisWksStruct::DSET> ClarisDrawText::readDSETZone(ClarisWksStruct::
   libmwaw::DebugStream f;
   f << "Entries(DSETT):";
 
-  shared_ptr<ClarisDrawTextInternal::DSET> textZone(new ClarisDrawTextInternal::DSET(zone));
+  std::shared_ptr<ClarisDrawTextInternal::DSET> textZone(new ClarisDrawTextInternal::DSET(zone));
   textZone->m_unknown = static_cast<int>(input->readULong(2)); // alway 0 ?
   textZone->m_fatherId = static_cast<int>(input->readULong(2));
   textZone->m_numChar = static_cast<int>(input->readULong(4));
@@ -540,10 +571,10 @@ shared_ptr<ClarisWksStruct::DSET> ClarisDrawText::readDSETZone(ClarisWksStruct::
   // read the last part
   int const data0Length = 28;
 
-  int N = int(zone.m_numData);
-  if (data0Length<0 || N<0 || long(input->tell())+N*data0Length > entry.end()) {
+  auto N = int(zone.m_numData);
+  if (N<0 || long(input->tell())+N*data0Length > entry.end()) {
     MWAW_DEBUG_MSG(("ClarisDrawText::readDSETZone: file is too short\n"));
-    return shared_ptr<ClarisWksStruct::DSET>();
+    return std::shared_ptr<ClarisWksStruct::DSET>();
   }
 
   input->seek(entry.end()-N*data0Length, librevenge::RVNG_SEEK_SET);
@@ -562,9 +593,8 @@ shared_ptr<ClarisWksStruct::DSET> ClarisDrawText::readDSETZone(ClarisWksStruct::
       textZone->m_subSectionPosList.push_back(child.m_posC);
     child.m_type = ClarisWksStruct::DSET::C_SubText;
     int dim[2];
-    for (int j = 0; j < 2; j++)
-      dim[j] = static_cast<int>(input->readLong(2));
-    child.m_box = MWAWBox2i(MWAWVec2i(0,0), MWAWVec2i(dim[0], dim[1]));
+    for (int &j : dim) j = static_cast<int>(input->readLong(2));
+    child.m_box = MWAWBox2f(MWAWVec2f(0,0), MWAWVec2f(float(dim[0]), float(dim[1])));
     textZone->m_childs.push_back(child);
     plc.m_id = i;
     textZone->m_plcMap.insert(std::map<long, ClarisDrawTextInternal::PLC>::value_type(child.m_posC, plc));
@@ -573,16 +603,16 @@ shared_ptr<ClarisWksStruct::DSET> ClarisDrawText::readDSETZone(ClarisWksStruct::
     f << "f0=" << input->readLong(2) << ","; // a small number : number of line ?
     f << "y[real]=" << input->readLong(2) << ",";
     for (int j = 1; j < 4; j++) {
-      int val = static_cast<int>(input->readLong(2));
+      auto val = static_cast<int>(input->readLong(2));
       if (val)
         f << "f" << j << "=" << val << ",";
     }
-    int order = static_cast<int>(input->readLong(2));
+    auto order = static_cast<int>(input->readLong(2));
     // simple id or 0: main text ?, 1 : header/footnote ?, 2: footer => id or order?
     if (order)
       f << "order?=" << order << ",";
 
-    long id=static_cast<long>(input->readULong(4));
+    auto id=static_cast<long>(input->readULong(4));
     if (id) {
       f << "ID=" << std::hex << id << std::dec << ",";
       ++numExtraHId;
@@ -609,7 +639,7 @@ shared_ptr<ClarisWksStruct::DSET> ClarisDrawText::readDSETZone(ClarisWksStruct::
         break;
       return textZone;
     }
-    long sz = long(input->readULong(4));
+    auto sz = long(input->readULong(4));
     if (!sz) {
       f.str("");
       f << "DSETT-Z" << z;
@@ -666,7 +696,7 @@ shared_ptr<ClarisWksStruct::DSET> ClarisDrawText::readDSETZone(ClarisWksStruct::
   // never seems
   for (int i=0; ok && i<numExtraHId; ++i) {
     pos=input->tell();
-    long sz=long(input->readULong(4));
+    auto sz=long(input->readULong(4));
     if (sz<10 || !input->checkPosition(pos+4+sz)) {
       MWAW_DEBUG_MSG(("ClarisDrawText::readDSETZone:: can not read an extra block\n"));
       ascFile.addPos(pos);
@@ -678,10 +708,10 @@ shared_ptr<ClarisWksStruct::DSET> ClarisDrawText::readDSETZone(ClarisWksStruct::
     f.str("");
     f << "DSETT-extra:";
     /* Checkme: no sure how to read this unfrequent structures */
-    int val=static_cast<int>(input->readLong(2)); // 2 (with size=34 or 4c)|a(with size=a or e)|3c (with size 3c)
+    auto val=static_cast<int>(input->readLong(2)); // 2 (with size=34 or 4c)|a(with size=a or e)|3c (with size 3c)
     f << "type?=" << val << ",";
     int dim[4];
-    for (int j=0; j<4; ++j) dim[j]=static_cast<int>(input->readLong(2));
+    for (int &j : dim) j=static_cast<int>(input->readLong(2));
     f << "dim=" << dim[1] << "x" << dim[0] << "<->" << dim[3] << "x" << dim[2] << ",";
     if (sz!=10) ascFile.addDelimiter(input->tell(),'|');
     ascFile.addPos(pos);
@@ -698,7 +728,7 @@ shared_ptr<ClarisWksStruct::DSET> ClarisDrawText::readDSETZone(ClarisWksStruct::
   if (ok) {
     // look for unparsed zone
     pos=input->tell();
-    long sz=long(input->readULong(4));
+    auto sz=long(input->readULong(4));
     if (input->checkPosition(pos+4+sz)) {
       if (sz) {
         MWAW_DEBUG_MSG(("ClarisDrawText::readDSETZone:: find some extra block\n"));
@@ -729,7 +759,7 @@ bool ClarisDrawText::readFonts(MWAWEntry const &entry, ClarisDrawTextInternal::D
   if ((entry.length()%12) != 4)
     return false;
 
-  int numElt = int((entry.length()-4)/12);
+  auto numElt = int((entry.length()-4)/12);
   MWAWInputStreamPtr &input= m_parserState->m_input;
   input->seek(pos+4, librevenge::RVNG_SEEK_SET); // skip header
   libmwaw::DebugFile &ascFile = m_parserState->m_asciiFile;
@@ -772,7 +802,7 @@ bool ClarisDrawText::readFont(int id, int &posC, MWAWFont &font)
   posC = int(input->readULong(4));
   f << "pos=" << posC << ",";
   font.setId(static_cast<int>(input->readULong(2)));
-  int flag =static_cast<int>(input->readULong(2));
+  auto flag =static_cast<int>(input->readULong(2));
   uint32_t flags=0;
   if (flag&0x1) flags |= MWAWFont::boldBit;
   if (flag&0x2) flags |= MWAWFont::italicBit;
@@ -791,7 +821,7 @@ bool ClarisDrawText::readFont(int id, int &posC, MWAWFont &font)
     font.setUnderlineType(MWAWFont::Line::Double);
   }
   font.setSize(float(input->readULong(2)));
-  int colId = static_cast<int>(input->readULong(1));
+  auto colId = static_cast<int>(input->readULong(1));
   if (colId) f << "#backColor=" << colId << ",";
   colId = static_cast<int>(input->readULong(1));
   if (colId!=1) {
@@ -820,40 +850,23 @@ bool ClarisDrawText::readParagraphs()
 {
   MWAWInputStreamPtr &input= m_parserState->m_input;
   long pos = input->tell();
-  long sz = long(input->readULong(4));
-  long endPos = pos+4+sz;
-
-  if (!input->checkPosition(endPos)) {
-    MWAW_DEBUG_MSG(("ClarisDrawText::readParagraphs: ruler zone is too short\n"));
-    return false;
-  }
-
-  int N = static_cast<int>(input->readULong(2));
-  int type = static_cast<int>(input->readLong(2));
-  int val = static_cast<int>(input->readLong(2));
-  int fSz = static_cast<int>(input->readLong(2));
-
-  if (sz != 12+fSz*N) {
-    input->seek(pos, librevenge::RVNG_SEEK_SET);
-    MWAW_DEBUG_MSG(("ClarisDrawText::readParagraphs: find odd ruler size\n"));
+  ClarisWksStruct::Struct header;
+  if (!header.readHeader(input,true)) {
+    MWAW_DEBUG_MSG(("ClarisDrawText::readParagraphs: can not reead the header\n"));
     return false;
   }
 
   libmwaw::DebugFile &ascFile = m_parserState->m_asciiFile;
   libmwaw::DebugStream f;
-  f << "Entries(RULR):";
-  f << "N=" << N << ", type?=" << type <<", fSz=" << fSz << ",";
-  if (val) f << "unkn=" << val << ",";
-
-  for (int i = 0; i < 2; i++) {
-    val = static_cast<int>(input->readLong(2));
-    if (val)  f << "f" << i << "=" << val << ",";
+  f << "Entries(RULR):" << header;
+  if (header.m_headerSize) {
+    ascFile.addDelimiter(input->tell(),'|');
+    input->seek(header.m_headerSize, librevenge::RVNG_SEEK_CUR);
   }
-
   ascFile.addPos(pos);
   ascFile.addNote(f.str().c_str());
 
-  for (int i = 0; i < N; i++) {
+  for (int i = 0; i < int(header.m_numData); i++) {
     pos = input->tell();
     if (!readParagraph(i)) {
       input->seek(pos, librevenge::RVNG_SEEK_SET);
@@ -869,7 +882,7 @@ bool ClarisDrawText::readParagraphs(MWAWEntry const &entry, ClarisDrawTextIntern
   if ((entry.length()%8) != 4)
     return false;
 
-  int numElt = int((entry.length()-4)/8);
+  auto numElt = int((entry.length()-4)/8);
 
   MWAWInputStreamPtr &input= m_parserState->m_input;
   input->seek(pos+4, librevenge::RVNG_SEEK_SET); // skip header
@@ -886,7 +899,7 @@ bool ClarisDrawText::readParagraphs(MWAWEntry const &entry, ClarisDrawTextIntern
     pos = input->tell();
     ClarisDrawTextInternal::ParagraphPLC info;
 
-    long posC = long(input->readULong(4));
+    auto posC = long(input->readULong(4));
     f.str("");
     f << "ParaPLC-R" << i << ": pos=" << posC << ",";
     info.m_rulerId = static_cast<int>(input->readLong(2));
@@ -953,8 +966,8 @@ bool ClarisDrawText::readParagraph(int id)
       ruler.setInterline(1.0+double(interline)/8, librevenge::RVNG_PERCENT);
   }
   if (val) f << "#flags=" << std::hex << val << std::dec << ",";
-  for (int i = 0; i < 3; i++)
-    ruler.m_margins[i] = double(input->readLong(2))/72.;
+  for (auto &margin : ruler.m_margins)
+    margin = double(input->readLong(2))/72.;
   *(ruler.m_margins[2]) -= 28./72.;
   if (ruler.m_margins[2].get() < 0.0) ruler.m_margins[2] = 0.0;
   for (int i = 0; i < 2; i++) {
@@ -963,7 +976,7 @@ bool ClarisDrawText::readParagraph(int id)
   }
   val = static_cast<int>(input->readLong(1));
   if (val) f << "unkn1=" << val << ",";
-  int numTabs = static_cast<int>(input->readULong(1));
+  auto numTabs = static_cast<int>(input->readULong(1));
   if (long(input->tell())+numTabs*4 > endPos) {
     if (numTabs != 255) { // 0xFF seems to be used in v1, v2
       MWAW_DEBUG_MSG(("ClarisDrawText::readParagraph: numTabs is too big\n"));
@@ -1004,7 +1017,7 @@ bool ClarisDrawText::readParagraph(int id)
       break;
     }
     val &= 0x3C;
-    char decimalChar = char(input->readULong(1));
+    auto decimalChar = char(input->readULong(1));
     if (decimalChar) {
       int unicode= m_parserState->m_fontConverter->unicode(3, static_cast<unsigned char>(decimalChar));
       if (unicode==-1)
@@ -1056,7 +1069,7 @@ bool ClarisDrawText::readTokens(MWAWEntry const &entry, ClarisDrawTextInternal::
   libmwaw::DebugFile &ascFile = m_parserState->m_asciiFile;
   ascFile.addPos(pos);
   ascFile.addNote("Entries(Token)");
-  int numElt = int((entry.length()-4)/32);
+  auto numElt = int((entry.length()-4)/32);
   input->seek(pos+4, librevenge::RVNG_SEEK_SET); // skip header
 
   libmwaw::DebugStream f;
@@ -1067,10 +1080,10 @@ bool ClarisDrawText::readTokens(MWAWEntry const &entry, ClarisDrawTextInternal::
   for (int i = 0; i < numElt; i++) {
     pos = input->tell();
 
-    int posC = static_cast<int>(input->readULong(4));
+    auto posC = static_cast<int>(input->readULong(4));
     ClarisDrawTextInternal::Token token;
 
-    int type = static_cast<int>(input->readLong(2));
+    auto type = static_cast<int>(input->readLong(2));
     f.str("");
     switch (type) {
     case 0:
@@ -1120,13 +1133,14 @@ bool ClarisDrawText::readTokens(MWAWEntry const &entry, ClarisDrawTextInternal::
   }
 
   input->seek(entry.end(), librevenge::RVNG_SEEK_SET);
-  for (size_t i=0; i < fieldList.size(); ++i) {
+  int n=0;
+  for (auto fl : fieldList) {
     pos=input->tell();
-    long sz=long(input->readULong(4));
+    auto sz=long(input->readULong(4));
     f.str("");
-    f << "Token[field-" << i << "]:";
+    f << "Token[field-" << n++ << "]:";
     if (!input->checkPosition(pos+sz+4) || long(input->readULong(1))+1!=sz) {
-      MWAW_DEBUG_MSG(("ClarisDrawText::readTokens: can find token field name %d\n", int(i)));
+      MWAW_DEBUG_MSG(("ClarisDrawText::readTokens: can find token field name %d\n", n-1));
       input->seek(pos, librevenge::RVNG_SEEK_SET);
       f << "###";
       ascFile.addPos(pos);
@@ -1138,7 +1152,7 @@ bool ClarisDrawText::readTokens(MWAWEntry const &entry, ClarisDrawTextInternal::
     MWAWEntry fieldEntry;
     fieldEntry.setBegin(input->tell());
     fieldEntry.setEnd(pos+sz+4);
-    zone.m_tokenList[size_t(fieldList[i])].m_fieldEntry=fieldEntry;
+    zone.m_tokenList[size_t(fl)].m_fieldEntry=fieldEntry;
     input->seek(fieldEntry.end(), librevenge::RVNG_SEEK_SET);
   }
   return true;
@@ -1160,7 +1174,7 @@ bool ClarisDrawText::readTextZoneSize(MWAWEntry const &entry, ClarisDrawTextInte
   ascFile.addPos(pos);
   ascFile.addNote("Entries(TextZoneSz)");
 
-  int numElt = int((entry.length()-4)/dataSize);
+  auto numElt = int((entry.length()-4)/dataSize);
 
   MWAWInputStreamPtr &input= m_parserState->m_input;
   input->seek(pos+4, librevenge::RVNG_SEEK_SET); // skip header
@@ -1201,15 +1215,13 @@ bool ClarisDrawText::sendText(ClarisDrawTextInternal::DSET const &zone, int subZ
     MWAW_DEBUG_MSG(("ClarisDrawText::sendText: can not find a listener\n"));
     return false;
   }
-  int numParaPLC = int(zone.m_paragraphList.size());
-  int numParagraphs = int(m_state->m_paragraphsList.size());
-  size_t numZones = zone.m_zones.size();
+  auto numParaPLC = int(zone.m_paragraphList.size());
+  auto numParagraphs = int(m_state->m_paragraphsList.size());
   int numCols = 1;
-  shared_ptr<MWAWList> actList;
+  std::shared_ptr<MWAWList> actList;
   bool isOutline=zone.isOutlined();
   MWAWInputStreamPtr &input= m_parserState->m_input;
   libmwaw::DebugFile &ascFile = m_parserState->m_asciiFile;
-  std::multimap<long, ClarisDrawTextInternal::PLC>::const_iterator plcIt;
 
   long firstChar=0, lastChar=zone.m_numChar;
   if (subZone>=0) {
@@ -1221,23 +1233,24 @@ bool ClarisDrawText::sendText(ClarisDrawTextInternal::DSET const &zone, int subZ
   }
 
   long actC = 0;
+  size_t numZones = zone.m_zones.size();
   for (size_t z = 0; z < numZones; z++) {
     MWAWEntry const &entry  =  zone.m_zones[z];
     long pos = entry.begin();
     libmwaw::DebugStream f, f2;
 
-    int numC = int(entry.length()-4);
+    auto numC = int(entry.length()-4);
     input->seek(pos+4, librevenge::RVNG_SEEK_SET); // skip header
 
     for (int i = 0; i < numC; i++) {
-      plcIt = zone.m_plcMap.find(actC);
+      auto plcIt = zone.m_plcMap.find(actC);
       bool seeToken = false;
       while (actC>=firstChar && plcIt != zone.m_plcMap.end() && plcIt->first<=actC) {
         if (actC != plcIt->first) {
           MWAW_DEBUG_MSG(("ClarisDrawText::sendText: find a plc inside a complex char!!!\n"));
           f << "###";
         }
-        ClarisDrawTextInternal::PLC const &plc = plcIt++->second;
+        auto const &plc = plcIt++->second;
         f << "[" << plc << "]";
         switch (plc.m_type) {
         case ClarisDrawTextInternal::P_Font:
@@ -1251,11 +1264,11 @@ bool ClarisDrawText::sendText(ClarisDrawTextInternal::DSET const &zone, int subZ
         case ClarisDrawTextInternal::P_Ruler: {
           if (plc.m_id < 0 || plc.m_id >= numParaPLC)
             break;
-          ClarisDrawTextInternal::ParagraphPLC const &paraPLC = zone.m_paragraphList[size_t(plc.m_id)];
+          auto const &paraPLC = zone.m_paragraphList[size_t(plc.m_id)];
           f << "[" << paraPLC << "]";
           if (paraPLC.m_rulerId < 0 || paraPLC.m_rulerId >= numParagraphs)
             break;
-          ClarisDrawTextInternal::Paragraph para = m_state->m_paragraphsList[size_t(paraPLC.m_rulerId)];
+          auto para = m_state->m_paragraphsList[size_t(paraPLC.m_rulerId)];
           if (isOutline) {
             para.m_labelType=paraPLC.getLabelType();
             para.m_listLevelIndex=0;
@@ -1273,7 +1286,7 @@ bool ClarisDrawText::sendText(ClarisDrawTextInternal::DSET const &zone, int subZ
             f << "###";
             break;
           }
-          ClarisDrawTextInternal::Token const &token = zone.m_tokenList[size_t(plc.m_id)];
+          auto const &token = zone.m_tokenList[size_t(plc.m_id)];
           switch (token.m_type) {
           case ClarisDrawTextInternal::TKN_FOOTNOTE:
             MWAW_DEBUG_MSG(("ClarisDrawText::sendText: can not send footnote in a paint file\n"));
@@ -1338,7 +1351,7 @@ bool ClarisDrawText::sendText(ClarisDrawTextInternal::DSET const &zone, int subZ
           break;
         }
       }
-      char c = char(input->readULong(1));
+      auto c = char(input->readULong(1));
       if (actC++<firstChar)
         continue;
       if (actC>lastChar) break;
@@ -1427,11 +1440,10 @@ bool ClarisDrawText::sendText(ClarisDrawTextInternal::DSET const &zone, int subZ
 
 bool ClarisDrawText::sendZone(int number, int subZone)
 {
-  std::map<int, shared_ptr<ClarisDrawTextInternal::DSET> >::iterator iter
-    = m_state->m_zoneMap.find(number);
+  auto iter = m_state->m_zoneMap.find(number);
   if (iter == m_state->m_zoneMap.end())
     return false;
-  shared_ptr<ClarisDrawTextInternal::DSET> zone = iter->second;
+  auto zone = iter->second;
   if (zone)
     sendText(*zone, subZone);
   return true;
