@@ -127,12 +127,13 @@ struct Paragraph final : public MWAWParagraph {
   friend std::ostream &operator<<(std::ostream &o, Paragraph const &ind)
   {
     o << static_cast<MWAWParagraph const &>(ind) << ",";
-    static char const *(labelNames[]) = {
-      "none", "diamond", "bullet", "checkbox", "hardvard", "leader", "legal",
-      "upperalpha", "alpha", "numeric", "upperroman", "roman"
-    };
-    if (ind.m_labelType > 0 && ind.m_labelType < 12)
+    if (ind.m_labelType > 0 && ind.m_labelType < 12) {
+      static char const *labelNames[] = {
+        "none", "diamond", "bullet", "checkbox", "hardvard", "leader", "legal",
+        "upperalpha", "alpha", "numeric", "upperroman", "roman"
+      };
       o << "label=" << labelNames[ind.m_labelType] << ",";
+    }
     else if (ind.m_labelType)
       o << "#labelType=" << ind.m_labelType << ",";
     return o;
@@ -254,14 +255,15 @@ struct ParagraphPLC {
     }
     if (info.m_flags&4)
       o << "flags4,";
-    static char const *(labelNames[]) = {
-      "none", "diamond", "bullet", "checkbox", "hardvard", "leader", "legal",
-      "upperalpha", "alpha", "numeric", "upperroman", "roman"
-    };
 
     auto listType=int((info.m_flags>>3)&0xF);
-    if (listType>0 && listType < 12)
+    if (listType>0 && listType < 12) {
+      static char const *labelNames[] = {
+        "none", "diamond", "bullet", "checkbox", "hardvard", "leader", "legal",
+        "upperalpha", "alpha", "numeric", "upperroman", "roman"
+      };
       o << labelNames[listType] << ",";
+    }
     else if (listType)
       o << "#listType=" << listType << ",";
     if (info.m_flags&0x80) o << "flags80,";
