@@ -61,7 +61,10 @@ namespace FullWrtTextInternal
 /** Internal: class to store a para modifier with appear in docInfo */
 struct ParaModifier {
   //! constructor
-  ParaModifier() : m_beforeSpacing(0), m_afterSpacing(0), m_extra("")
+  ParaModifier()
+    : m_beforeSpacing(0)
+    , m_afterSpacing(0)
+    , m_extra("")
   {
   }
   //! operator<<
@@ -89,9 +92,11 @@ struct ParaModifier {
 /** Internal: class to store a font/para modifier with appear in text data */
 struct DataModifier {
   //! constructor
-  DataModifier() : m_color(MWAWColor::black()), m_extra("")
+  DataModifier()
+    : m_color(MWAWColor::black())
+    , m_extra("")
   {
-    for (int i = 0; i < 4; i++) m_data[i]=0xFFFF;
+    for (auto &data : m_data) data=0xFFFF;
   }
   //! returns the superscript value ( negative in pt, position in li)
   float getSuper() const
@@ -148,9 +153,16 @@ struct Item {
   /** the different type of id */
   enum Type { Father=0, Child, Next, Prev, Main };
   /** constructor */
-  Item(): m_level(0), m_index(1), m_collapsed(false), m_hidden(false), m_childList(), m_hiddenZone(), m_extra("")
+  Item()
+    : m_level(0)
+    , m_index(1)
+    , m_collapsed(false)
+    , m_hidden(false)
+    , m_childList()
+    , m_hiddenZone()
+    , m_extra("")
   {
-    for (int i = 0; i < 5; i++) m_structId[i]=0;
+    for (auto &structId : m_structId) structId=0;
   }
   //! return a value which can be used to represent the label(changme)
   std::string label() const
@@ -167,7 +179,7 @@ struct Item {
     if (it.m_collapsed) o << "collapsed,";
     if (it.m_level) o << "level=" << it.m_level << ",";
     if (it.m_index!=1) o << "index=" << it.m_index << ",";
-    char const *(wh[5])= {"father", "child", "next", "prev", "main"};
+    char const *wh[5]= {"father", "child", "next", "prev", "main"};
     o << "zId=[";
     for (int i = 0; i < 5; i++) {
       if (it.m_structId[i]) o << wh[i] << "=" << it.m_structId[i] << ",";
@@ -187,7 +199,7 @@ struct Item {
   //! the list of childlist
   std::vector<int> m_childList;
   //! the hidden item zone
-  shared_ptr<Zone> m_hiddenZone;
+  std::shared_ptr<Zone> m_hiddenZone;
   //! the item id in text struct zone ( father, child, next, prev, main )
   int m_structId[5];
   //! extra data
@@ -197,9 +209,13 @@ struct Item {
 /** Internal: class to store a font and it state */
 struct Font {
   /** constructor */
-  Font() : m_font(), m_modifier(), m_defModifier(true), m_item()
+  Font()
+    : m_font()
+    , m_modifier()
+    , m_defModifier(true)
+    , m_item()
   {
-    for (int i = 0; i < 128; i++) m_state[i]=false;
+    for (auto &state : m_state) state=false;
   }
   /** update the font using the modifier */
   void update();
@@ -250,7 +266,14 @@ void Font::update()
 /** Internal: class to store the LineHeader */
 struct LineHeader {
   /** Constructor */
-  LineHeader() : m_numChar(0), m_font(), m_fontSet(false), m_height(-1.0), m_prevHeight(-1.0), m_textIndent(0), m_extra("")
+  LineHeader()
+    : m_numChar(0)
+    , m_font()
+    , m_fontSet(false)
+    , m_height(-1.0)
+    , m_prevHeight(-1.0)
+    , m_textIndent(0)
+    , m_extra("")
   {
   }
   //! try to find the line height using m_height or m_prevHeight
@@ -288,7 +311,10 @@ struct LineHeader {
 };
 /** Internal: class to store a ColumnInfo */
 struct ColumnInfo {
-  ColumnInfo() : m_column(0), m_box(), m_beginPos(1)
+  ColumnInfo()
+    : m_column(0)
+    , m_box()
+    , m_beginPos(1)
   {
   }
 
@@ -309,7 +335,9 @@ struct ColumnInfo {
 };
 
 struct PageInfo {
-  PageInfo() : m_page(-1), m_columns()
+  PageInfo()
+    : m_page(-1)
+    , m_columns()
   {
   }
 
@@ -360,10 +388,17 @@ struct Zone {
   //! the zone type
   enum ZoneType { Normal, Main, CollapsedItem };
   //! constructor
-  Zone() : m_zone(), m_box(), m_begin(-1), m_end(-1), m_zoneType(Normal), m_pagesInfo(), m_extra("")
+  Zone()
+    : m_zone()
+    , m_box()
+    , m_begin(-1)
+    , m_end(-1)
+    , m_zoneType(Normal)
+    , m_pagesInfo()
+    , m_extra("")
   {
-    for (int i = 0; i < 2; i++) m_flags[i] = 0;
-    for (int i = 0; i < 2; i++) m_pages[i] = 0;
+    for (auto &fl : m_flags) fl=0;
+    for (auto &p : m_pages) p=0;
   }
   //! operator<<
   friend std::ostream &operator<<(std::ostream &o, Zone const &z)
@@ -401,16 +436,13 @@ struct Zone {
   //! return the col/page break
   std::vector<int> getBreaksPosition() const
   {
-    size_t numPages = m_pagesInfo.size();
     int prevPos = 0;
     std::vector<int> res;
-    for (size_t p = 0; p < numPages; p++) {
-      PageInfo const &page = m_pagesInfo[p];
-      for (size_t c = 0; c < page.m_columns.size(); c++) {
-        int pos = page.m_columns[c].m_beginPos;
+    for (auto const &page : m_pagesInfo) {
+      for (auto const &column : page.m_columns) {
+        int pos = column.m_beginPos;
         if (pos < prevPos) {
           MWAW_DEBUG_MSG(("FullWrtTextInternal::Zone::getBreaksPosition pos go back\n"));
-          p = numPages;
           break;
         }
         res.push_back(pos);
@@ -441,15 +473,25 @@ struct Zone {
 };
 
 /** Internal: class to store the paragraph properties */
-struct Paragraph : public MWAWParagraph {
+struct Paragraph final : public MWAWParagraph {
   //! Constructor
-  Paragraph() : MWAWParagraph(), m_align(0), m_interSpacing(1.), m_interSpacingUnit(librevenge::RVNG_PERCENT),
-    m_dim(0,0), m_border(), m_isTable(false), m_tableBorderId(0), m_tableFlags(), m_actCol(-1), m_isSent(false)
+  Paragraph()
+    : MWAWParagraph()
+    , m_align(0)
+    , m_interSpacing(1.)
+    , m_interSpacingUnit(librevenge::RVNG_PERCENT)
+    , m_dim(0,0)
+    , m_border()
+    , m_isTable(false)
+    , m_tableBorderId(0)
+    , m_tableFlags()
+    , m_actCol(-1)
+    , m_isSent(false)
   {
-    m_befAftSpacings[0]=m_befAftSpacings[1]=0;
+    for (auto &space : m_befAftSpacings) space=0;
   }
   //! destructor
-  ~Paragraph();
+  ~Paragraph() final;
   //! operator<<
   friend std::ostream &operator<<(std::ostream &o, Paragraph const &ind)
   {
@@ -625,8 +667,16 @@ Paragraph::~Paragraph()
 //! Internal: the state of a FullWrtText
 struct State {
   //! constructor
-  State() : m_version(-1), m_entryMap(), m_paragraphMap(), m_itemMap(), m_dataModMap(),
-    m_paragraphModList(), m_mainZones(), m_numPages(1), m_actualPage(0)
+  State()
+    : m_version(-1)
+    , m_entryMap()
+    , m_paragraphMap()
+    , m_itemMap()
+    , m_dataModMap()
+    , m_paragraphModList()
+    , m_mainZones()
+    , m_numPages(1)
+    , m_actualPage(0)
   {
   }
 
@@ -634,7 +684,7 @@ struct State {
   mutable int m_version;
 
   //! zoneId -> entry
-  std::multimap<int, shared_ptr<Zone> > m_entryMap;
+  std::multimap<int, std::shared_ptr<Zone> > m_entryMap;
   //! rulerId -> ruler
   std::map<int, Paragraph> m_paragraphMap;
   //! itemId -> item
@@ -654,14 +704,16 @@ struct State {
 ////////////////////////////////////////////////////////////
 // constructor/destructor, ...
 ////////////////////////////////////////////////////////////
-FullWrtText::FullWrtText(FullWrtParser &parser) :
-  m_parserState(parser.getParserState()), m_state(new FullWrtTextInternal::State),
-  m_mainParser(&parser)
+FullWrtText::FullWrtText(FullWrtParser &parser)
+  : m_parserState(parser.getParserState())
+  , m_state(new FullWrtTextInternal::State)
+  , m_mainParser(&parser)
 {
 }
 
 FullWrtText::~FullWrtText()
-{ }
+{
+}
 
 int FullWrtText::version() const
 {
@@ -678,7 +730,7 @@ int FullWrtText::numPages() const
 ////////////////////////////////////////////////////////////
 // Intermediate level
 ////////////////////////////////////////////////////////////
-void FullWrtText::send(shared_ptr<FullWrtTextInternal::Zone> zone, int numChar,
+void FullWrtText::send(std::shared_ptr<FullWrtTextInternal::Zone> zone, int numChar,
                        FullWrtTextInternal::Font &font, FullWrtTextInternal::Paragraph &ruler,
                        std::string &str)
 {
@@ -695,7 +747,7 @@ void FullWrtText::send(shared_ptr<FullWrtTextInternal::Zone> zone, int numChar,
     long actPos = input->tell();
     if (actPos >= endPos)
       break;
-    int val = static_cast<int>(input->readULong(1));
+    auto val = static_cast<int>(input->readULong(1));
     bool done = false;
     int id=-1;
     if (nextIsChar)
@@ -875,10 +927,10 @@ void FullWrtText::send(shared_ptr<FullWrtTextInternal::Zone> zone, int numChar,
         if (font.m_item.m_collapsed && font.m_item.m_childList.size()) {
           if (!lastEOL)
             listener->insertEOL(false);
-          FullWrtTextInternal::Font hFont = font;
-          FullWrtTextInternal::Paragraph hRuler = ruler;
-          for (size_t c=0; c < font.m_item.m_childList.size(); c++)
-            sendHiddenItem(font.m_item.m_childList[c], hFont, hRuler);
+          auto hFont = font;
+          auto hRuler = ruler;
+          for (auto item : font.m_item.m_childList)
+            sendHiddenItem(item, hFont, hRuler);
           fontSet = false;
           ruler.m_isSent=false;
           lastEOL=false;
@@ -916,8 +968,7 @@ void FullWrtText::send(shared_ptr<FullWrtTextInternal::Zone> zone, int numChar,
         if (fCharSent) break;
         int pId = font.m_modifier.getDocParaId();
         if (pId >= 0 && pId < int(m_state->m_paragraphModList.size())) {
-          FullWrtTextInternal::ParaModifier const &paraMod =
-            m_state->m_paragraphModList[size_t(pId)];
+          auto const &paraMod = m_state->m_paragraphModList[size_t(pId)];
           ruler.setSpacings(double(paraMod.m_beforeSpacing), true);
           ruler.setSpacings(double(paraMod.m_afterSpacing), false);
           ruler.setBorder(FullWrtStruct::Border());
@@ -1018,8 +1069,7 @@ void FullWrtText::send(shared_ptr<FullWrtTextInternal::Zone> zone, int numChar,
         id = int(input->readULong(2));
         f << "[P" << id << "]";
 
-        std::map<int,FullWrtTextInternal::Paragraph>::iterator it=
-          m_state->m_paragraphMap.find(id);
+        auto it=m_state->m_paragraphMap.find(id);
         if (it==m_state->m_paragraphMap.end()) {
           MWAW_DEBUG_MSG(("FullWrtText::send: can not find paragraph with id=%d\n", id));
           break;
@@ -1036,7 +1086,7 @@ void FullWrtText::send(shared_ptr<FullWrtTextInternal::Zone> zone, int numChar,
           f << "[#justWithType]";
         }
         else {
-          int just = static_cast<int>(input->readLong(2));
+          auto just = static_cast<int>(input->readLong(2));
           if (just < 0)
             ruler.setInterlineSpacing(-just, librevenge::RVNG_POINT);
           f << "[just=" << just << ",";
@@ -1160,7 +1210,7 @@ void FullWrtText::send(shared_ptr<FullWrtTextInternal::Zone> zone, int numChar,
   str=f.str();
 }
 
-bool FullWrtText::sendTable(shared_ptr<FullWrtTextInternal::Zone> zone, FullWrtTextInternal::LineHeader const &lHeader,
+bool FullWrtText::sendTable(std::shared_ptr<FullWrtTextInternal::Zone> zone, FullWrtTextInternal::LineHeader const &lHeader,
                             FullWrtTextInternal::Font &font, FullWrtTextInternal::Paragraph &ruler, std::string &str)
 {
   std::vector<float> dim;
@@ -1185,7 +1235,7 @@ bool FullWrtText::sendTable(shared_ptr<FullWrtTextInternal::Zone> zone, FullWrtT
     long actPos = input->tell();
     if (input->isEnd())
       break;
-    int c = static_cast<int>(input->readULong(1));
+    auto c = static_cast<int>(input->readULong(1));
     if (c==0xa7) {
       cellPos.push_back(actPos);
       cellPos.push_back(actPos+1);
@@ -1263,7 +1313,7 @@ bool FullWrtText::sendTable(shared_ptr<FullWrtTextInternal::Zone> zone, FullWrtT
   return true;
 }
 
-bool FullWrtText::readLineHeader(shared_ptr<FullWrtTextInternal::Zone> zone, FullWrtTextInternal::LineHeader &lHeader)
+bool FullWrtText::readLineHeader(std::shared_ptr<FullWrtTextInternal::Zone> zone, FullWrtTextInternal::LineHeader &lHeader)
 {
   lHeader = FullWrtTextInternal::LineHeader();
 
@@ -1271,7 +1321,7 @@ bool FullWrtText::readLineHeader(shared_ptr<FullWrtTextInternal::Zone> zone, Ful
   libmwaw::DebugStream f;
   long pos = input->tell();
 
-  int type = static_cast<int>(input->readULong(2));
+  auto type = static_cast<int>(input->readULong(2));
   int lengthSz = 1;
   if (type & 0x8000)
     lengthSz = 2;
@@ -1348,8 +1398,8 @@ bool FullWrtText::readLineHeader(shared_ptr<FullWrtTextInternal::Zone> zone, Ful
     f << "],";
   }
   if (type & 0x10) {
-    int fId = static_cast<int>(input->readLong(2));
-    float fSz = float(input->readULong(2));
+    auto fId = static_cast<int>(input->readLong(2));
+    auto fSz = float(input->readULong(2));
     lHeader.m_fontSet = true;
     lHeader.m_font.setId(fId);
     lHeader.m_font.setSize(fSz);
@@ -1380,7 +1430,7 @@ bool FullWrtText::readLineHeader(shared_ptr<FullWrtTextInternal::Zone> zone, Ful
   return true;
 }
 
-bool FullWrtText::send(shared_ptr<FullWrtTextInternal::Zone> zone, MWAWColor fontColor)
+bool FullWrtText::send(std::shared_ptr<FullWrtTextInternal::Zone> zone, MWAWColor fontColor)
 {
   MWAWTextListenerPtr listener=m_parserState->m_textListener;
   if (!listener) {
@@ -1403,9 +1453,9 @@ bool FullWrtText::send(shared_ptr<FullWrtTextInternal::Zone> zone, MWAWColor fon
   if (zone->m_zone->m_type==0x11 || zone->m_zone->m_type==0x12)
     ruler.setAlign(1);
 
-  std::vector<int> listBreaks = zone->getBreaksPosition();
-  int numBreaks = int(listBreaks.size());
-  int nPages = int(zone->m_pagesInfo.size());
+  auto listBreaks = zone->getBreaksPosition();
+  auto numBreaks = int(listBreaks.size());
+  auto nPages = int(zone->m_pagesInfo.size());
   int actBreak = numBreaks, actBreakPos = -1;
   if (numBreaks) {
     actBreak = 0;
@@ -1429,7 +1479,7 @@ bool FullWrtText::send(shared_ptr<FullWrtTextInternal::Zone> zone, MWAWColor fon
         MWAW_DEBUG_MSG(("FullWrtText::send can not find the page information\n"));
       }
       else {
-        FullWrtTextInternal::PageInfo const &page = zone->m_pagesInfo[size_t(actPage)];
+        auto const &page = zone->m_pagesInfo[size_t(actPage)];
         if (sendData) {
           if (zone->m_zoneType == FullWrtTextInternal::Zone::Main)
             m_mainParser->newPage(++m_state->m_actualPage);
@@ -1439,7 +1489,7 @@ bool FullWrtText::send(shared_ptr<FullWrtTextInternal::Zone> zone, MWAWColor fon
         actCol = 0;
 
         if (!actPage || !page.isSimilar(zone->m_pagesInfo[size_t(actPage-1)])) {
-          MWAWSection section = page.getSection();
+          auto section = page.getSection();
           libmwaw::SubDocumentType subdocType;
           int numC = section.numColumns();
           if (listener->isSubDocumentOpened(subdocType) && numC <=1
@@ -1515,7 +1565,7 @@ bool FullWrtText::sendHiddenItem(int id, FullWrtTextInternal::Font &font, FullWr
     MWAW_DEBUG_MSG(("FullWrtText::sendHiddenItem: can not find item %d\n", id));
     return false;
   }
-  FullWrtTextInternal::Item &item = m_state->m_itemMap.find(id)->second;
+  auto &item = m_state->m_itemMap.find(id)->second;
   if (!item.m_hidden) {
     MWAW_DEBUG_MSG(("FullWrtText::sendHiddenItem: item %d is not hidden\n", id));
     return false;
@@ -1524,7 +1574,7 @@ bool FullWrtText::sendHiddenItem(int id, FullWrtTextInternal::Font &font, FullWr
   font.m_item=FullWrtTextInternal::Item(); // no previous item
   item.m_hidden = false; // item is send
 
-  shared_ptr<FullWrtTextInternal::Zone> zone=item.m_hiddenZone;
+  std::shared_ptr<FullWrtTextInternal::Zone> zone=item.m_hiddenZone;
   if (!zone) {
     MWAW_DEBUG_MSG(("FullWrtText::sendHiddenItem can not find the hidden zone\n"));
     return false;
@@ -1536,7 +1586,7 @@ bool FullWrtText::sendHiddenItem(int id, FullWrtTextInternal::Font &font, FullWr
   input->seek(pos, librevenge::RVNG_SEEK_SET);
 
   f << "ItemData[Collapsed]:";
-  int val = static_cast<int>(input->readULong(1)); // alway 40 ?
+  auto val = static_cast<int>(input->readULong(1)); // alway 40 ?
   if (val != 0x40)
     f << "#type=" << val << ",";
   val = static_cast<int>(input->readULong(1)); // find number between 3 and 7, a unique id ?
@@ -1573,7 +1623,7 @@ bool FullWrtText::sendHiddenItem(int id, FullWrtTextInternal::Font &font, FullWr
     if (val) f << "h" << i+3 << "=" << std::hex << val << std::dec << ",";
   }
   input->seek(4, librevenge::RVNG_SEEK_CUR); // skip size...
-  int numChar=int(zone->m_end-(pos+44));
+  auto numChar=int(zone->m_end-(pos+44));
   if (numChar)
     ascii.addDelimiter(pos+44,'|');
   listener->setParagraph(ruler);
@@ -1584,8 +1634,8 @@ bool FullWrtText::sendHiddenItem(int id, FullWrtTextInternal::Font &font, FullWr
   ascii.addPos(pos);
   ascii.addNote(f.str().c_str());
 
-  for (size_t c=0; c < item.m_childList.size(); c++)
-    sendHiddenItem(item.m_childList[c], font, ruler);
+  for (auto child : item.m_childList)
+    sendHiddenItem(child, font, ruler);
   return true;
 }
 
@@ -1602,11 +1652,11 @@ bool FullWrtText::readTextData(FullWrtStruct::EntryPtr zone)
 
   bool knownZone = (zone->m_type >= 0xa && zone->m_type <= 0x14) || (zone->m_type == 0x18);
 
-  int header = static_cast<int>(input->readULong(2));
+  auto header = static_cast<int>(input->readULong(2));
   bool hasHeader = false;
   if (!knownZone && (header&0xFC00)) return false;
 
-  shared_ptr<FullWrtTextInternal::Zone> text(new FullWrtTextInternal::Zone);
+  std::shared_ptr<FullWrtTextInternal::Zone> text(new FullWrtTextInternal::Zone);
   text->m_zoneType = (zone->m_type==0xa) ?
                      FullWrtTextInternal::Zone::Main : FullWrtTextInternal::Zone::Normal;
   text->m_zone = zone;
@@ -1692,7 +1742,7 @@ bool FullWrtText::readTextData(FullWrtStruct::EntryPtr zone)
   }
 
   // between 1 and 202 ( very similar to dim[2]
-  int dimUnk = static_cast<int>(input->readLong(2));
+  auto dimUnk = static_cast<int>(input->readLong(2));
   // two flags 0|ce|fa, 0
   for (int i = 3; i < 5; i++) {
     val = static_cast<int>(input->readLong(1));
@@ -1702,8 +1752,7 @@ bool FullWrtText::readTextData(FullWrtStruct::EntryPtr zone)
   // between 8 and 58
   f << "N3=" << static_cast<int>(input->readLong(2)) << ",";
   int dim[4]; // box with almost always y1=y0+1?
-  for (int i = 0; i < 4; i++)
-    dim[i]=static_cast<int>(input->readLong(2));
+  for (auto &d : dim) d=static_cast<int>(input->readLong(2));
   if (dimUnk != dim[2]) f << "dimUnk=" << dimUnk << ",";
 
   text->m_box=MWAWBox2f(MWAWVec2f(float(dim[0]),float(dim[1])),MWAWVec2f(float(dim[2]),float(dim[3])));
@@ -1733,7 +1782,7 @@ bool FullWrtText::readTextData(FullWrtStruct::EntryPtr zone)
   while (1) {
     pos = input->tell();
     if (pos+2 >= zone->end()) break;
-    int type = static_cast<int>(input->readULong(2));
+    auto type = static_cast<int>(input->readULong(2));
     if (input->isEnd()) {
       MWAW_DEBUG_MSG(("FullWrtText::readTextData: internal problem, unexpected EOS!!!\n"));
       return false;
@@ -1741,7 +1790,7 @@ bool FullWrtText::readTextData(FullWrtStruct::EntryPtr zone)
     int lengthSz = 1;
     if (type & 0x8000)
       lengthSz = 2;
-    int numChar = static_cast<int>(input->readULong(lengthSz));
+    auto numChar = static_cast<int>(input->readULong(lengthSz));
     if ((lengthSz==1 && (numChar & 0x80)) ||
         long(input->tell()+numChar) > zone->end()) {
       input->seek(pos, librevenge::RVNG_SEEK_SET);
@@ -1777,13 +1826,12 @@ bool FullWrtText::readTextData(FullWrtStruct::EntryPtr zone)
 #endif
   pos = text->m_end = input->tell();
   // ok, we can insert the data
-  std::multimap<int, shared_ptr<FullWrtTextInternal::Zone> >::iterator it =
-    m_state->m_entryMap.find(zone->id());
+  auto it = m_state->m_entryMap.find(zone->id());
   if (it != m_state->m_entryMap.end()) {
     MWAW_DEBUG_MSG(("FullWrtText::readTextData: entry %d already exists\n", zone->id()));
   }
   m_state->m_entryMap.insert
-  (std::multimap<int, shared_ptr<FullWrtTextInternal::Zone> >::value_type(zone->id(), text));
+  (std::multimap<int, std::shared_ptr<FullWrtTextInternal::Zone> >::value_type(zone->id(), text));
 
   f.str("");
   f << "TextData-b:";
@@ -1830,7 +1878,7 @@ bool FullWrtText::readTextData(FullWrtStruct::EntryPtr zone)
         FullWrtTextInternal::ColumnInfo col;
         col.m_column = i;
         col.m_beginPos = static_cast<int>(input->readLong(2));
-        for (int j = 0; j < 4; j++) dim[j] = static_cast<int>(input->readLong(2));
+        for (auto &d : dim) d = static_cast<int>(input->readLong(2));
         col.m_box = MWAWBox2i(MWAWVec2i(dim[0],dim[2]), MWAWVec2i(dim[1], dim[3]));
         f << col;
         page.m_columns.push_back(col);
@@ -1851,13 +1899,13 @@ bool FullWrtText::readTextData(FullWrtStruct::EntryPtr zone)
       sz = 42;
     else if (high==0x61||high==0x63) {
       input->seek(12, librevenge::RVNG_SEEK_CUR);
-      int numData = static_cast<int>(input->readULong(2));
+      auto numData = static_cast<int>(input->readULong(2));
       if (!numData) break;
       sz = 26+9*numData;
     }
     else if (high==0xe1) {
       input->seek(14, librevenge::RVNG_SEEK_CUR);
-      int numData = static_cast<int>(input->readULong(2));
+      auto numData = static_cast<int>(input->readULong(2));
       if (!numData) break;
       sz = 30+9*numData;
     }
@@ -1990,7 +2038,7 @@ bool FullWrtText::readItem(FullWrtStruct::EntryPtr zone, int id, bool hidden)
     return true;
   }
   input->seek(pos+42, librevenge::RVNG_SEEK_SET);
-  int sz = static_cast<int>(input->readULong(2));
+  auto sz = static_cast<int>(input->readULong(2));
   if (pos+44+sz > zone->end()) {
     MWAW_DEBUG_MSG(("FullWrtText::readItem: find bad data size\n"));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
@@ -1998,7 +2046,7 @@ bool FullWrtText::readItem(FullWrtStruct::EntryPtr zone, int id, bool hidden)
   }
 
   if (set && m_state->m_itemMap.find(id) != m_state->m_itemMap.end()) {
-    FullWrtTextInternal::Item &theItem = m_state->m_itemMap.find(id)->second;
+    auto &theItem = m_state->m_itemMap.find(id)->second;
     theItem.m_hiddenZone.reset(new FullWrtTextInternal::Zone);
     theItem.m_hiddenZone->m_zone = zone;
     theItem.m_hiddenZone->m_zoneType = FullWrtTextInternal::Zone::CollapsedItem;
@@ -2020,13 +2068,13 @@ bool FullWrtText::readStyle(FullWrtStruct::EntryPtr zone)
   libmwaw::DebugStream f;
   long pos=input->tell();
 
-  int sz = int(input->readLong(2));
+  auto sz = int(input->readLong(2));
   if (sz < 4 || sz >= 0x100) return false;
   if (pos+2+sz> zone->end()) return false;
   f.str("");
   f << "Entries(Style):";
   for (int i=0; i<2; ++i) { //f0: small number, f1: number between 0 and 1c: flag?
-    int val=static_cast<int>(input->readLong(2));
+    auto val=static_cast<int>(input->readLong(2));
     if (val) f << "f" << i << "=" << val << ",";
   }
   if (sz==4) {
@@ -2042,7 +2090,7 @@ bool FullWrtText::readStyle(FullWrtStruct::EntryPtr zone)
     ascii.addNote(f.str().c_str());
     return true;
   }
-  int nSz=static_cast<int>(input->readULong(1));
+  auto nSz=static_cast<int>(input->readULong(1));
   if (!nSz || nSz>0x1f) {
     f << "###";
     MWAW_DEBUG_MSG(("FullWrtText::readStyle: style name length seems odd\n"));
@@ -2075,7 +2123,7 @@ bool FullWrtText::readParagraphTabs(FullWrtStruct::EntryPtr zone, int id)
   const int headerSz = vers==1 ? 24 : 30;
   long pos = input->tell();
   input->seek(pos, librevenge::RVNG_SEEK_SET);
-  long sz = long(input->readULong(4));
+  auto sz = long(input->readULong(4));
   if (sz<24 || pos+4+sz > zone->end()) {
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     return false;
@@ -2095,11 +2143,11 @@ bool FullWrtText::readParagraphTabs(FullWrtStruct::EntryPtr zone, int id)
   }
   FullWrtTextInternal::Paragraph para;
   float dim[2];
-  for (int i = 0; i < 2; i++) // dim0: height?, dim1:width
-    dim[i] = float(input->readULong(2))/72.f;
+  for (float &i : dim)  // dim0: height?, dim1:width
+    i = float(input->readULong(2))/72.f;
   para.m_dim=MWAWVec2f(dim[1],dim[0]);
   double margins[3];
-  char const *(margNames[]) = { "left", "right", "first" };
+  char const *margNames[] = { "left", "right", "first" };
   for (int i = 0; i < 3; i++) {
     margins[i] = double(input->readLong(4))/65536./72.0;
     if (margins[i] < 0 || margins[i] > 0)
@@ -2112,7 +2160,7 @@ bool FullWrtText::readParagraphTabs(FullWrtStruct::EntryPtr zone, int id)
   ascii.addDelimiter(input->tell(), '|');
 
   input->seek(vers==1 ? pos+27 : pos+26, librevenge::RVNG_SEEK_SET);
-  int N = static_cast<int>(input->readULong(1));
+  auto N = static_cast<int>(input->readULong(1));
   if (headerSz+dataSz *N != sz) {
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     return false;
@@ -2251,14 +2299,13 @@ bool FullWrtText::readDataMod(FullWrtStruct::EntryPtr zone, int id)
     return false;
   }
   FullWrtTextInternal::DataModifier mod;
-  int val = int(input->readULong(2));
+  auto val = int(input->readULong(2));
   MWAWColor col;
   if (FullWrtStruct::getColor(val, col))
     mod.m_color = col;
   else if (val != 0xFFFF)
     f << "#col=" << std::hex << val << std::dec << ",";
-  for (int i = 0; i < 4; i++)
-    mod.m_data[i] = int(input->readULong(2));
+  for (auto &data : mod.m_data) data = int(input->readULong(2));
   mod.m_extra = f.str();
   f.str("");
   f << "Entries(DataMod):" << mod;
@@ -2351,14 +2398,14 @@ bool FullWrtText::readColumns(FullWrtStruct::EntryPtr zone)
 
   long pos = input->tell();
   input->seek(pos, librevenge::RVNG_SEEK_SET);
-  long sz = long(input->readULong(4));
+  auto sz = long(input->readULong(4));
   if (sz<34 || pos+4+sz > zone->end()) {
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     return false;
   }
 
   input->seek(13, librevenge::RVNG_SEEK_CUR);
-  int N = static_cast<int>(input->readULong(1));
+  auto N = static_cast<int>(input->readULong(1));
   if (24+10*N != sz) {
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     return false;
@@ -2372,9 +2419,9 @@ bool FullWrtText::readColumns(FullWrtStruct::EntryPtr zone)
     pos = input->tell();
     f.str("");
     f << "Columns-" << i << ":";
-    int dim[2];
+    int dim[2]; // checkme: pos as float?
     dim[0] = static_cast<int>(input->readLong(2));
-    long val = long(input->readULong(2));
+    auto val = long(input->readULong(2));
     if (val) f << "f0=" << std::hex << val << std::dec << ",";
     dim[1] = static_cast<int>(input->readLong(2));
     f << "pos=" << dim[0] << "<->" << dim[1] << ",";
@@ -2392,15 +2439,13 @@ bool FullWrtText::readColumns(FullWrtStruct::EntryPtr zone)
 //! send data to the listener
 bool FullWrtText::sendMainText()
 {
-  size_t numZones = m_state->m_mainZones.size();
-  if (!numZones) {
+  if (m_state->m_mainZones.empty()) {
     MWAW_DEBUG_MSG(("FullWrtText::sendMainText: can not find main zone\n"));
     return false;
   }
   if (!m_parserState->m_textListener) return true;
-  std::multimap<int, shared_ptr<FullWrtTextInternal::Zone> >::iterator it;
-  for (size_t i = 0; i < numZones; i++) {
-    it = m_state->m_entryMap.find(m_state->m_mainZones[i]);
+  for (auto id : m_state->m_mainZones) {
+    auto it = m_state->m_entryMap.find(id);
     if (it == m_state->m_entryMap.end() || !it->second) {
       MWAW_DEBUG_MSG(("FullWrtText::sendMainText: can not find main zone: internal problem\n"));
       continue;
@@ -2414,20 +2459,17 @@ bool FullWrtText::sendMainText()
 int FullWrtText::getHeaderFooterId(bool header, int page, int &numSimilar) const
 {
   int type=header ? 0x11 : 0x12;
-  size_t numZones = m_state->m_mainZones.size();
-  if (!numZones) {
+  if (m_state->m_mainZones.empty()) {
     numSimilar=1;
     if (m_state->m_numPages>page)
       numSimilar=m_state->m_numPages-page+1;
     return -1;
   }
-  std::multimap<int, shared_ptr<FullWrtTextInternal::Zone> >::iterator it =
-    m_state->m_entryMap.begin();
   int nextPage=-1;
   int res=-1;
-  while (it!=m_state->m_entryMap.end()) {
-    int id=it->first;
-    shared_ptr<FullWrtTextInternal::Zone> zone=it++->second;
+  for (auto it : m_state->m_entryMap) {
+    int id=it.first;
+    auto zone=it.second;
     if (!zone || !zone->m_zone || zone->m_zone->m_type!=type ||
         zone->m_pages[0]<page)
       continue;
@@ -2444,8 +2486,7 @@ int FullWrtText::getHeaderFooterId(bool header, int page, int &numSimilar) const
 
 bool FullWrtText::send(int zId, MWAWColor fontColor)
 {
-  std::multimap<int, shared_ptr<FullWrtTextInternal::Zone> >::iterator it;
-  it = m_state->m_entryMap.find(zId);
+  auto it = m_state->m_entryMap.find(zId);
   if (it == m_state->m_entryMap.end() || !it->second) {
     MWAW_DEBUG_MSG(("FullWrtText::send: can not find zone: %d\n", zId));
     return false;
@@ -2456,9 +2497,8 @@ bool FullWrtText::send(int zId, MWAWColor fontColor)
 
 void FullWrtText::flushExtra()
 {
-  std::multimap<int, shared_ptr<FullWrtTextInternal::Zone> >::iterator it;
-  for (it = m_state->m_entryMap.begin(); it != m_state->m_entryMap.end(); ++it) {
-    shared_ptr<FullWrtTextInternal::Zone> zone = it->second;
+  for (auto it : m_state->m_entryMap) {
+    std::shared_ptr<FullWrtTextInternal::Zone> &zone = it.second;
     if (!zone || !zone->m_zone || zone->m_zone->isParsed())
       continue;
     send(zone);
@@ -2467,11 +2507,10 @@ void FullWrtText::flushExtra()
 
 void FullWrtText::sortZones()
 {
-  std::multimap<int, shared_ptr<FullWrtTextInternal::Zone> >::iterator it;
   int numZones = 0, totalNumPages = 0;
   std::vector<int> pagesLimits;
-  for (it = m_state->m_entryMap.begin(); it != m_state->m_entryMap.end(); ++it) {
-    shared_ptr<FullWrtTextInternal::Zone> zone = it->second;
+  for (auto it : m_state->m_entryMap) {
+    auto &zone = it.second;
     if (!zone || !zone->m_zone || zone->m_zoneType != FullWrtTextInternal::Zone::Main)
       continue;
     int fPage = zone->m_pages[0], lPage = zone->m_pages[1];
@@ -2510,9 +2549,8 @@ void FullWrtText::sortZones()
 
 void FullWrtText::createItemStructures()
 {
-  std::map<int, FullWrtTextInternal::Item>::iterator it=m_state->m_itemMap.begin(), it2;
-  for (; it != m_state->m_itemMap.end(); ++it) {
-    FullWrtTextInternal::Item &item = it->second;
+  for (auto it=m_state->m_itemMap.begin(); it != m_state->m_itemMap.end(); ++it) {
+    auto &item = it->second;
     int childId=item.m_structId[FullWrtTextInternal::Item::Child];
     int id=item.m_structId[FullWrtTextInternal::Item::Main];
     if (childId<=0)
@@ -2525,7 +2563,7 @@ void FullWrtText::createItemStructures()
         break;
       }
       seens.insert(childId);
-      it2=m_state->m_itemMap.find(childId);
+      auto it2=m_state->m_itemMap.find(childId);
       if (it2==m_state->m_itemMap.end()) {
         MWAW_DEBUG_MSG(("FullWrtText::createItemStructures: can not find child: %d\n", childId));
         break;
