@@ -57,13 +57,16 @@
 namespace HanMacWrdKTextInternal
 {
 /** Internal: class to store the paragraph properties of a HanMacWrdKText */
-struct Paragraph : public MWAWParagraph {
+struct Paragraph final : public MWAWParagraph {
   //! Constructor
-  Paragraph() : MWAWParagraph(), m_type(0), m_addPageBreak(false)
+  Paragraph()
+    : MWAWParagraph()
+    , m_type(0)
+    , m_addPageBreak(false)
   {
   }
   //! destructor
-  ~Paragraph();
+  ~Paragraph() final;
   //! operator<<
   friend std::ostream &operator<<(std::ostream &o, Paragraph const &ind)
   {
@@ -100,7 +103,12 @@ Paragraph::~Paragraph()
 /** Internal: class to store a section of a HanMacWrdKText */
 struct Section {
   //! constructor
-  Section() : m_numCols(1), m_colWidth(), m_colSep(), m_id(0), m_extra("")
+  Section()
+    : m_numCols(1)
+    , m_colWidth()
+    , m_colSep()
+    , m_id(0)
+    , m_extra("")
   {
   }
   //! returns a MWAWSection
@@ -138,7 +146,7 @@ struct Section {
   {
     if (sec.m_numCols!=1)
       o << "numCols=" << sec.m_numCols << ",";
-    if (sec.m_colWidth.size()) {
+    if (!sec.m_colWidth.empty()) {
       o << "colWidth=[";
       for (size_t i = 0; i < sec.m_colWidth.size(); i++)
         o << sec.m_colWidth[i] << ":" << sec.m_colSep[i] << ",";
@@ -164,7 +172,10 @@ struct Section {
 /** Internal: class to store the token properties of a HanMacWrdKText */
 struct Token {
   //! Constructor
-  Token() : m_type(0), m_id(-1), m_extra("")
+  Token()
+    : m_type(0)
+    , m_id(-1)
+    , m_extra("")
   {
   }
   //! destructor
@@ -224,15 +235,23 @@ struct Token {
 //! Internal: the state of a HanMacWrdKText
 struct State {
   //! constructor
-  State() : m_version(-1), m_IdTextMaps(), m_IdTypeMaps(), m_tokenIdList(), m_sectionList(), m_numPages(-1), m_actualPage(0),
-    m_headerId(0), m_footerId(0)
+  State()
+    : m_version(-1)
+    , m_IdTextMaps()
+    , m_IdTypeMaps()
+    , m_tokenIdList()
+    , m_sectionList()
+    , m_numPages(-1)
+    , m_actualPage(0)
+    , m_headerId(0)
+    , m_footerId(0)
   {
   }
 
   //! the file version
   mutable int m_version;
   //! the map of id -> text zone
-  std::multimap<long, shared_ptr<HanMacWrdKZone> > m_IdTextMaps;
+  std::multimap<long, std::shared_ptr<HanMacWrdKZone> > m_IdTextMaps;
   //! the zone frame type if known
   std::map<long,int> m_IdTypeMaps;
   //! the token id list
@@ -248,7 +267,7 @@ struct State {
 
 Section getSection(const State &state, const long id)
 {
-  const std::map<long, Section>::const_iterator it = state.m_sectionList.find(id);
+  auto it = state.m_sectionList.find(id);
   if (it != state.m_sectionList.end())
     return it->second;
   MWAW_DEBUG_MSG(("HanMacWrdKTextInternal::getSection: can not find section %ld\n", id));
@@ -260,8 +279,10 @@ Section getSection(const State &state, const long id)
 ////////////////////////////////////////////////////////////
 // constructor/destructor, ...
 ////////////////////////////////////////////////////////////
-HanMacWrdKText::HanMacWrdKText(HanMacWrdKParser &parser) :
-  m_parserState(parser.getParserState()), m_state(new HanMacWrdKTextInternal::State), m_mainParser(&parser)
+HanMacWrdKText::HanMacWrdKText(HanMacWrdKParser &parser)
+  : m_parserState(parser.getParserState())
+  , m_state(new HanMacWrdKTextInternal::State)
+  , m_mainParser(&parser)
 {
 }
 
@@ -279,10 +300,9 @@ int HanMacWrdKText::version() const
 int HanMacWrdKText::numPages() const
 {
   int nPages = 1;
-  std::multimap<long, shared_ptr<HanMacWrdKZone> >::iterator tIt=m_state->m_IdTextMaps.begin();
-  for (; tIt!=m_state->m_IdTextMaps.end(); ++tIt) {
-    if (!tIt->second) continue;
-    int pages = const_cast<HanMacWrdKText *>(this)->computeNumPages(*tIt->second);
+  for (auto tIt : m_state->m_IdTextMaps) {
+    if (!tIt.second) continue;
+    int pages = const_cast<HanMacWrdKText *>(this)->computeNumPages(*tIt.second);
     if (pages > nPages) nPages=pages;
   }
   m_state->m_numPages = nPages;
@@ -307,12 +327,11 @@ void HanMacWrdKText::updateTextZoneTypes(std::map<long,int> const &idTypeMap)
     m_state->m_IdTypeMaps[m_state->m_headerId]=1;
   if (m_state->m_footerId)
     m_state->m_IdTypeMaps[m_state->m_footerId]=1;
-  std::multimap<long, shared_ptr<HanMacWrdKZone> >::iterator tIt;
   int numUnkns=0;
-  for (tIt=m_state->m_IdTextMaps.begin(); tIt!=m_state->m_IdTextMaps.end(); ++tIt) {
-    if (m_state->m_IdTypeMaps.find(tIt->first)!=m_state->m_IdTypeMaps.end())
+  for (auto tIt : m_state->m_IdTextMaps) {
+    if (m_state->m_IdTypeMaps.find(tIt.first)!=m_state->m_IdTypeMaps.end())
       continue;
-    m_state->m_IdTypeMaps[tIt->first]=0;
+    m_state->m_IdTypeMaps[tIt.first]=0;
     numUnkns++;
   }
   if (numUnkns!=1) {
@@ -351,10 +370,10 @@ int HanMacWrdKText::computeNumPages(HanMacWrdKZone const &zone) const
   input->seek(0, librevenge::RVNG_SEEK_SET);
   while (!input->isEnd()) {
     pos = input->tell();
-    long val = long(input->readULong(1));
+    auto val = long(input->readULong(1));
     if (val != 1 || input->readLong(1) != 0) break;
 
-    int type = static_cast<int>(input->readLong(2));
+    auto type = static_cast<int>(input->readLong(2));
     bool done=false;
     switch (type) {
     case 1: {
@@ -381,7 +400,7 @@ int HanMacWrdKText::computeNumPages(HanMacWrdKZone const &zone) const
     case 4: {
       actCol = 0;
       actPage++;
-      HanMacWrdKTextInternal::Section const &sec = getSection(*m_state, actSection++);
+      auto const &sec = getSection(*m_state, actSection++);
       numCol = sec.m_numCols >= 1 ? sec.m_numCols : 1;
       break;
     }
@@ -391,14 +410,14 @@ int HanMacWrdKText::computeNumPages(HanMacWrdKZone const &zone) const
 
     if (!done) {
       input->seek(pos+4, librevenge::RVNG_SEEK_SET);
-      long sz = long(input->readULong(2));
+      auto sz = long(input->readULong(2));
       if (pos+6+sz>endPos)
         break;
       input->seek(pos+6+sz, librevenge::RVNG_SEEK_SET);
     }
     bool ok=true;
     while (!input->isEnd()) {
-      int c=static_cast<int>(input->readLong(2));
+      auto c=static_cast<int>(input->readLong(2));
       if (c==0x100) {
         input->seek(-2, librevenge::RVNG_SEEK_CUR);
         break;
@@ -426,14 +445,14 @@ int HanMacWrdKText::computeNumPages(HanMacWrdKZone const &zone) const
   return actPage;
 }
 
-bool HanMacWrdKText::readTextZone(shared_ptr<HanMacWrdKZone> zone)
+bool HanMacWrdKText::readTextZone(std::shared_ptr<HanMacWrdKZone> zone)
 {
   if (!zone || !zone->valid()) {
     MWAW_DEBUG_MSG(("HanMacWrdKText::readTextZone: called without any zone\n"));
     return false;
   }
   m_state->m_IdTextMaps.insert
-  (std::multimap<long, shared_ptr<HanMacWrdKZone> >::value_type(zone->m_id, zone));
+  (std::multimap<long, std::shared_ptr<HanMacWrdKZone> >::value_type(zone->m_id, zone));
   long endPos = zone->end();
   MWAWInputStreamPtr input = zone->m_input;
   input->seek(zone->begin(), librevenge::RVNG_SEEK_SET);
@@ -442,11 +461,11 @@ bool HanMacWrdKText::readTextZone(shared_ptr<HanMacWrdKZone> zone)
     long pos = input->tell();
     if (pos >= endPos)
       break;
-    long val = long(input->readULong(1));
+    auto val = long(input->readULong(1));
     if (val == 0 && input->isEnd()) break;
     if (val != 1 || input->readLong(1) != 0)
       break;
-    int type = static_cast<int>(input->readLong(2));
+    auto type = static_cast<int>(input->readLong(2));
     bool done=false;
     switch (type) {
     case 2: { // ruler
@@ -467,7 +486,7 @@ bool HanMacWrdKText::readTextZone(shared_ptr<HanMacWrdKZone> zone)
 
     if (!done) {
       input->seek(pos+4, librevenge::RVNG_SEEK_SET);
-      long sz = long(input->readULong(2));
+      auto sz = long(input->readULong(2));
       if (pos+6+sz > endPos)
         break;
       input->seek(pos+6+sz, librevenge::RVNG_SEEK_SET);
@@ -475,7 +494,7 @@ bool HanMacWrdKText::readTextZone(shared_ptr<HanMacWrdKZone> zone)
 
     bool ok=true;
     while (!input->isEnd()) {
-      int c=static_cast<int>(input->readLong(2));
+      auto c=static_cast<int>(input->readLong(2));
       if (c==0x100) {
         input->seek(-2, librevenge::RVNG_SEEK_CUR);
         break;
@@ -495,12 +514,11 @@ bool HanMacWrdKText::readTextZone(shared_ptr<HanMacWrdKZone> zone)
 
 bool HanMacWrdKText::canSendTextAsGraphic(long id, long subId)
 {
-  std::multimap<long, shared_ptr<HanMacWrdKZone> >::iterator tIt
-    =m_state->m_IdTextMaps.lower_bound(id);
+  auto tIt=m_state->m_IdTextMaps.lower_bound(id);
   if (tIt == m_state->m_IdTextMaps.end() || tIt->first != id)
     return false;
   while (tIt != m_state->m_IdTextMaps.end() && tIt->first == id) {
-    shared_ptr<HanMacWrdKZone> zone = (tIt++)->second;
+    auto zone = (tIt++)->second;
     if (!zone || zone->m_subId != subId) continue;
     return canSendTextAsGraphic(*zone);
   }
@@ -509,14 +527,13 @@ bool HanMacWrdKText::canSendTextAsGraphic(long id, long subId)
 
 bool HanMacWrdKText::sendText(long id, long subId, MWAWListenerPtr listener)
 {
-  std::multimap<long, shared_ptr<HanMacWrdKZone> >::iterator tIt
-    =m_state->m_IdTextMaps.lower_bound(id);
+  auto tIt=m_state->m_IdTextMaps.lower_bound(id);
   if (tIt == m_state->m_IdTextMaps.end() || tIt->first != id) {
     MWAW_DEBUG_MSG(("HanMacWrdKText::sendText: can not find the text zone\n"));
     return false;
   }
   while (tIt != m_state->m_IdTextMaps.end() && tIt->first == id) {
-    shared_ptr<HanMacWrdKZone> zone = (tIt++)->second;
+    auto zone = (tIt++)->second;
     if (!zone || zone->m_subId != subId) continue;
     sendText(*zone, listener);
     return true;
@@ -527,11 +544,10 @@ bool HanMacWrdKText::sendText(long id, long subId, MWAWListenerPtr listener)
 
 bool HanMacWrdKText::sendMainText()
 {
-  std::map<long, int>::iterator tIt=m_state->m_IdTypeMaps.begin();
-  for (; tIt!=m_state->m_IdTypeMaps.end(); ++tIt) {
-    if (tIt->second != 0)
+  for (auto tIt : m_state->m_IdTypeMaps) {
+    if (tIt.second != 0)
       continue;
-    sendText(tIt->first, 0);
+    sendText(tIt.first, 0);
     return true;
   }
   MWAW_DEBUG_MSG(("HanMacWrdKText::sendMainText: can not find the main zone\n"));
@@ -554,11 +570,11 @@ bool HanMacWrdKText::canSendTextAsGraphic(HanMacWrdKZone &zone)
     pos = input->tell();
     if (pos>=endPos)
       break;
-    long val = long(input->readULong(1));
+    auto val = long(input->readULong(1));
     if (val == 0 && input->isEnd()) break;
     if (val != 1 || input->readLong(1) != 0)
       return false;
-    int type = static_cast<int>(input->readLong(2));
+    auto type = static_cast<int>(input->readLong(2));
     bool done=false;
     switch (type) {
     case 1:
@@ -582,12 +598,12 @@ bool HanMacWrdKText::canSendTextAsGraphic(HanMacWrdKZone &zone)
 
     if (!done) {
       input->seek(pos+4, librevenge::RVNG_SEEK_SET);
-      long sz = long(input->readULong(2));
+      auto sz = long(input->readULong(2));
       if (pos+6+sz > endPos) return false;
     }
 
     while (!input->isEnd()) {
-      int c=static_cast<int>(input->readULong(2));
+      auto c=static_cast<int>(input->readULong(2));
       if (c==0x100) {
         input->seek(-2, librevenge::RVNG_SEEK_CUR);
         break;
@@ -629,7 +645,7 @@ bool HanMacWrdKText::sendText(HanMacWrdKZone &zone, MWAWListenerPtr listener)
   if (m_state->m_IdTypeMaps.find(zone.m_id)!= m_state->m_IdTypeMaps.end())
     isMain = m_state->m_IdTypeMaps.find(zone.m_id)->second == 0;
   int actPage = 1, actCol = 0, numCol=1, actSection = 1;
-  float width = float(72.0*m_mainParser->getPageWidth());
+  auto width = float(72.0*m_mainParser->getPageWidth());
 
   if (isMain)
     m_mainParser->newPage(1);
@@ -637,7 +653,7 @@ bool HanMacWrdKText::sendText(HanMacWrdKZone &zone, MWAWListenerPtr listener)
     MWAW_DEBUG_MSG(("HanMacWrdKText::sendText: can not find section 0\n"));
   }
   else if (isMain) {
-    HanMacWrdKTextInternal::Section sec = getSection(*m_state, 0);
+    auto sec = getSection(*m_state, 0);
     if (sec.m_numCols >= 1 && sec.m_colWidth.size() > 0) {
       if (listener->isSectionOpened())
         listener->closeSection();
@@ -652,7 +668,7 @@ bool HanMacWrdKText::sendText(HanMacWrdKZone &zone, MWAWListenerPtr listener)
       break;
     f.str("");
     f << zone.name()<< ":";
-    long val = long(input->readULong(1));
+    auto val = long(input->readULong(1));
     if (val == 0 && input->isEnd()) break;
     if (val != 1 || input->readLong(1) != 0) {
       f << "###";
@@ -660,7 +676,7 @@ bool HanMacWrdKText::sendText(HanMacWrdKZone &zone, MWAWListenerPtr listener)
       asciiFile.addNote(f.str().c_str());
       break;
     }
-    int type = static_cast<int>(input->readLong(2));
+    auto type = static_cast<int>(input->readLong(2));
     bool done=false;
     switch (type) {
     case 1: {
@@ -713,7 +729,7 @@ bool HanMacWrdKText::sendText(HanMacWrdKZone &zone, MWAWListenerPtr listener)
         break;
       }
       {
-        HanMacWrdKTextInternal::Section sec = getSection(*m_state, actSection++);
+        auto sec = getSection(*m_state, actSection++);
         actCol = 0;
         if (listener->isSectionOpened())
           listener->closeSection();
@@ -747,7 +763,7 @@ bool HanMacWrdKText::sendText(HanMacWrdKZone &zone, MWAWListenerPtr listener)
     bool ok=true;
     if (!done) {
       input->seek(pos+4, librevenge::RVNG_SEEK_SET);
-      long sz = long(input->readULong(2));
+      auto sz = long(input->readULong(2));
       ok = pos+6+sz <= endPos;
       if (!ok)
         f << "###";
@@ -766,7 +782,7 @@ bool HanMacWrdKText::sendText(HanMacWrdKZone &zone, MWAWListenerPtr listener)
     f.str("");
     f << zone.name()<< ":text,";
     while (!input->isEnd()) {
-      int c=static_cast<int>(input->readULong(2));
+      auto c=static_cast<int>(input->readULong(2));
       if (c==0x100) {
         input->seek(-2, librevenge::RVNG_SEEK_CUR);
         break;
@@ -885,7 +901,7 @@ bool HanMacWrdKText::readFont(HanMacWrdKZone const &zone, MWAWFont &font) const
   }
 
   libmwaw::DebugStream f;
-  int val = static_cast<int>(input->readLong(2));
+  auto val = static_cast<int>(input->readLong(2));
   if (val!=28) {
     MWAW_DEBUG_MSG(("HanMacWrdKText::readFont: the data size seems bad\n"));
     f << "##dataSz=" << val << ",";
@@ -901,7 +917,7 @@ bool HanMacWrdKText::readFont(HanMacWrdKZone const &zone, MWAWFont &font) const
   if (xScale < 1 || xScale > 1)
     font.setWidthStreching(xScale);
 
-  int flag =static_cast<int>(input->readULong(2));
+  auto flag =static_cast<int>(input->readULong(2));
   uint32_t flags=0;
   if (flag&1) {
     font.setUnderlineStyle(MWAWFont::Line::Simple);
@@ -963,7 +979,7 @@ bool HanMacWrdKText::readFont(HanMacWrdKZone const &zone, MWAWFont &font) const
     font.setUnderlineType(MWAWFont::Line::Double);
     font.setUnderlineWidth(0.5);
   }
-  int color = static_cast<int>(input->readLong(2));
+  auto color = static_cast<int>(input->readLong(2));
   MWAWColor col;
   if (color && m_mainParser->getColor(color, 1, col))
     font.setColor(col);
@@ -972,7 +988,7 @@ bool HanMacWrdKText::readFont(HanMacWrdKZone const &zone, MWAWFont &font) const
   val = static_cast<int>(input->readLong(2));
   if (val) f << "#unk=" << val << ",";
   color = static_cast<int>(input->readLong(2));
-  int pattern = static_cast<int>(input->readLong(2));
+  auto pattern = static_cast<int>(input->readLong(2));
   if ((color || pattern) && m_mainParser->getColor(color, pattern, col))
     font.setBackgroundColor(col);
   else if (color || pattern)
@@ -998,7 +1014,7 @@ bool HanMacWrdKText::readFont(HanMacWrdKZone const &zone, MWAWFont &font) const
 }
 
 // the list of fonts
-bool HanMacWrdKText::readFontNames(shared_ptr<HanMacWrdKZone> zone)
+bool HanMacWrdKText::readFontNames(std::shared_ptr<HanMacWrdKZone> zone)
 {
   if (!zone) {
     MWAW_DEBUG_MSG(("HanMacWrdKText::readFontNames: called without any zone\n"));
@@ -1018,7 +1034,7 @@ bool HanMacWrdKText::readFontNames(shared_ptr<HanMacWrdKZone> zone)
 
   long pos = zone->begin();
   input->seek(pos, librevenge::RVNG_SEEK_SET);
-  int N = static_cast<int>(input->readLong(2));
+  auto N = static_cast<int>(input->readLong(2));
   f << "N=" << N << ",";
   long expectedSz = N*68+2;
   if (expectedSz != dataSz && expectedSz+1 != dataSz) {
@@ -1032,12 +1048,12 @@ bool HanMacWrdKText::readFontNames(shared_ptr<HanMacWrdKZone> zone)
     pos = input->tell();
     f.str("");
     f << zone->name() << "-" << i << ":";
-    int fId = static_cast<int>(input->readLong(2));
+    auto fId = static_cast<int>(input->readLong(2));
     f << "fId=" << fId << ",";
-    int val = static_cast<int>(input->readLong(2));
+    auto val = static_cast<int>(input->readLong(2));
     if (val != fId)
       f << "#fId2=" << val << ",";
-    int fSz = static_cast<int>(input->readULong(1));
+    auto fSz = static_cast<int>(input->readULong(1));
     if (fSz+5 > 68) {
       f << "###fSz";
       MWAW_DEBUG_MSG(("HanMacWrdKText::readFontNames: can not read a font\n"));
@@ -1059,7 +1075,7 @@ bool HanMacWrdKText::readFontNames(shared_ptr<HanMacWrdKZone> zone)
 ////////////////////////////////////////////////////////////
 //     Style
 ////////////////////////////////////////////////////////////
-bool HanMacWrdKText::readStyles(shared_ptr<HanMacWrdKZone> zone)
+bool HanMacWrdKText::readStyles(std::shared_ptr<HanMacWrdKZone> zone)
 {
   if (!zone) {
     MWAW_DEBUG_MSG(("HanMacWrdKText::readStyles: called without any zone\n"));
@@ -1081,7 +1097,7 @@ bool HanMacWrdKText::readStyles(shared_ptr<HanMacWrdKZone> zone)
   long pos = zone->begin();
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   long fieldSz = 636;
-  int N = static_cast<int>(input->readULong(2));
+  auto N = static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
   long expectedSz = N*fieldSz+2;
   if (expectedSz != dataSz && expectedSz+1 != dataSz) {
@@ -1095,7 +1111,7 @@ bool HanMacWrdKText::readStyles(shared_ptr<HanMacWrdKZone> zone)
     f.str("");
     f << zone->name() << "-" << i << ":";
     pos = input->tell();
-    int val = static_cast<int>(input->readULong(2));
+    auto val = static_cast<int>(input->readULong(2));
     if (val != i) f << "#id=" << val << ",";
 
     // f0=c2|c6, f2=0|44, f3=1|14|15|16: fontId?
@@ -1157,7 +1173,7 @@ bool HanMacWrdKText::readStyles(shared_ptr<HanMacWrdKZone> zone)
     if (val != -1) f << "unkn=" << val << ",";
     val  = static_cast<int>(input->readLong(2));
     if (val != i) f << "#id" << val << ",";
-    int fSz = static_cast<int>(input->readULong(1));
+    auto fSz = static_cast<int>(input->readULong(1));
     if (input->tell()+fSz > pos+fieldSz) {
       MWAW_DEBUG_MSG(("HanMacWrdKText::readStyles: can not read styleName\n"));
       f << "###";
@@ -1206,12 +1222,12 @@ bool HanMacWrdKText::readParagraph(HanMacWrdKZone const &zone, HanMacWrdKTextInt
 
   libmwaw::DebugStream f;
   libmwaw::DebugFile &asciiFile = zone.ascii();
-  int val = static_cast<int>(input->readLong(2));
+  auto val = static_cast<int>(input->readLong(2));
   if (val!=100) {
     MWAW_DEBUG_MSG(("HanMacWrdKText::readParagraph: the data size seems bad\n"));
     f << "##dataSz=" << val << ",";
   }
-  int flags = static_cast<int>(input->readULong(1));
+  auto flags = static_cast<int>(input->readULong(1));
   if (flags&0x80)
     para.m_breakStatus = para.m_breakStatus.get()|MWAWParagraph::NoBreakWithNextBit;
   if (flags&0x40)
@@ -1248,18 +1264,16 @@ bool HanMacWrdKText::readParagraph(HanMacWrdKZone const &zone, HanMacWrdKTextInt
   para.m_type = static_cast<int>(input->readLong(2));
 
   float dim[3];
-  for (int i = 0; i < 3; i++)
-    dim[i] = float(input->readLong(4))/65536.0f;
+  for (auto &d : dim) d = float(input->readLong(4))/65536.0f;
   para.m_marginsUnit = librevenge::RVNG_POINT;
   para.m_margins[0]=double(dim[1]);
   para.m_margins[1]=double(dim[0]);
   para.m_margins[2]=double(dim[2]); // ie. distance to right border - ...
 
-  for (int i = 0; i < 3; i++)
-    para.m_spacings[i] = double(input->readLong(4))/65536.0;
+  for (auto &spacing : para.m_spacings)
+    spacing = double(input->readLong(4))/65536.0;
   int spacingsUnit[3]; // 1=mm, ..., 4=pt, b=line
-  for (int i = 0; i < 3; i++)
-    spacingsUnit[i] = static_cast<int>(input->readULong(1));
+  for (auto &unit : spacingsUnit) unit = static_cast<int>(input->readULong(1));
   if (spacingsUnit[0]==0xb)
     para.m_spacingsInterlineUnit = librevenge::RVNG_PERCENT;
   else
@@ -1274,10 +1288,10 @@ bool HanMacWrdKText::readParagraph(HanMacWrdKZone const &zone, HanMacWrdKTextInt
     if (val) f << "#f" << i+4 << "=" << std::hex << val << std::dec << ",";
   }
   // the borders
-  char const *(wh[5]) = { "T", "L", "B", "R", "VSep" };
+  char const *wh[5] = { "T", "L", "B", "R", "VSep" };
   MWAWBorder borders[5];
-  for (int d=0; d < 5; d++)
-    borders[d].m_width = double(input->readLong(4))/65536.;
+  for (auto &border : borders)
+    border.m_width = double(input->readLong(4))/65536.;
   for (int d=0; d < 5; d++) {
     val = static_cast<int>(input->readULong(1));
     switch (val) {
@@ -1300,10 +1314,8 @@ bool HanMacWrdKText::readParagraph(HanMacWrdKZone const &zone, HanMacWrdKTextInt
     }
   }
   int color[5], pattern[5];
-  for (int d=0; d < 5; d++)
-    color[d] = static_cast<int>(input->readULong(1));
-  for (int d=0; d < 5; d++)
-    pattern[d] = static_cast<int>(input->readULong(2));
+  for (auto &c : color) c = static_cast<int>(input->readULong(1));
+  for (auto &p : pattern) p = static_cast<int>(input->readULong(2));
   for (int d=0; d < 5; d++) {
     if (!pattern[d]) {
       borders[d].m_style=MWAWBorder::None;
@@ -1319,7 +1331,7 @@ bool HanMacWrdKText::readParagraph(HanMacWrdKZone const &zone, HanMacWrdKTextInt
   }
   // update the paragraph
   para.resizeBorders(6);
-  libmwaw::Position const(which[5]) = {
+  libmwaw::Position const which[5] = {
     libmwaw::Top, libmwaw::Left, libmwaw::Bottom, libmwaw::Right,
     libmwaw::VMiddle
   };
@@ -1336,7 +1348,7 @@ bool HanMacWrdKText::readParagraph(HanMacWrdKZone const &zone, HanMacWrdKTextInt
     if (bMargins[d] > 0 || bMargins[d] < 0)
       f << "bordMarg" << wh[d] << "=" << bMargins[d] << ",";
   }
-  int nTabs = static_cast<int>(input->readULong(1));
+  auto nTabs = static_cast<int>(input->readULong(1));
   if (pos+102+nTabs*12 > dataSz) {
     MWAW_DEBUG_MSG(("HanMacWrdKText::readParagraph: can not read numbers of tab\n"));
     return false;
@@ -1431,7 +1443,7 @@ bool HanMacWrdKText::readToken(HanMacWrdKZone const &zone, HanMacWrdKTextInterna
 
   libmwaw::DebugStream f;
   libmwaw::DebugFile &asciiFile = zone.ascii();
-  int val = static_cast<int>(input->readLong(2));
+  auto val = static_cast<int>(input->readLong(2));
   if (val!=8) {
     MWAW_DEBUG_MSG(("HanMacWrdKText::readToken: the data size seems bad\n"));
     f << "##dataSz=" << val << ",";
@@ -1462,7 +1474,7 @@ bool HanMacWrdKText::readToken(HanMacWrdKZone const &zone, HanMacWrdKTextInterna
 ////////////////////////////////////////////////////////////
 //     the sections
 ////////////////////////////////////////////////////////////
-bool HanMacWrdKText::readSections(shared_ptr<HanMacWrdKZone> zone)
+bool HanMacWrdKText::readSections(std::shared_ptr<HanMacWrdKZone> zone)
 {
   if (!zone) {
     MWAW_DEBUG_MSG(("HanMacWrdKText::readSections: called without any zone\n"));
@@ -1485,7 +1497,7 @@ bool HanMacWrdKText::readSections(shared_ptr<HanMacWrdKZone> zone)
   long val = input->readLong(2);
   if (val != 1) // always 1
     f << "f0=" << val << ",";
-  int numColumns = static_cast<int>(input->readLong(2));
+  auto numColumns = static_cast<int>(input->readLong(2));
   if (numColumns <= 0 || numColumns > 8) {
     MWAW_DEBUG_MSG(("HanMacWrdKText::readSections: numColumns seems bad\n"));
     f << "###nCols=" << numColumns << ",";
@@ -1568,11 +1580,9 @@ bool HanMacWrdKText::readSections(shared_ptr<HanMacWrdKZone> zone)
 void HanMacWrdKText::flushExtra()
 {
   if (!m_parserState->m_textListener) return;
-  std::multimap<long, shared_ptr<HanMacWrdKZone> >::iterator tIt
-    =m_state->m_IdTextMaps.begin();
-  for (; tIt!=m_state->m_IdTextMaps.end(); ++tIt) {
-    if (!tIt->second) continue;
-    HanMacWrdKZone &zone = *tIt->second;
+  for (auto tIt : m_state->m_IdTextMaps) {
+    if (!tIt.second) continue;
+    HanMacWrdKZone &zone = *tIt.second;
     if (zone.m_parsed) continue;
     sendText(zone);
   }
