@@ -111,9 +111,9 @@ bool MWAWGraphicStyle::Pattern::getAverageColor(MWAWColor &color) const
     return true;
   }
   int numOne=0, numZero=0;
-  for (size_t c=0; c < m_data.size(); ++c) {
+  for (auto data : m_data) {
     for (int depl=1, b=0; b < 8; ++b, depl*=2) {
-      if (m_data[c] & depl)
+      if (data & depl)
         numOne++;
       else
         numZero++;
@@ -141,8 +141,8 @@ bool MWAWGraphicStyle::Pattern::getBinary(MWAWEmbeddedObject &picture) const
    */
   MWAWPictBitmapIndexed bitmap(m_dim);
   std::vector<MWAWColor> colors;
-  for (int i=0; i < 2; ++i)
-    colors.push_back(m_colors[i]);
+  for (auto color : m_colors)
+    colors.push_back(color);
   bitmap.setColors(colors);
   int numBytesByLines = m_dim[0]/8;
   unsigned char const *ptr = &m_data[0];
@@ -311,11 +311,11 @@ void MWAWGraphicStyle::addTo(librevenge::RVNGPropertyList &list, bool only1D) co
     }
     else {
       librevenge::RVNGPropertyListVector gradient;
-      for (size_t s=0; s < m_gradientStopList.size(); ++s) {
+      for (auto const &gr : m_gradientStopList) {
         librevenge::RVNGPropertyList grad;
-        grad.insert("svg:offset", double(m_gradientStopList[s].m_offset), librevenge::RVNG_PERCENT);
-        grad.insert("svg:stop-color", m_gradientStopList[s].m_color.str().c_str());
-        grad.insert("svg:stop-opacity", double(m_gradientStopList[s].m_opacity), librevenge::RVNG_PERCENT);
+        grad.insert("svg:offset", double(gr.m_offset), librevenge::RVNG_PERCENT);
+        grad.insert("svg:stop-color", gr.m_color.str().c_str());
+        grad.insert("svg:stop-opacity", double(gr.m_opacity), librevenge::RVNG_PERCENT);
         gradient.append(grad);
       }
       list.insert("svg:linearGradient", gradient);
@@ -464,8 +464,8 @@ int MWAWGraphicStyle::cmp(MWAWGraphicStyle const &a) const
   if (m_gradientAngle > a.m_gradientAngle) return 1;
   if (m_gradientStopList.size() < a.m_gradientStopList.size()) return 1;
   if (m_gradientStopList.size() > a.m_gradientStopList.size()) return -1;
-  for (size_t c=0; c < m_gradientStopList.size(); ++c) {
-    diff = m_gradientStopList[c].cmp(m_gradientStopList[c]);
+  for (auto c : m_gradientStopList) {
+    diff = c.cmp(c);
     if (diff) return diff;
   }
   if (m_gradientBorder < a.m_gradientBorder) return -1;
@@ -510,8 +510,8 @@ std::ostream &operator<<(std::ostream &o, MWAWGraphicStyle const &st)
     o << "width=" << st.m_lineWidth << ",";
   if (!st.m_lineDashWidth.empty()) {
     o << "dash=[";
-    for (size_t d=0; d < st.m_lineDashWidth.size(); ++d)
-      o << st.m_lineDashWidth[d] << ",";
+    for (auto w : st.m_lineDashWidth)
+      o << w << ",";
     o << "],";
   }
   switch (st.m_lineCap) {
@@ -589,8 +589,8 @@ std::ostream &operator<<(std::ostream &o, MWAWGraphicStyle const &st)
     if (st.m_gradientAngle>0 || st.m_gradientAngle<0) o << "angle=" << st.m_gradientAngle << ",";
     if (st.m_gradientStopList.size() >= 2) {
       o << "stops=[";
-      for (size_t s=0; s < st.m_gradientStopList.size(); ++s)
-        o << "[" << st.m_gradientStopList[s] << "],";
+      for (auto const &grad : st.m_gradientStopList)
+        o << "[" << grad << "],";
       o << "],";
     }
     if (st.m_gradientBorder>0) o << "border=" << st.m_gradientBorder*100 << "%,";
