@@ -56,7 +56,8 @@ class CompObj
 {
 public:
   //! the constructor
-  CompObj() : m_mapCls()
+  CompObj()
+    : m_mapCls()
   {
     initCLSMap();
   }
@@ -64,7 +65,7 @@ public:
   /** return the CLS Name corresponding to an identifier */
   char const *getCLSName(unsigned long v)
   {
-    if (m_mapCls.find(v) == m_mapCls.end()) return 0L;
+    if (m_mapCls.find(v) == m_mapCls.end()) return nullptr;
     return m_mapCls[v];
   }
 
@@ -186,7 +187,14 @@ protected:
 
 /** Internal: internal method to keep ole definition */
 struct OleDef {
-  OleDef() : m_id(-1), m_subId(-1), m_dir(""), m_base(""), m_name("") { }
+  OleDef()
+    : m_id(-1)
+    , m_subId(-1)
+    , m_dir("")
+    , m_base("")
+    , m_name("")
+  {
+  }
   int m_id /**main id*/, m_subId /**subsversion id */ ;
   std::string m_dir/**the directory*/, m_base/**the base*/, m_name/**the complete name*/;
 };
@@ -194,15 +202,25 @@ struct OleDef {
 /** Internal: internal state of a MWAWOLEParser */
 struct State {
   /** constructor */
-  State(MWAWFontConverterPtr fontConverter, int fId)
-    : m_fontConverter(fontConverter), m_fontId(fId), m_metaData(), m_unknownOLEs(),
-      m_objects(), m_objectsPosition(), m_objectsId(), m_objectsType(), m_compObjIdName()
+  State(MWAWFontConverterPtr const &fontConverter, int fId)
+    : m_fontConverter(fontConverter)
+    , m_fontId(fId)
+    , m_encoding(-1)
+    , m_metaData()
+    , m_unknownOLEs()
+    , m_objects()
+    , m_objectsPosition()
+    , m_objectsId()
+    , m_objectsType()
+    , m_compObjIdName()
   {
   }
   //! the font converter
   MWAWFontConverterPtr m_fontConverter;
   //! the font id used to decode string
   int m_fontId;
+  //! the font encoding
+  int m_encoding;
   //! the meta data
   librevenge::RVNGPropertyList m_metaData;
   //! list of ole which can not be parsed
@@ -218,13 +236,14 @@ struct State {
   std::vector<std::string> m_objectsType;
 
   //! a smart ptr used to stored the list of compobj id->name
-  shared_ptr<MWAWOLEParserInternal::CompObj> m_compObjIdName;
+  std::shared_ptr<MWAWOLEParserInternal::CompObj> m_compObjIdName;
 };
 }
 
 // constructor/destructor
-MWAWOLEParser::MWAWOLEParser(std::string mainName, MWAWFontConverterPtr fontConverter, int fId)
-  : m_avoidOLE(mainName), m_state(new MWAWOLEParserInternal::State(fontConverter, fId))
+MWAWOLEParser::MWAWOLEParser(std::string const &mainName, MWAWFontConverterPtr const &fontConverter, int fId)
+  : m_avoidOLE(mainName)
+  , m_state(new MWAWOLEParserInternal::State(fontConverter, fId))
 {
 }
 
@@ -232,6 +251,11 @@ MWAWOLEParser::~MWAWOLEParser()
 {
 }
 
+int MWAWOLEParser::getFontEncoding() const
+{
+  return m_state->m_encoding;
+}
+
 void MWAWOLEParser::updateMetaData(librevenge::RVNGPropertyList &metaData) const
 {
   librevenge::RVNGPropertyList::Iter i(m_state->m_metaData);
@@ -323,7 +347,7 @@ bool MWAWOLEParser::parse(MWAWInputStreamPtr file)
     // separated the directory and the name
     //    MatOST/MatadorObject1/Ole10Native
     //      -> dir="MatOST/MatadorObject1", base="Ole10Native"
-    std::string::size_type pos = name.find_last_of('/');
+    auto pos = name.find_last_of('/');
 
     std::string dir, base;
     if (pos == std::string::npos) base = name;
@@ -351,7 +375,7 @@ bool MWAWOLEParser::parse(MWAWInputStreamPtr file)
     int id[2] = { -1, -1};
     while (pos != std::string::npos) {
       if (pos >= 1 && dir[pos-1] >= '0' && dir[pos-1] <= '9') {
-        std::string::size_type idP = pos-1;
+        auto idP = pos-1;
         while (idP >=1 && dir[idP-1] >= '0' && dir[idP-1] <= '9')
           idP--;
         int val = std::atoi(dir.substr(idP, idP-pos).c_str());
@@ -370,11 +394,8 @@ bool MWAWOLEParser::parse(MWAWInputStreamPtr file)
     listsById.insert(std::multimap<int, MWAWOLEParserInternal::OleDef>::value_type(data.m_id, data));
   }
 
-  for (size_t i = 0; i < listIds.size(); i++) {
-    int id = listIds[i];
-
-    std::multimap<int, MWAWOLEParserInternal::OleDef>::iterator pos =
-      listsById.lower_bound(id);
+  for (auto id : listIds) {
+    auto pos = listsById.lower_bound(id);
 
     // try to find a representation for each id
     // FIXME: maybe we must also find some for each subid
@@ -384,7 +405,7 @@ bool MWAWOLEParser::parse(MWAWInputStreamPtr file)
     bool isPict = false;
 
     while (pos != listsById.end()) {
-      MWAWOLEParserInternal::OleDef const &dOle = pos->second;
+      auto const &dOle = pos->second;
       if (pos++->first != id) break;
 
       MWAWInputStreamPtr ole = file->getSubStreamByName(dOle.m_name);
@@ -407,8 +428,17 @@ bool MWAWOLEParser::parse(MWAWInputStreamPtr file)
 
       try {
         librevenge::RVNGPropertyList pList;
+        int encoding=m_state->m_encoding;
+        bool isMainOle=dOle.m_dir.empty();
         if (readMM(ole, dOle.m_base, asciiFile));
-        else if (readSummaryInformation(ole, dOle.m_base, dOle.m_dir.empty() ? m_state->m_metaData : pList, asciiFile));
+        else if (readSummaryInformation(ole, dOle.m_base, isMainOle ? m_state->m_encoding : encoding, isMainOle ? m_state->m_metaData : pList, asciiFile)) {
+          if (isMainOle && m_state->m_encoding!=encoding && m_state->m_fontConverter &&
+              m_state->m_encoding>=1250 && m_state->m_encoding<=1258) {
+            std::stringstream s;
+            s << "CP" << m_state->m_encoding;
+            m_state->m_fontId=m_state->m_fontConverter->getId(s.str().c_str());
+          }
+        }
         else if (readObjInfo(ole, dOle.m_base, asciiFile));
         else if (readOle(ole, dOle.m_base, asciiFile));
         else if (isOlePres(ole, dOle.m_base) &&
@@ -521,9 +551,9 @@ bool MWAWOLEParser::readOle(MWAWInputStreamPtr ip, std::string const &oleName,
   ip->seek(0, librevenge::RVNG_SEEK_SET);
 
   int val[20];
-  for (int i= 0; i < 20; i++) {
-    val[i] = static_cast<int>(ip->readLong(1));
-    if (val[i] < -10 || val[i] > 10) return false;
+  for (int &i : val) {
+    i = static_cast<int>(ip->readLong(1));
+    if (i < -10 || i > 10) return false;
   }
 
   libmwaw::DebugStream f;
@@ -572,7 +602,7 @@ bool MWAWOLEParser::readMM(MWAWInputStreamPtr input, std::string const &oleName,
   if (input->tell() != 14 || !input->isEnd()) return false;
 
   input->seek(0, librevenge::RVNG_SEEK_SET);
-  int entete = static_cast<int>(input->readULong(2));
+  auto entete = static_cast<int>(input->readULong(2));
   if (entete != 0x444e) {
     if (entete == 0x4e44) {
       MWAW_DEBUG_MSG(("MWAWOLEParser::readMM: ERROR: endian mode probably bad, potentially bad PC/Mac mode detection.\n"));
@@ -583,8 +613,7 @@ bool MWAWOLEParser::readMM(MWAWInputStreamPtr input, std::string const &oleName,
   f << "@@MM:";
 
   int val[6];
-  for (int i = 0; i < 6; i++)
-    val[i] = static_cast<int>(input->readLong(2));
+  for (auto &v : val) v = static_cast<int>(input->readLong(2));
 
   switch (val[5]) {
   case 0:
@@ -633,7 +662,7 @@ bool MWAWOLEParser::readCompObj(MWAWInputStreamPtr ip, std::string const &oleNam
   ip->seek(0,librevenge::RVNG_SEEK_SET);
 
   for (int i = 0; i < 6; i++) {
-    int val = static_cast<int>(ip->readLong(2));
+    auto val = static_cast<int>(ip->readLong(2));
     f << val << ", ";
   }
 
@@ -643,8 +672,7 @@ bool MWAWOLEParser::readCompObj(MWAWInputStreamPtr ip, std::string const &oleNam
   ascii.addPos(12);
   // the clsid
   unsigned long clsData[4]; // ushort n1, n2, n3, b8, ... b15
-  for (int i = 0; i < 4; i++)
-    clsData[i] = ip->readULong(4);
+  for (auto &data : clsData) data = ip->readULong(4);
 
   f.str("");
   f << "@@CompObj(CLSID):";
@@ -741,8 +769,8 @@ bool MWAWOLEParser::readCompObj(MWAWInputStreamPtr ip, std::string const &oleNam
 //////////////////////////////////////////////////
 // summary and doc summary
 //////////////////////////////////////////////////
-bool MWAWOLEParser::readSummaryInformation(MWAWInputStreamPtr input, std::string const &oleName, librevenge::RVNGPropertyList &pList,
-    libmwaw::DebugFile &ascii) const
+bool MWAWOLEParser::readSummaryInformation(MWAWInputStreamPtr input, std::string const &oleName,
+    int &encoding, librevenge::RVNGPropertyList &pList, libmwaw::DebugFile &ascii) const
 {
   if (oleName!="SummaryInformation" && oleName!="DocumentSummaryInformation") return false;
   input->seek(0, librevenge::RVNG_SEEK_SET);
@@ -750,7 +778,7 @@ bool MWAWOLEParser::readSummaryInformation(MWAWInputStreamPtr input, std::string
   f << "Entries(SumInfo):";
   bool isDoc=oleName=="DocumentSummaryInformation";
   if (isDoc) f << "doc,";
-  int val=int(input->readULong(2));
+  auto val=int(input->readULong(2));
   if (val==0xfeff) {
     input->setReadInverted(false);
     val=0xfffe;
@@ -766,18 +794,21 @@ bool MWAWOLEParser::readSummaryInformation(MWAWInputStreamPtr input, std::string
     val=int(input->readULong(2));
     if (val) f << "f" << i << "=" << val << ",";
   }
-  val=int(input->readULong(4));
-  if (val==0x1000000) {
-    val=1;
+  unsigned long lVal=input->readULong(4);
+  if ((lVal&0xF0FFFFFF)==0) {
+    lVal=(lVal>>24);
     input->setReadInverted(!input->readInverted());
   }
-  if (val!=1) {
+  if (lVal==0 || lVal>15) { // find 1 or 2 sections, unsure about the maximum numbers
     MWAW_DEBUG_MSG(("MWAWOLEParser::readSummaryInformation: summary info is bad\n"));
-    f << "###sumInfo=" << val << ",";
+    f << "###sumInfo=" << std::hex << lVal << std::dec << ",";
     ascii.addPos(0);
     ascii.addNote(f.str().c_str());
     return true;
   }
+  auto numSection=int(lVal);
+  if (numSection!=1)
+    f << "num[section]=" << numSection << ",";
   for (int i=0; i<4; ++i) {
     val=int(input->readULong(4));
     static int const expected[]= {int(0xf29f85e0),0x10684ff9,0x891ab,int(0xd9b3272b)};
@@ -790,7 +821,7 @@ bool MWAWOLEParser::readSummaryInformation(MWAWInputStreamPtr input, std::string
       first=false;
     }
   }
-  int decal=int(input->readULong(4));
+  auto decal=int(input->readULong(4));
   if (decal<0x30 || input->size()<decal) {
     MWAW_DEBUG_MSG(("MWAWOLEParser::readSummaryInformation: decal is bad\n"));
     f << "decal=" << val << ",";
@@ -807,63 +838,72 @@ bool MWAWOLEParser::readSummaryInformation(MWAWInputStreamPtr input, std::string
     input->seek(decal, librevenge::RVNG_SEEK_SET);
   }
 
-  long pos=input->tell();
-  f.str("");
-  f << "SumInfo-A:";
-  long pSetSize=long(input->readULong(4));
-  int N=int(input->readULong(4));
-  f << "N=" << N << ",";
-  if (pSetSize<0 || input->size()-pos<pSetSize || (pSetSize-8)/8<N) {
-    MWAW_DEBUG_MSG(("MWAWOLEParser::readSummaryInformation: psetstruct is bad\n"));
-    f << "###";
-    ascii.addPos(pos);
-    ascii.addNote(f.str().c_str());
-    return true;
-  }
-  f << "[";
-  std::map<long,int> posToTypeMap;
-  for (int i=0; i<N; ++i) {
-    int type=int(input->readULong(4));
-    int depl=int(input->readULong(4));
-    if (depl==0) continue;
-    f << std::hex << depl << std::dec << ":" << type << ",";
-    if (depl<8+8*N || depl+4>pSetSize || posToTypeMap.find(pos+depl)!=posToTypeMap.end()) {
-      f << "###";
-      continue;
-    }
-    posToTypeMap[pos+depl]=type;
-  }
-  f << "],";
-  ascii.addPos(pos);
-  ascii.addNote(f.str().c_str());
-
-  for (std::map<long,int>::const_iterator it=posToTypeMap.begin(); it!=posToTypeMap.end(); ++it) {
-    pos=it->first;
-    long endPos=input->size();
-    std::map<long,int>::const_iterator nextIt=it;
-    if (++nextIt!=posToTypeMap.end()) endPos=nextIt->first;
-    input->seek(pos, librevenge::RVNG_SEEK_SET);
+  for (int sect=0; sect<numSection; ++sect) {
+    long pos=input->tell();
     f.str("");
-    f << "SumInfo-B" << it->second << ":";
-    int type=int(input->readULong(4));
-    if (type==0x1e && !isDoc && ((it->second>=2 && it->second<=6) || it->second==8)) {
-      librevenge::RVNGString text;
-      if (readSummaryPropertyString(input, endPos, type, text, f) && !text.empty()) {
-        static char const *(attribNames[]) = {
-          "", "", "dc:title", "dc:subject", "meta:initial-creator",
-          "meta:keywords", "dc:description"/*comment*/, "", "dc:creator"
-        };
-        pList.insert(attribNames[it->second], text);
+    f << "SumInfo-A:";
+    auto pSectSize=long(input->readULong(4));
+    long endSect=pos+pSectSize;
+    auto N=int(input->readULong(4));
+    f << "N=" << N << ",";
+    if (pSectSize<0 || input->size()-pos<pSectSize || (pSectSize-8)/8<N) {
+      MWAW_DEBUG_MSG(("MWAWOLEParser::readSummaryInformation: psetstruct is bad\n"));
+      f << "###";
+      ascii.addPos(pos);
+      ascii.addNote(f.str().c_str());
+      return true;
+    }
+    f << "[";
+    std::map<long,int> posToTypeMap;
+    for (int i=0; i<N; ++i) {
+      auto type=int(input->readULong(4));
+      auto depl=int(input->readULong(4));
+      if (depl<=0) continue;
+      f << std::hex << depl << std::dec << ":" << type << ",";
+      if ((depl-8)/8<N || depl>pSectSize-4 || posToTypeMap.find(pos+depl)!=posToTypeMap.end()) {
+        f << "###";
+        continue;
       }
+      posToTypeMap[pos+depl]=type;
     }
-    else if (!readSummaryProperty(input, endPos, type, ascii, f)) {
-      MWAW_DEBUG_MSG(("MWAWOLEParser::readSummaryInformation: find unknown type\n"));
-      f << "##type=" << std::hex << type << std::dec << ",";
-    }
-    if (input->tell()!=endPos && input->tell()!=pos)
-      ascii.addDelimiter(input->tell(),'|');
+    f << "],";
     ascii.addPos(pos);
     ascii.addNote(f.str().c_str());
+
+    long endPos=input->size();
+    for (auto it=posToTypeMap.begin(); it!=posToTypeMap.end(); ++it) {
+      pos=it->first;
+      auto nextIt=it;
+      if (++nextIt!=posToTypeMap.end()) endPos=nextIt->first;
+      input->seek(pos, librevenge::RVNG_SEEK_SET);
+      f.str("");
+      f << "SumInfo-B" << it->second << ":";
+      auto type=int(input->readULong(4));
+      if (sect==0 && it->second==1 && !isDoc && type==2) {
+        long value=-1;
+        if (readSummaryPropertyLong(input,endPos,type,value,f) && value>=0 && value<10000) // 10000 is mac
+          encoding=int(value);
+      }
+      else if (sect==0 && type==0x1e && !isDoc && ((it->second>=2 && it->second<=6) || it->second==8)) {
+        librevenge::RVNGString text;
+        if (readSummaryPropertyString(input, endPos, type, text, f) && !text.empty()) {
+          static char const *attribNames[] = {
+            "", "", "dc:title", "dc:subject", "meta:initial-creator",
+            "meta:keywords", "dc:description"/*comment*/, "", "dc:creator"
+          };
+          pList.insert(attribNames[it->second], text);
+        }
+      }
+      else if (!readSummaryProperty(input, endPos, type, ascii, f)) {
+        MWAW_DEBUG_MSG(("MWAWOLEParser::readSummaryInformation: find unknown type\n"));
+        f << "##type=" << std::hex << type << std::dec << ",";
+      }
+      if (input->tell()!=endPos && input->tell()!=pos)
+        ascii.addDelimiter(input->tell(),'|');
+      ascii.addPos(pos);
+      ascii.addNote(f.str().c_str());
+    }
+    input->seek(endSect, librevenge::RVNG_SEEK_SET);
   }
   return true;
 }
@@ -874,7 +914,7 @@ bool MWAWOLEParser::readSummaryPropertyString(MWAWInputStreamPtr input, long end
   if (!input) return false;
   long pos=input->tell();
   string.clear();
-  long sSz=long(input->readULong(4));
+  auto sSz=long(input->readULong(4));
   if (sSz<0 || (endPos-pos-4)<sSz || pos+4+sSz>endPos) {
     MWAW_DEBUG_MSG(("MWAWOLEParser::readSummaryPropertyString: string size is bad\n"));
     f << "##stringSz=" << sSz << ",";
@@ -882,7 +922,7 @@ bool MWAWOLEParser::readSummaryPropertyString(MWAWInputStreamPtr input, long end
   }
   std::string text("");
   for (long c=0; c < sSz; ++c) {
-    char ch=char(input->readULong(1));
+    auto ch=char(input->readULong(1));
     if (ch) {
       text+=ch;
       if (m_state->m_fontConverter) {
@@ -900,6 +940,31 @@ bool MWAWOLEParser::readSummaryPropertyString(MWAWInputStreamPtr input, long end
   return true;
 }
 
+bool MWAWOLEParser::readSummaryPropertyLong(MWAWInputStreamPtr input, long endPos, int type, long &value,
+    libmwaw::DebugStream &f) const
+{
+  if (!input) return false;
+  long pos=input->tell();
+  switch (type) {
+  case 2: // int
+  case 0x12: // uint
+    if (pos+2>endPos)
+      return false;
+    value=type==2 ? long(input->readLong(2)) : long(input->readULong(2));
+    break;
+  case 3: // int
+  case 9: // uint
+    if (pos+4>endPos)
+      return false;
+    value=type==3 ? long(input->readLong(4)) : long(input->readULong(4));
+    break;
+  default:
+    return false;
+  }
+  f << "val=" << value << ",";
+  return true;
+}
+
 bool MWAWOLEParser::readSummaryProperty(MWAWInputStreamPtr input, long endPos, int type,
                                         libmwaw::DebugFile &ascii, libmwaw::DebugStream &f) const
 {
@@ -907,7 +972,7 @@ bool MWAWOLEParser::readSummaryProperty(MWAWInputStreamPtr input, long endPos, i
   long pos=input->tell();
   // see propread.cxx
   if (type&0x1000) {
-    int N=int(input->readULong(4));
+    auto N=int(input->readULong(4));
     f << "N=" << N << ",";
     f << "[";
     for (int n=0; n<N; ++n) {
@@ -997,7 +1062,7 @@ bool MWAWOLEParser::readSummaryProperty(MWAWInputStreamPtr input, long endPos, i
     if (pos+4>endPos)
       return false;
     f << (type==0x41 ? "blob" : type==0x46 ? "blob[object]" : "clipboard") << ",";
-    long dSz=long(input->readULong(4));
+    auto dSz=long(input->readULong(4));
     if (dSz<0 || pos+4+dSz>endPos)
       return false;
     if (dSz) {
@@ -1102,7 +1167,7 @@ bool MWAWOLEParser::readOlePres(MWAWInputStreamPtr ip, librevenge::RVNGBinaryDat
       std::string str;
       bool find = false;
       while (ip->tell() < endHPos) {
-        unsigned char c = static_cast<unsigned char>(ip->readULong(1));
+        auto c = static_cast<unsigned char>(ip->readULong(1));
         if (c == 0) {
           find = true;
           break;
@@ -1135,8 +1200,8 @@ bool MWAWOLEParser::readOlePres(MWAWInputStreamPtr ip, librevenge::RVNGBinaryDat
     f << val << ", ";
   }
   // dim in TWIP ?
-  long extendX = long(ip->readULong(4));
-  long extendY = long(ip->readULong(4));
+  auto extendX = long(ip->readULong(4));
+  auto extendY = long(ip->readULong(4));
   if (extendX > 0 && extendY > 0) pos.setNaturalSize(MWAWVec2f(float(extendX)/20.f, float(extendY)/20.f));
   long fSize = ip->readLong(4);
   f << "extendX="<< extendX << ", extendY=" << extendY << ", fSize=" << fSize;
@@ -1237,12 +1302,11 @@ bool MWAWOLEParser::readContents(MWAWInputStreamPtr input,
   bool ok = true;
   // bdbox 0 : size in the file ?
   long dim[2];
-  dim[0] = input->readLong(4);
-  dim[1] = input->readLong(4);
+  for (auto &d : dim) d = input->readLong(4);
   f << "bdbox0=(" << dim[0] << "," << dim[1]<<"),";
   for (int i = 0; i < 3; i++) {
     /* 0,{10|21|75|101|116}x2 */
-    long val = long(input->readULong(4));
+    auto val = long(input->readULong(4));
     if (val < 1000)
       f << val << ",";
     else
@@ -1251,8 +1315,7 @@ bool MWAWOLEParser::readContents(MWAWInputStreamPtr input,
   }
   // new bdbox : size of the picture ?
   long naturalSize[2];
-  naturalSize[0] = input->readLong(4);
-  naturalSize[1] = input->readLong(4);
+  for (auto &size : naturalSize) size = input->readLong(4);
   f << std::dec << "bdbox1=(" << naturalSize[0] << "," << naturalSize[1]<<"),";
   f << "unk=" << input->readULong(4) << ","; // 24 or 32
   if (input->isEnd()) {
@@ -1273,7 +1336,7 @@ bool MWAWOLEParser::readContents(MWAWInputStreamPtr input,
   }
 
   long actPos = input->tell();
-  long size = long(input->readULong(4));
+  auto size = long(input->readULong(4));
   if (size <= 0) ok = false;
   if (ok) {
     input->seek(actPos+size+4, librevenge::RVNG_SEEK_SET);
@@ -1334,7 +1397,7 @@ bool MWAWOLEParser::readCONTENTS(MWAWInputStreamPtr input,
   input->seek(0, librevenge::RVNG_SEEK_SET);
   f << "@@CONTENTS:";
 
-  long hSize = long(input->readULong(4));
+  auto hSize = long(input->readULong(4));
   if (input->isEnd()) return false;
   f << "hSize=" << std::hex << hSize << std::dec;
 
@@ -1347,9 +1410,9 @@ bool MWAWOLEParser::readCONTENTS(MWAWInputStreamPtr input,
 
   // minimal checking of the "copied" header
   input->seek(4, librevenge::RVNG_SEEK_SET);
-  long type = long(input->readULong(4));
+  auto type = long(input->readULong(4));
   if (type < 0 || type > 4) return false;
-  long newSize = long(input->readULong(4));
+  auto newSize = long(input->readULong(4));
 
   f << ", type=" << type;
   if (newSize < 8) return false;
@@ -1361,7 +1424,7 @@ bool MWAWOLEParser::readCONTENTS(MWAWInputStreamPtr input,
   //     Maybe first in POINT, second in TWIP ?
   for (int st = 0; st < 2 ; st++) {
     long dim[4];
-    for (int i = 0; i < 4; i++) dim[i] = input->readLong(4);
+    for (auto &d : dim) d = input->readLong(4);
 
     bool ok = dim[0] >= 0 && dim[2] > dim[0] && dim[1] >= 0 && dim[3] > dim[2];
     if (ok && st==0) pos.setNaturalSize(MWAWVec2f(float(dim[2]-dim[0]), float(dim[3]-dim[1])));
@@ -1376,10 +1439,10 @@ bool MWAWOLEParser::readCONTENTS(MWAWInputStreamPtr input,
   f << ",typ=\""<<dataType<<"\""; // always " EMF" ?
 
   for (int i = 0; i < 2; i++) { // always id0=0, id1=1 ?
-    int val = static_cast<int>(input->readULong(2));
+    auto val = static_cast<int>(input->readULong(2));
     if (val) f << ",id"<< i << "=" << val;
   }
-  long dataLength = long(input->readULong(4));
+  auto dataLength = long(input->readULong(4));
   f << ",length=" << dataLength+hSize;
 
   ascii.addPos(0);
@@ -1393,14 +1456,14 @@ bool MWAWOLEParser::readCONTENTS(MWAWInputStreamPtr input,
     // or f0=a,f1=1,f2=2,f3=6c,f5=480,f6=360,f7=140,f8=f0
     // or f0=61,f1=1,f2=2,f3=58,f5=280,f6=1e0,f7=a9,f8=7f
     // f3=some header sub size ? f5/f6 and f7/f8 two other bdbox ?
-    long val = long(input->readULong(4));
+    auto val = long(input->readULong(4));
     if (val) f << std::hex << ",f" << i << "=" << val;
   }
   for (int i = 0; 2*i+100 < hSize; i++) {
     // g0=e3e3,g1=6,g2=4e6e,g3=4
     // g0=e200,g1=4,g2=a980,g3=3,g4=4c,g5=50
     // ---
-    long val = long(input->readULong(2));
+    auto val = long(input->readULong(2));
     if (val) f << std::hex << ",g" << i << "=" << val;
   }
   ascii.addNote(f.str().c_str());
