@@ -134,7 +134,7 @@ struct Block {
     }
     if (bl.m_id >= 0) o << "id=" << bl.m_id << ",";
     o << "box=" << bl.m_box << ",";
-    static char const *(wh[]) = { "L", "R", "T", "B" };
+    static char const *wh[] = { "L", "R", "T", "B" };
     if (bl.hasSameBorders()) {
       if (bl.m_borderWList[0] > 0)
         o << "bord[width]=" << bl.m_borderWList[0] << ",";
@@ -388,9 +388,9 @@ struct Cell final : public MWAWCell {
     setBackgroundColor(block->m_surfaceColor);
     m_blockId = block->m_id;
     for (int b=0; b<4; ++b) {
-      int const(wh[4]) = { libmwaw::LeftBit, libmwaw::RightBit,
-                           libmwaw::TopBit, libmwaw::BottomBit
-                         };
+      int const wh[4] = { libmwaw::LeftBit, libmwaw::RightBit,
+                          libmwaw::TopBit, libmwaw::BottomBit
+                        };
       setBorders(wh[b], block->m_borderCellList[b]);
     }
   }
@@ -2067,7 +2067,7 @@ std::shared_ptr<MacWrtProStructuresInternal::Block> MacWrtProStructures::readBlo
   for (auto &d : dim) d = float(m_input->readLong(4))/65536.f;
   block->m_box = MWAWBox2f(MWAWVec2f(dim[1],dim[0]), MWAWVec2f(dim[3],dim[2]));
 
-  static int const(wh[4])= { libmwaw::Top, libmwaw::Left, libmwaw::Bottom, libmwaw::Right };
+  static int const wh[4] = { libmwaw::Top, libmwaw::Left, libmwaw::Bottom, libmwaw::Right };
   for (auto what : wh)
     block->m_borderWList[what]=double(m_input->readLong(4))/65536.;
 
@@ -2136,7 +2136,7 @@ std::shared_ptr<MacWrtProStructuresInternal::Block> MacWrtProStructures::readBlo
   if (block->m_type==4 && sz == 0xa0) {
     // this can be a note, let check
     isNote=true;
-    static double const(expectedWidth[4])= {5,5,19,5};
+    static double const expectedWidth[4] = {5,5,19,5};
     for (int i=0; i < 4; ++i) {
       if (block->m_borderWList[i]<expectedWidth[i] ||
           block->m_borderWList[i]>expectedWidth[i]) {
