@@ -67,7 +67,12 @@ enum PLCType { FONT=0, RULER, FOOTNOTE, PAGE, ZONE, UNKNOWN};
 /** Internal: class to store the PLC: Pointer List Content ? */
 struct PLC {
   //! constructor
-  explicit PLC(PLCType type=UNKNOWN): m_type(type), m_id(-1), m_extras("") {}
+  explicit PLC(PLCType type=UNKNOWN)
+    : m_type(type)
+    , m_id(-1)
+    , m_extras("")
+  {
+  }
   //! operator<<
   friend std::ostream &operator<<(std::ostream &o, PLC const &plc);
   //! the type
@@ -113,7 +118,10 @@ std::ostream &operator<<(std::ostream &o, PLC const &plc)
 //! Internal: the font of a MsWrd1Parser
 struct Font {
   //! constructor
-  Font(): m_font(), m_type(0), m_extras("")
+  Font()
+    : m_font()
+    , m_type(0)
+    , m_extras("")
   {
   }
   //! operator<<
@@ -135,13 +143,16 @@ std::ostream &operator<<(std::ostream &o, Font const &ft)
 
 ////////////////////////////////////////
 //! Internal: the paragraph of a MsWrd1Parser
-struct Paragraph : public MWAWParagraph {
+struct Paragraph final : public MWAWParagraph {
   //! constructor
-  Paragraph(): MWAWParagraph(), m_type(0), m_type2(0)
+  Paragraph()
+    : MWAWParagraph()
+    , m_type(0)
+    , m_type2(0)
   {
   }
   //! destructor
-  ~Paragraph();
+  ~Paragraph() final;
   //! operator<<
   friend std::ostream &operator<<(std::ostream &o, Paragraph const &ft);
   //! the initial type
@@ -179,12 +190,23 @@ std::ostream &operator<<(std::ostream &o, Paragraph const &para)
 //! Internal: the state of a MsWrd1Parser
 struct State {
   //! constructor
-  State() : m_eot(-1), m_numColumns(1), m_columnsSep(0), m_textZonesList(), m_mainTextZonesList(),
-    m_fontsList(), m_paragraphsList(), m_endNote(false), m_footnotesList(), m_plcMap(),
-    m_actPage(0), m_numPages(1), m_headerHeight(0), m_footerHeight(0), m_headersId(), m_footersId()
+  State()
+    : m_eot(-1)
+    , m_numColumns(1)
+    , m_columnsSep(0)
+    , m_textZonesList()
+    , m_mainTextZonesList()
+    , m_fontsList()
+    , m_paragraphsList()
+    , m_endNote(false)
+    , m_footnotesList()
+    , m_plcMap()
+    , m_actPage(0)
+    , m_numPages(1)
+    , m_headersId()
+    , m_footersId()
   {
-    for (int i = 0; i < 7; i++)
-      m_fileZonesLimit[i] = -1;
+    for (auto &limit : m_fileZonesLimit) limit = -1;
   }
 
   //! end of text
@@ -211,8 +233,6 @@ struct State {
   std::multimap<long, PLC> m_plcMap;
 
   int m_actPage /** the actual page */, m_numPages /** the number of page of the final document */;
-  int m_headerHeight /** the header height if known */,
-      m_footerHeight /** the footer height if known */;
   /** the list of header id which corresponds to each page */
   std::vector<int> m_headersId;
   /** the list of footer id which corresponds to each page */
@@ -221,29 +241,26 @@ struct State {
 
 ////////////////////////////////////////
 //! Internal: the subdocument of a MsWrdParser
-class SubDocument : public MWAWSubDocument
+class SubDocument final : public MWAWSubDocument
 {
 public:
   //! constructor for footnote, header
-  SubDocument(MsWrd1Parser &pars, MWAWInputStreamPtr input, MWAWEntry const &position) :
-    MWAWSubDocument(&pars, input, position)  {}
+  SubDocument(MsWrd1Parser &pars, MWAWInputStreamPtr const &input, MWAWEntry const &position)
+    : MWAWSubDocument(&pars, input, position)
+  {
+  }
 
   //! destructor
-  virtual ~SubDocument() {}
+  ~SubDocument() final {}
 
   //! operator!=
-  virtual bool operator!=(MWAWSubDocument const &doc) const
+  bool operator!=(MWAWSubDocument const &doc) const final
   {
     return MWAWSubDocument::operator!=(doc);
   }
-  //! operator!==
-  virtual bool operator==(MWAWSubDocument const &doc) const
-  {
-    return !operator!=(doc);
-  }
 
   //! the parser function
-  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type);
+  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type) final;
 
 protected:
 };
@@ -254,7 +271,7 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType)
     MWAW_DEBUG_MSG(("MsWrd1ParserInternal::SubDocument::parse: no listener\n"));
     return;
   }
-  MsWrd1Parser *parser=dynamic_cast<MsWrd1Parser *>(m_parser);
+  auto *parser=dynamic_cast<MsWrd1Parser *>(m_parser);
   if (!parser) {
     MWAW_DEBUG_MSG(("MsWrd1ParserInternal::SubDocument::parse: no parser\n"));
     return;
@@ -274,8 +291,9 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType)
 ////////////////////////////////////////////////////////////
 // constructor/destructor, ...
 ////////////////////////////////////////////////////////////
-MsWrd1Parser::MsWrd1Parser(MWAWInputStreamPtr input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header) :
-  MWAWTextParser(input, rsrcParser, header), m_state()
+MsWrd1Parser::MsWrd1Parser(MWAWInputStreamPtr const &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header)
+  : MWAWTextParser(input, rsrcParser, header)
+  , m_state()
 {
   init();
 }
@@ -326,13 +344,13 @@ void MsWrd1Parser::removeLastCharIfEOL(MWAWEntry &entry)
 ////////////////////////////////////////////////////////////
 void MsWrd1Parser::parse(librevenge::RVNGTextInterface *docInterface)
 {
-  if (!getInput().get() || !checkHeader(0L))  throw(libmwaw::ParseException());
+  if (!getInput().get() || !checkHeader(nullptr))  throw(libmwaw::ParseException());
   bool ok = true;
   try {
     // create the asciiFile
     ascii().setStream(getInput());
     ascii().open(asciiName());
-    checkHeader(0L);
+    checkHeader(nullptr);
     ok = createZones();
     if (ok) {
       createDocument(docInterface);
@@ -355,8 +373,7 @@ void MsWrd1Parser::parse(librevenge::RVNGTextInterface *docInterface)
 ////////////////////////////////////////////////////////////
 void MsWrd1Parser::sendMain()
 {
-  for (size_t i = 0; i < m_state->m_mainTextZonesList.size(); i++) {
-    int id = m_state->m_mainTextZonesList[i];
+  for (auto id : m_state->m_mainTextZonesList) {
     if (id < 0 || id >= int(m_state->m_textZonesList.size()))
       continue;
     MWAWEntry entry;
@@ -384,8 +401,8 @@ void MsWrd1Parser::createDocument(librevenge::RVNGTextInterface *documentInterfa
   m_state->m_actPage = 0;
   // create the page list
   std::vector<MWAWPageSpan> pageList;
-  int numHeaders=int(m_state->m_headersId.size());
-  int numFooters=int(m_state->m_footersId.size());
+  auto numHeaders=int(m_state->m_headersId.size());
+  auto numFooters=int(m_state->m_footersId.size());
   for (int i = 0; i <= m_state->m_numPages;) {
     int numSim[2]= {1,1};
     MWAWPageSpan ps(getPageSpan());
@@ -517,8 +534,8 @@ bool MsWrd1Parser::prepareTextZones()
   m_state->m_headersId.resize(0);
   m_state->m_footersId.resize(0);
   long endMain = m_state->m_eot;
-  for (size_t i=0; i < m_state->m_footnotesList.size(); i++) {
-    long pos = m_state->m_footnotesList[i][0];
+  for (auto const &footnote : m_state->m_footnotesList) {
+    long pos = footnote[0];
     if (pos >= 0x80 && pos < endMain)
       endMain = pos;
   }
@@ -529,7 +546,7 @@ bool MsWrd1Parser::prepareTextZones()
     return false;
   }
 
-  std::multimap<long,MsWrd1ParserInternal::PLC>::iterator plcIt = m_state->m_plcMap.begin();
+  auto plcIt = m_state->m_plcMap.begin();
   long pos = 0x80, prevMainPos=pos;
   int actPage = 1;
   int actType = 0;
@@ -566,7 +583,7 @@ bool MsWrd1Parser::prepareTextZones()
       continue;
     }
 
-    int id = int(m_state->m_textZonesList.size());
+    auto id = int(m_state->m_textZonesList.size());
     m_state->m_textZonesList.push_back(MWAWVec2l(prevMainPos, pos));
     prevMainPos=pos;
     if (actType==0) {
@@ -617,7 +634,7 @@ bool MsWrd1Parser::readFont(long fPos, MsWrd1ParserInternal::Font &font)
   libmwaw::DebugStream f;
   MWAWInputStreamPtr input = getInput();
   input->seek(fPos, librevenge::RVNG_SEEK_SET);
-  int sz = static_cast<int>(input->readLong(1));
+  auto sz = static_cast<int>(input->readLong(1));
   if (sz < 1 || sz > 0x7f || !input->checkPosition(fPos+1+sz)) {
     MWAW_DEBUG_MSG(("MsWrd1Parser::readFont: the zone size seems bad\n"));
     return false;
@@ -681,7 +698,7 @@ bool MsWrd1Parser::readParagraph(long fPos, MsWrd1ParserInternal::Paragraph &par
   libmwaw::DebugStream f;
   MWAWInputStreamPtr input = getInput();
   input->seek(fPos, librevenge::RVNG_SEEK_SET);
-  int sz = static_cast<int>(input->readLong(1));
+  auto sz = static_cast<int>(input->readLong(1));
   if (sz < 1 || sz > 0x7f || !input->checkPosition(fPos+1+sz)) {
     MWAW_DEBUG_MSG(("MsWrd1Parser::readParagraph: the zone size seems bad\n"));
     return false;
@@ -760,7 +777,7 @@ bool MsWrd1Parser::readParagraph(long fPos, MsWrd1ParserInternal::Paragraph &par
     for (int i = 0; i < numTabs; i++) {
       MWAWTabStop newTab;
       newTab.m_position = double(input->readLong(2))/1440.;
-      int flags = static_cast<int>(input->readULong(1));
+      auto flags = static_cast<int>(input->readULong(1));
       switch ((flags>>5)&3) {
       case 0:
         break;
@@ -817,7 +834,7 @@ bool MsWrd1Parser::readPageBreak(MWAWVec2i limits)
   long pos = limits[0]*0x80;
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   f << "Entries(PageBreak):";
-  int N = static_cast<int>(input->readULong(2));
+  auto N = static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
   if (N==0 || 4+6*N > (limits[1]-limits[0])*0x80) {
     MWAW_DEBUG_MSG(("MsWrd1Parser::readPageBreak: the number of element seems odds\n"));
@@ -830,7 +847,7 @@ bool MsWrd1Parser::readPageBreak(MWAWVec2i limits)
   f << "unkn=" << val << ",";
   MsWrd1ParserInternal::PLC plc(MsWrd1ParserInternal::PAGE);
   for (int i = 0; i < N; i++) {
-    int pg = static_cast<int>(input->readULong(2));
+    auto pg = static_cast<int>(input->readULong(2));
     long textPos = long(input->readULong(4))+0x80;
     f << "Page" << i << "=" << std::hex << textPos << std::dec;
     if (pg != i+1) f << "[page=" << pg << "]";
@@ -865,8 +882,8 @@ bool MsWrd1Parser::readFootnoteCorrespondance(MWAWVec2i limits)
   long pos = limits[0]*0x80;
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   f << "Entries(Footnote):";
-  int N = static_cast<int>(input->readULong(2));
-  int N1 = static_cast<int>(input->readULong(2));
+  auto N = static_cast<int>(input->readULong(2));
+  auto N1 = static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
   if (N!=N1) f << "N1=" << N1 << ",";
   if (N!=N1 || N==0 || 4+8*N > (limits[1]-limits[0])*0x80) {
@@ -895,8 +912,7 @@ bool MsWrd1Parser::readFootnoteCorrespondance(MWAWVec2i limits)
     (std::multimap<long,MsWrd1ParserInternal::PLC>::value_type(notePos, plc));
   }
   m_state->m_footnotesList.resize(footnoteMap.size(),MWAWVec2l(0,0));
-  std::map<long, int>::iterator fIt=footnoteMap.begin();
-  for (fIt=footnoteMap.begin(); fIt!=footnoteMap.end();) {
+  for (auto fIt=footnoteMap.begin(); fIt!=footnoteMap.end();) {
     MWAWVec2l fPos;
     fPos[0] = fIt->first;
     int id = fIt++->second;
@@ -926,8 +942,8 @@ bool MsWrd1Parser::readZones(MWAWVec2i limits)
   long pos = limits[0]*0x80;
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   f << "Entries(Zones):";
-  int N = static_cast<int>(input->readULong(2));
-  int N1 = static_cast<int>(input->readULong(2));
+  auto N = static_cast<int>(input->readULong(2));
+  auto N1 = static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
   if (N!=N1) f << "N1=" << N1 << ",";
   if (N!=N1 || N==0 || 4+10*N > (limits[1]-limits[0])*0x80) {
@@ -941,7 +957,7 @@ bool MsWrd1Parser::readZones(MWAWVec2i limits)
     long textPos = long(input->readULong(4))+0x80;
     f << std::hex << textPos << std::dec;
     f << ":f0=" << input->readLong(2); // find 1|2|3
-    int val = static_cast<int>(input->readLong(4)); // find -1, 0x900, 0xa00
+    auto val = static_cast<int>(input->readLong(4)); // find -1, 0x900, 0xa00
     if (val!=-1) f << ":f1=" << std::hex << val << std::dec;
     if (textPos < m_state->m_eot) {
       plc.m_id = i;
@@ -978,7 +994,7 @@ bool MsWrd1Parser::readDocInfo(MWAWVec2i limits)
     if (val)
       f << "f" << i << "=" << std::hex << val << std::dec << ",";
   }
-  int flags = static_cast<int>(input->readULong(1));
+  auto flags = static_cast<int>(input->readULong(1));
   switch (flags>>5) {
   case 0:
     f << "division=no,";
@@ -1021,14 +1037,13 @@ bool MsWrd1Parser::readDocInfo(MWAWVec2i limits)
   if (flags&3) f << "flags=" << (flags&3) << ",";
 
   float pageDim[2];
-  for (int i = 0; i < 2; i++)
-    pageDim[i] = float(input->readULong(2))/1440.f;
+  for (auto &d : pageDim) d = float(input->readULong(2))/1440.f;
   f << "dim=[" << pageDim[1] << "x" << pageDim[0] << "],";
   val = static_cast<int>(input->readLong(2));
   if (val != -1) f << "firstPage=" << val << ",";
   // check me
   float pagePos[2][2]; // [Y|X][header|size]
-  char const *(wh[]) = {"TopMargin", "Y[page]", "LeftMargin", "X[page]" };
+  char const *wh[] = {"TopMargin", "Y[page]", "LeftMargin", "X[page]" };
   for (int i = 0; i < 2; i++) {
     for (int j = 0; j < 2; j++) {
       pagePos[i][j] = float(input->readULong(2))/1440.f;
@@ -1051,7 +1066,7 @@ bool MsWrd1Parser::readDocInfo(MWAWVec2i limits)
   pos = input->tell();
   f.str("");
   f << "DocInfo(II):";
-  int numCols = static_cast<int>(input->readULong(1));
+  auto numCols = static_cast<int>(input->readULong(1));
   if (numCols != 1) {
     f << "nCols=" << numCols << ",";
     if (numCols < 1 || numCols > 6) {
@@ -1060,8 +1075,7 @@ bool MsWrd1Parser::readDocInfo(MWAWVec2i limits)
     }
   }
   float hfLength[2];
-  for (int i = 0; i < 2; i++)
-    hfLength[i] = float(input->readULong(2))/1440.f;
+  for (auto &hf : hfLength) hf = float(input->readULong(2))/1440.f;
   hfLength[1]=pageDim[0]-hfLength[1];
 
   f << "headerLength=" << hfLength[0] << ",";
@@ -1118,7 +1132,7 @@ bool MsWrd1Parser::readPLC(MWAWVec2i limits, int wh)
     f << "Entries(" << what << ")[" << n << "]:";
     long pos = z*0x80;
     input->seek(pos+0x7f, librevenge::RVNG_SEEK_SET);
-    int N = static_cast<int>(input->readULong(1));
+    auto N = static_cast<int>(input->readULong(1));
     f << "N=" << N << ",";
     if (4+N*6 > 0x7f) {
       f << "###";
@@ -1129,14 +1143,14 @@ bool MsWrd1Parser::readPLC(MWAWVec2i limits, int wh)
       continue;
     }
     input->seek(pos, librevenge::RVNG_SEEK_SET);
-    long fPos = long(input->readULong(4));
+    auto fPos = long(input->readULong(4));
 
     for (int i = 0; i < N; i++) {
       f << "fPos=" << std::hex << fPos;
-      long newPos = long(input->readULong(4));
+      auto newPos = long(input->readULong(4));
       f << "->" << newPos << std::dec;
 
-      int depl = static_cast<int>(input->readLong(2));
+      auto depl = static_cast<int>(input->readLong(2));
       if (depl == -1)
         plc.m_id = -1;
       else if (depl < N*6 || 4+depl >= 0x7f) {
@@ -1224,7 +1238,7 @@ bool MsWrd1Parser::sendText(MWAWEntry const &textEntry, bool isMain)
   libmwaw::DebugStream f;
   f << "TextContent:";
   int actFId=-1, actRId = -1, actPage=0;
-  std::multimap<long,MsWrd1ParserInternal::PLC>::iterator plcIt = m_state->m_plcMap.begin();
+  auto plcIt = m_state->m_plcMap.begin();
   while (plcIt != m_state->m_plcMap.end() && plcIt->first < pos) {
     MsWrd1ParserInternal::PLC const &plc = plcIt++->second;
     if (plc.m_type == MsWrd1ParserInternal::FONT)
@@ -1257,7 +1271,7 @@ bool MsWrd1Parser::sendText(MWAWEntry const &textEntry, bool isMain)
         firstPlc = false;
       }
 
-      MsWrd1ParserInternal::PLC const &plc = plcIt++->second;
+      auto const &plc = plcIt++->second;
       switch (plc.m_type) {
       case MsWrd1ParserInternal::FONT:
         if (plc.m_id >= 0 && plc.m_id < int(m_state->m_fontsList.size()))
@@ -1284,7 +1298,7 @@ bool MsWrd1Parser::sendText(MWAWEntry const &textEntry, bool isMain)
         entry.setBegin(m_state->m_footnotesList[size_t(plc.m_id)][0]);
         entry.setEnd(m_state->m_footnotesList[size_t(plc.m_id)][1]);
         removeLastCharIfEOL(entry);
-        shared_ptr<MWAWSubDocument> subdoc
+        std::shared_ptr<MWAWSubDocument> subdoc
         (new MsWrd1ParserInternal::SubDocument(*this, getInput(), entry));
         getTextListener()->insertNote(MWAWNote(m_state->m_endNote ? MWAWNote::EndNote : MWAWNote::FootNote), subdoc);
         break;
@@ -1306,7 +1320,7 @@ bool MsWrd1Parser::sendText(MWAWEntry const &textEntry, bool isMain)
       rulerNotSent = false;
     }
     if (fontNotSent) getTextListener()->setFont(actFont.m_font);
-    unsigned char c = static_cast<unsigned char>(input->readULong(1));
+    auto c = static_cast<unsigned char>(input->readULong(1));
     f << char(c);
     switch (c) {
     case 1:
@@ -1357,7 +1371,7 @@ bool MsWrd1Parser::checkHeader(MWAWHeader *header, bool strict)
   }
   long pos = 0;
   input->seek(pos, librevenge::RVNG_SEEK_SET);
-  int val = static_cast<int>(input->readULong(2));
+  auto val = static_cast<int>(input->readULong(2));
   switch (val) {
   case 0xfe32:
     switch (input->readULong(2)) {
@@ -1423,8 +1437,7 @@ bool MsWrd1Parser::checkHeader(MWAWHeader *header, bool strict)
   ascii().addNote(f.str().c_str());
 
   long textSize[2];
-  for (int i = 0; i < 2; i++)
-    textSize[i] = input->readLong(4);
+  for (auto &tSize : textSize) tSize = input->readLong(4);
   if (textSize[0] != textSize[1] || 0x80+textSize[0] != m_state->m_eot) {
     MWAW_DEBUG_MSG(("MsWrd1Parser::checkHeader: problem with text position length\n"));
     if (strict) return false;
