@@ -628,7 +628,7 @@ std::ostream &operator<<(std::ostream &o, Table::Cell const &cell)
 {
   if (cell.hasBorders()) {
     o << "borders=[";
-    char const *(wh[]) = { "T", "L", "B", "R" };
+    char const *wh[] = { "T", "L", "B", "R" };
     for (size_t i = 0; i < cell.m_borders.size() ; i++) {
       if (!cell.m_borders[i].isSet()) continue;
       if (i < 4) o << wh[i];
