@@ -78,7 +78,7 @@ struct State {
 PowerPoint3OLE::PowerPoint3OLE(MWAWInputStreamPtr const &input, int vers, MWAWFontConverterPtr const &fontConverter, int fId)
   : m_state(new PowerPoint3OLEInternal::State(input, vers))
 {
-  char const(*mainOle)=(version()<=4 ? "PP40" : "PowerPoint Document");
+  char const *mainOle =(version()<=4 ? "PP40" : "PowerPoint Document");
   if (input && input->isStructured() && input->getSubStreamByName(mainOle))
     m_state->m_oleParser.reset(new MWAWOLEParser(mainOle, fontConverter, fId));
 }
@@ -272,7 +272,7 @@ bool PowerPoint3OLE::parseHeader(MWAWInputStreamPtr input, std::string const &na
   }
   for (int i=0; i<9; ++i) {
     auto val=int(input->readULong(2));
-    int const(expected[])= {7,0,0x3f0,0,0xc05f,0xe391,1,0,0};
+    int const expected[]= {7,0,0x3f0,0,0xc05f,0xe391,1,0,0};
     if (val!=expected[i]) f << "f" << i << "=" << std::hex << val << std::dec << ",";
   }
   ascFile.addPos(0);
@@ -299,7 +299,7 @@ bool PowerPoint3OLE::parsePersistentStorage(MWAWInputStreamPtr input, std::strin
   int val;
   for (int i=0; i<2; ++i) { // f1=3c6|3e0
     val=int(input->readULong(2));
-    int const(expected[])= {7,0x3e0};
+    int const expected[]= {7,0x3e0};
     if (val!=expected[i])
       f << "f" << i << "=" << val << ",";
   }
